"""
Structured information on a brain atlas (version level).
"""

# this file was auto-generated!

from datetime import date
from openminds.base import IRI

from openminds.base import LinkedMetadata
from openminds.properties import Property


class BrainAtlasVersion(LinkedMetadata):
    """
    Structured information on a brain atlas (version level).
    """

    type_ = "https://openminds.ebrains.eu/sands/BrainAtlasVersion"
    context = {"@vocab": "https://openminds.ebrains.eu/vocab/"}
    schema_version = "latest"

    properties = [
        Property(
            "abbreviation",
            str,
            "abbreviation",
            formatting="text/plain",
            description="no description available",
            instructions="Enter the official abbreviation of this brain atlas version.",
        ),
        Property(
            "accessibility",
            "openminds.latest.controlled_terms.ProductAccessibility",
            "accessibility",
            required=True,
            description="Level to which something is accessible to the brain atlas version.",
            instructions="Add the accessibility of the data for this research product version.",
        ),
        Property(
            "authors",
            ["openminds.latest.core.Consortium", "openminds.latest.core.Organization", "openminds.latest.core.Person"],
            "author",
            multiple=True,
            unique_items=True,
            min_items=1,
            description="Creator of a literary or creative work, as well as a dataset publication.",
            instructions="Add all parties that contributed to this brain atlas version as authors. Note that these authors will overwrite the author list provided for the overarching brain atlas.",
        ),
        Property(
            "coordinate_space",
            "openminds.latest.sands.CommonCoordinateSpaceVersion",
            "coordinateSpace",
            required=True,
            description="Two or three dimensional geometric setting.",
            instructions="Add the specific common coordinate space in which this brain atlas version exists.",
        ),
        Property(
            "copyright",
            "openminds.latest.core.Copyright",
            "copyright",
            description="Exclusive and assignable legal right of an originator to reproduce, publish, sell, or distribute the matter and form of a creative work for a defined time period.",
            instructions="Enter the copyright information of this research product version.",
        ),
        Property(
            "custodians",
            ["openminds.latest.core.Consortium", "openminds.latest.core.Organization", "openminds.latest.core.Person"],
            "custodian",
            multiple=True,
            unique_items=True,
            min_items=1,
            description="The 'custodian' is a legal person who is responsible for the content and quality of the data, metadata, and/or code of a research product.",
            instructions="Add all parties that fulfill the role of a custodian for the research product version (e.g., a research group leader or principle investigator). Custodians are typically the main contact in case of misconduct, obtain permission from the contributors to publish personal information, and maintain the content and quality of the data, metadata, and/or code of the research product version.",
        ),
        Property(
            "description",
            str,
            "description",
            formatting="text/markdown",
            multiline=True,
            description="Longer statement or account giving the characteristics of the brain atlas version.",
            instructions="Enter a description (or abstract) of this research product version. Note that this version specific description will overwrite the description for the overarching dataset.",
        ),
        Property(
            "digital_identifier",
            ["openminds.latest.core.DOI", "openminds.latest.core.ISBN", "openminds.latest.core.RRID"],
            "digitalIdentifier",
            description="Digital handle to identify objects or legal persons.",
            instructions="Add the globally unique and persistent digital identifier of this research product version.",
        ),
        Property(
            "full_documentation",
            ["openminds.latest.core.DOI", "openminds.latest.core.File", "openminds.latest.core.WebResource"],
            "fullDocumentation",
            required=True,
            description="Non-abridged instructions, comments, and information for using a particular product.",
            instructions="Add the publication or file that acts as the full documentation of this research product version.",
        ),
        Property(
            "full_name",
            str,
            "fullName",
            formatting="text/plain",
            description="Whole, non-abbreviated name of the brain atlas version.",
            instructions="Enter a descriptive full name (or title) for this research product version. Note that this version specific full name will overwrite the full name for the overarching dataset.",
        ),
        Property(
            "funding",
            "openminds.latest.core.Funding",
            "funding",
            multiple=True,
            unique_items=True,
            min_items=1,
            description="Money provided by a legal person for a particular purpose.",
            instructions="Add all funding information of this research product version.",
        ),
        Property(
            "has_terminology",
            "openminds.latest.sands.ParcellationTerminologyVersion",
            "hasTerminology",
            required=True,
            description="no description available",
            instructions="Enter the specific parcellation terminology of this brain atlas version.",
        ),
        Property(
            "homepage",
            IRI,
            "homepage",
            description="Main website of the brain atlas version.",
            instructions="Enter the internationalized resource identifier (IRI) to the homepage of this research product version.",
        ),
        Property(
            "how_to_cite",
            str,
            "howToCite",
            formatting="text/markdown",
            multiline=True,
            description="Preferred format for citing a particular object or legal person.",
            instructions="Enter the preferred citation text for this research product version. Leave blank if citation text can be extracted from the assigned digital identifier.",
        ),
        Property(
            "is_alternative_version_of",
            "openminds.latest.sands.BrainAtlasVersion",
            "isAlternativeVersionOf",
            multiple=True,
            unique_items=True,
            min_items=1,
            description="Reference to an original form where the essence was preserved, but presented in an alternative form.",
            instructions="Add all brain atlas versions that can be used alternatively to this brain atlas version.",
        ),
        Property(
            "is_new_version_of",
            "openminds.latest.sands.BrainAtlasVersion",
            "isNewVersionOf",
            description="Reference to a previous (potentially outdated) particular form of something.",
            instructions="Add the brain atlas version preceding this brain atlas version.",
        ),
        Property(
            "keywords",
            [
                "openminds.latest.controlled_terms.ActionStatusType",
                "openminds.latest.controlled_terms.AgeCategory",
                "openminds.latest.controlled_terms.AnalysisTechnique",
                "openminds.latest.controlled_terms.AnatomicalAxesOrientation",
                "openminds.latest.controlled_terms.AnatomicalIdentificationType",
                "openminds.latest.controlled_terms.AnatomicalPlane",
                "openminds.latest.controlled_terms.AnnotationCriteriaType",
                "openminds.latest.controlled_terms.AnnotationType",
                "openminds.latest.controlled_terms.AtlasType",
                "openminds.latest.controlled_terms.AuditoryStimulusType",
                "openminds.latest.controlled_terms.BiologicalOrder",
                "openminds.latest.controlled_terms.BiologicalProcess",
                "openminds.latest.controlled_terms.BiologicalSex",
                "openminds.latest.controlled_terms.BreedingType",
                "openminds.latest.controlled_terms.CellCultureType",
                "openminds.latest.controlled_terms.CellType",
                "openminds.latest.controlled_terms.ChemicalMixtureType",
                "openminds.latest.controlled_terms.Colormap",
                "openminds.latest.controlled_terms.ContributionType",
                "openminds.latest.controlled_terms.CranialWindowConstructionType",
                "openminds.latest.controlled_terms.CranialWindowReinforcementType",
                "openminds.latest.controlled_terms.CriteriaQualityType",
                "openminds.latest.controlled_terms.DataType",
                "openminds.latest.controlled_terms.DeviceType",
                "openminds.latest.controlled_terms.DifferenceMeasure",
                "openminds.latest.controlled_terms.Disease",
                "openminds.latest.controlled_terms.DiseaseModel",
                "openminds.latest.controlled_terms.EducationalLevel",
                "openminds.latest.controlled_terms.ElectricalStimulusType",
                "openminds.latest.controlled_terms.EthicsAssessment",
                "openminds.latest.controlled_terms.ExperimentalApproach",
                "openminds.latest.controlled_terms.FileBundleGrouping",
                "openminds.latest.controlled_terms.FileRepositoryType",
                "openminds.latest.controlled_terms.FileUsageRole",
                "openminds.latest.controlled_terms.GeneticStrainType",
                "openminds.latest.controlled_terms.GustatoryStimulusType",
                "openminds.latest.controlled_terms.Handedness",
                "openminds.latest.controlled_terms.Language",
                "openminds.latest.controlled_terms.Laterality",
                "openminds.latest.controlled_terms.LearningResourceType",
                "openminds.latest.controlled_terms.MeasuredQuantity",
                "openminds.latest.controlled_terms.MeasuredSignalType",
                "openminds.latest.controlled_terms.MetaDataModelType",
                "openminds.latest.controlled_terms.ModelAbstractionLevel",
                "openminds.latest.controlled_terms.ModelScope",
                "openminds.latest.controlled_terms.MolecularEntity",
                "openminds.latest.controlled_terms.OlfactoryStimulusType",
                "openminds.latest.controlled_terms.OperatingDevice",
                "openminds.latest.controlled_terms.OperatingSystem",
                "openminds.latest.controlled_terms.OpticalStimulusType",
                "openminds.latest.controlled_terms.Organ",
                "openminds.latest.controlled_terms.OrganismSubstance",
                "openminds.latest.controlled_terms.OrganismSystem",
                "openminds.latest.controlled_terms.PatchClampVariation",
                "openminds.latest.controlled_terms.PreparationType",
                "openminds.latest.controlled_terms.ProductAccessibility",
                "openminds.latest.controlled_terms.ProgrammingLanguage",
                "openminds.latest.controlled_terms.QualitativeOverlap",
                "openminds.latest.controlled_terms.SemanticDataType",
                "openminds.latest.controlled_terms.Service",
                "openminds.latest.controlled_terms.SetupType",
                "openminds.latest.controlled_terms.SoftwareApplicationCategory",
                "openminds.latest.controlled_terms.SoftwareFeature",
                "openminds.latest.controlled_terms.Species",
                "openminds.latest.controlled_terms.StimulationApproach",
                "openminds.latest.controlled_terms.StimulationTechnique",
                "openminds.latest.controlled_terms.SubcellularEntity",
                "openminds.latest.controlled_terms.SubjectAttribute",
                "openminds.latest.controlled_terms.TactileStimulusType",
                "openminds.latest.controlled_terms.Technique",
                "openminds.latest.controlled_terms.TermSuggestion",
                "openminds.latest.controlled_terms.Terminology",
                "openminds.latest.controlled_terms.TissueSampleAttribute",
                "openminds.latest.controlled_terms.TissueSampleType",
                "openminds.latest.controlled_terms.TypeOfUncertainty",
                "openminds.latest.controlled_terms.UBERONParcellation",
                "openminds.latest.controlled_terms.UnitOfMeasurement",
                "openminds.latest.controlled_terms.VisualStimulusType",
            ],
            "keyword",
            multiple=True,
            unique_items=True,
            min_items=1,
            description="Significant word or concept that are representative of the brain atlas version.",
            instructions="Add all relevant keywords to this research product version either by adding controlled terms or by suggesting new terms.",
        ),
        Property(
            "license",
            "openminds.latest.core.License",
            "license",
            required=True,
            description="Grant by a party to another party as an element of an agreement between those parties that permits to do, use, or own something.",
            instructions="Add the license of this brain atlas version.",
        ),
        Property(
            "major_version_identifier",
            str,
            "majorVersionIdentifier",
            formatting="text/plain",
            description="no description available",
            instructions="Enter the identifier of the major version release this research product version belongs to.",
        ),
        Property(
            "ontology_identifier",
            IRI,
            "ontologyIdentifier",
            description="Term or code used to identify the brain atlas version registered within a particular ontology.",
            instructions="Enter the internationalized resource identifier (IRI) to the related ontological term matching this brain atlas version.",
        ),
        Property(
            "other_contributions",
            "openminds.latest.core.Contribution",
            "otherContribution",
            multiple=True,
            unique_items=True,
            min_items=1,
            description="Giving or supplying of something (such as money or time) as a part or share other than what is covered elsewhere.",
            instructions="Add any other contributions to this research product version that are not covered under 'author'/'developer' or 'custodian'.",
        ),
        Property(
            "related_publications",
            [
                "openminds.latest.core.DOI",
                "openminds.latest.core.HANDLE",
                "openminds.latest.core.ISBN",
                "openminds.latest.core.ISSN",
                "openminds.latest.publications.Book",
                "openminds.latest.publications.Chapter",
                "openminds.latest.publications.ScholarlyArticle",
            ],
            "relatedPublication",
            multiple=True,
            unique_items=True,
            min_items=1,
            description="Reference to something that was made available for the general public to see or buy.",
            instructions="Add all further publications besides the full documentation that provide the original context for the production of this research product version (e.g., an original research article that used or produced the data of this research product version).",
        ),
        Property(
            "release_date",
            date,
            "releaseDate",
            required=True,
            description="Fixed date on which a product is due to become or was made available for the general public to see or buy",
            instructions="Enter the date (actual or intended) on which this research product version was first release, formatted as 'YYYY-MM-DD'.",
        ),
        Property(
            "repository",
            "openminds.latest.core.FileRepository",
            "repository",
            description="Place, room, or container where something is deposited or stored.",
            instructions="Add the file repository of this research product version.",
        ),
        Property(
            "short_name",
            str,
            "shortName",
            formatting="text/plain",
            required=True,
            description="Shortened or fully abbreviated name of the brain atlas version.",
            instructions="Enter a short name (or alias) for this research product version that could be used as a shortened display title (e.g., for web services with too little space to display the full name).",
        ),
        Property(
            "support_channels",
            str,
            "supportChannel",
            multiple=True,
            unique_items=True,
            min_items=1,
            formatting="text/plain",
            description="Way of communication used to interact with users or customers.",
            instructions="Enter all channels through which a user can receive support for handling this research product version.",
        ),
        Property(
            "type",
            "openminds.latest.controlled_terms.AtlasType",
            "type",
            description="Distinct class to which a group of entities or concepts with similar characteristics or attributes belong to.",
            instructions="Add the type of this brain atlas version.",
        ),
        Property(
            "used_specimens",
            [
                "openminds.latest.core.Subject",
                "openminds.latest.core.SubjectGroup",
                "openminds.latest.core.TissueSample",
                "openminds.latest.core.TissueSampleCollection",
            ],
            "usedSpecimen",
            multiple=True,
            unique_items=True,
            min_items=1,
            description="no description available",
            instructions="Add the specimen that was used for the creation of this brain atlas version.",
        ),
        Property(
            "version_identifier",
            str,
            "versionIdentifier",
            formatting="text/plain",
            required=True,
            description="Term or code used to identify the version of something.",
            instructions="Enter the version identifier of this research product version.",
        ),
        Property(
            "version_innovation",
            str,
            "versionInnovation",
            formatting="text/markdown",
            multiline=True,
            required=True,
            description="Documentation on what changed in comparison to a previously published form of something.",
            instructions="Enter a short description (or summary) of the novelties/peculiarities of this research product version in comparison to its preceding versions. If this research product version is the first version, you can enter the following disclaimer 'This is the first version of this research product'.",
        ),
    ]

    def __init__(
        self,
        id=None,
        abbreviation=None,
        accessibility=None,
        authors=None,
        coordinate_space=None,
        copyright=None,
        custodians=None,
        description=None,
        digital_identifier=None,
        full_documentation=None,
        full_name=None,
        funding=None,
        has_terminology=None,
        homepage=None,
        how_to_cite=None,
        is_alternative_version_of=None,
        is_new_version_of=None,
        keywords=None,
        license=None,
        major_version_identifier=None,
        ontology_identifier=None,
        other_contributions=None,
        related_publications=None,
        release_date=None,
        repository=None,
        short_name=None,
        support_channels=None,
        type=None,
        used_specimens=None,
        version_identifier=None,
        version_innovation=None,
    ):
        return super().__init__(
            id=id,
            abbreviation=abbreviation,
            accessibility=accessibility,
            authors=authors,
            coordinate_space=coordinate_space,
            copyright=copyright,
            custodians=custodians,
            description=description,
            digital_identifier=digital_identifier,
            full_documentation=full_documentation,
            full_name=full_name,
            funding=funding,
            has_terminology=has_terminology,
            homepage=homepage,
            how_to_cite=how_to_cite,
            is_alternative_version_of=is_alternative_version_of,
            is_new_version_of=is_new_version_of,
            keywords=keywords,
            license=license,
            major_version_identifier=major_version_identifier,
            ontology_identifier=ontology_identifier,
            other_contributions=other_contributions,
            related_publications=related_publications,
            release_date=release_date,
            repository=repository,
            short_name=short_name,
            support_channels=support_channels,
            type=type,
            used_specimens=used_specimens,
            version_identifier=version_identifier,
            version_innovation=version_innovation,
        )

    @classmethod
    def instances(cls):
        return [value for value in cls.__dict__.values() if isinstance(value, cls)]

    @classmethod
    def by_name(cls, name):
        if cls._instance_lookup is None:
            cls._instance_lookup = {}
            for instance in cls.instances():
                cls._instance_lookup[instance.name] = instance
                if instance.synonyms:
                    for synonym in instance.synonyms:
                        cls._instance_lookup[synonym] = instance
        return cls._instance_lookup[name]


BrainAtlasVersion.aal1_spm12_v4 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/AAL1_SPM12-v4",
    abbreviation="AAL1",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/MNI-Colin27_1998"},
    description="The AAL1 atlas comprises an anatomical parcellation of the spatially normalized single-subject high-resolution T1 volume (Colin27, 2008) provided by the Montreal Neurological Institute (MNI) which can be used to automatically label individual subject brains of functional studies. The MNI single-subjectmain sulci were first delineated and further used as landmarks for the 3D definition of 45 anatomical volumes of interest (AVOI) in each hemisphere. This procedure was performed using a dedicated software which allowed a 3D following of the sulci course on the edited brain. Regions of interest were then drawn manually with the same software every 2mm on the axial slices of the high-resolution MNI single subject. The 90 AVOI were reconstructed and assigned a label. For automated anatomical labelling of functional studies according to this parcellation method, three procedures are proposed: (1) labelling of an extremum defined by a set of coordinates; (2) percentage of voxels belonging to teach of the AVOI intersected by a sphere centered by a set of coordinates; (3) percentage of voxels belonging to each of the AVOI intersected by an activated cluster. An interface with the Statistical Parametric Mapping (SPM) packages is provided as a freeware to researchers of the neuroimaging community to conduct the automated labelling procedures.",
    full_name="Automated Anatomical Labeling Atlas 1",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_PRE"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_POST"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_RO"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_F1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_F2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_F3OP"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_F3T"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_F1M"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_SMA"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_PCL"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_F1O"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_F1MO"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_F2O"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_F3O"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_GR"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_OC"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_T1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_HES"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_T2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_T3"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_P1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_P2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_AG"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_SMG"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_PQ"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_O1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_O2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_O3"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_Q"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_V1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_LING"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_FUSI"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_T1P"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_T2P"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_ACIN"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_MCIN"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_PCIN"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_HIP"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_PHIP"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_IN"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_AMYG"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_CAU"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_PUT"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_PAL"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AAL1_SPM12-v4_THA"},
        ],
        "ontologyIdentifier": None,
    },
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcNd4.0"},
    release_date="",
    short_name="AAL Atlas 1",
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/deterministicAtlas"},
    version_identifier="SPM12, v4",
    version_innovation="This is the 2018 release of the SPM12 version of the AAL Atlas 1 containing 3D definitions of 45 anatomical volumes of interest in each hemisphere.",
)
BrainAtlasVersion.amba_cc_fv3_2015 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/AMBA_CCFv3-2015",
    abbreviation="AMBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpace/AMB-CCF_v3"},
    full_name="Allen Mouse Brain Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminology",
        "dataLocation": None,
        "hasEntity": [
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_root"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_basicCellGroupsAndRegions"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_cerebrum"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_cerebralCortex"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corticalPlate"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_isocortex"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_frontalPoleCerebralCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_frontalPoleLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_frontalPoleLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_somatomotorAreas"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_somatomotorAreasLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_somatomotorAreasLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_somatomotorAreasLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_somatomotorAreasLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_somatomotorAreasLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primaryMotorArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primaryMotorAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primaryMotorAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primaryMotorAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primaryMotorAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primaryMotorAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_secondaryMotorArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_secondaryMotorAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_secondaryMotorAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_secondaryMotorAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_secondaryMotorAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_secondaryMotorAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_somatosensoryAreas"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_somatosensoryAreasLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_somatosensoryAreasLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_somatosensoryAreasLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_somatosensoryAreasLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_somatosensoryAreasLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_somatosensoryAreasLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaNose"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaNoseLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaNoseLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaNoseLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaNoseLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaNoseLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaNoseLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaBarrelField"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaBarrelFieldLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaBarrelFieldLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaBarrelFieldLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaBarrelFieldLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaBarrelFieldLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaBarrelFieldLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_rostrolateralLateralVisualArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_rostrolateralLateralVisualAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_rostrolateralLateralVisualAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_rostrolateralLateralVisualAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_rostrolateralLateralVisualArealayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_rostrolateralLateralVisualAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_rostrolateralLateralVisualAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaLowerLimb"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaLowerLimbLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaLowerLimbLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaLowerLimbLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaLowerLimbLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaLowerLimbLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaLowerLimbLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaMouth"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaMouthLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaMouthLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaMouthLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaMouthLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaMouthLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaMouthLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaUpperLimb"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaUpperLimbLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaUpperLimbLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaUpperLimbLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaUpperLimbLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaUpperLimbLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaUpperLimbLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaTrunk"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaTrunkLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaTrunkLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaTrunkLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaTrunkLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaTrunkLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaTrunkLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaUnassigned"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaUnassignedLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaUnassignedLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaUnassignedLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaUnassignedLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaUnassignedLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primarySomatosensoryAreaUnassignedLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_supplementalSomatosensoryArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_supplementalSomatosensoryAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_supplementalSomatosensoryAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_supplementalSomatosensoryAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_supplementalSomatosensoryAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_supplementalSomatosensoryAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_supplementalSomatosensoryAreaLayer6b"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_gustatoryAreas"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_gustatoryAreasLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_gustatoryAreasLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_gustatoryAreasLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_gustatoryAreasLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_gustatoryAreasLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_gustatoryAreasLayer6b"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_visceralArea"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_visceralAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_visceralAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_visceralAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_visceralAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_visceralAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_visceralAreaLayer6b"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_auditoryAreas"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalAuditoryArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalAuditoryAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalAuditoryAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalAuditoryAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalAuditoryAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalAuditoryAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalAuditoryAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_laterolateralAnteriorVisualArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_laterolateralAnteriorVisualAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_laterolateralAnteriorVisualAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_laterolateralAnteriorVisualAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_laterolateralAnteriorVisualArealayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_laterolateralAnteriorVisualAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_laterolateralAnteriorVisualAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primaryAuditoryArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primaryAuditoryAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primaryAuditoryAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primaryAuditoryAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primaryAuditoryAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primaryAuditoryAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primaryAuditoryAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posteriorAuditoryArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posteriorAuditoryAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posteriorAuditoryAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posteriorAuditoryAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posteriorAuditoryAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posteriorAuditoryAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posteriorAuditoryAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventralAuditoryArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventralAuditoryAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventralAuditoryAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventralAuditoryAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventralAuditoryAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventralAuditoryAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventralAuditoryAreaLayer6b"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_visualAreas"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_visualAreasLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_visualAreasLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_visualAreasLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_visualAreasLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_visualAreasLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_visualAreasLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anterolateralVisualArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anterolateralVisualAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anterolateralVisualAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anterolateralVisualAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anterolateralVisualAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anterolateralVisualAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anterolateralVisualAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteromedialVisualArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteromedialVisualAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteromedialVisualAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteromedialVisualAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteromedialVisualAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteromedialVisualAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteromedialVisualAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralVisualArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralVisualAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralVisualAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralVisualAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralVisualAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralVisualAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralVisualAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primaryVisualArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primaryVisualAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primaryVisualAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primaryVisualAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primaryVisualAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primaryVisualAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primaryVisualAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posterolateralVisualArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posterolateralVisualAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posterolateralVisualAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posterolateralVisualAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posterolateralVisualAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posterolateralVisualAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posterolateralVisualAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posteromedialVisualArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posteromedialVisualAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posteromedialVisualAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posteromedialVisualAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posteromedialVisualAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posteromedialVisualAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posteromedialVisualAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_laterointermediateArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_laterointermediateAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_laterointermediateAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_laterointermediateAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_laterointermediateAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_laterointermediateAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_laterointermediateAreaLayer6b"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_postrhinalArea"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_postrhinalAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_postrhinalAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_postrhinalAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_postrhinalAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_postrhinalAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_postrhinalAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorCingulateArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorCingulateAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorCingulateAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorCingulateAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorCingulateAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorCingulateAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorCingulateAreaDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorCingulateAreaDorsalPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorCingulateAreaDorsalPartLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorCingulateAreaDorsalPartLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorCingulateAreaDorsalPartLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorCingulateAreaDorsalPartLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorCingulateAreaVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorCingulateAreaVentralPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorCingulateAreaVentralPartLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorCingulateAreaVentralPartLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorCingulateAreaVentralPart6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorCingulateAreaVentralPart6b"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_prelimbicArea"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_prelimbicAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_prelimbicAreaLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_prelimbicAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_prelimbicAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_prelimbicAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_prelimbicAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_infralimbicArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_infralimbicAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_infralimbicAreaLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_infralimbicAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_infralimbicAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_infralimbicAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_infralimbicAreaLayer6b"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_orbitalArea"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_orbitalAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_orbitalAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_orbitalAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_orbitalAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_orbitalAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_orbitalAreaLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_orbitalAreaLateralPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_orbitalAreaLateralPartLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_orbitalAreaLateralPartLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_orbitalAreaLateralPartLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_orbitalAreaLateralPartLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_orbitalAreaMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_orbitalAreaMedialPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_orbitalAreaMedialPartLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_orbitalAreaMedialPartLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_orbitalAreaMedialPartLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_orbitalAreaMedialPartLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_orbitalAreaVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_orbitalAreaVentrolateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_orbitalAreaVentrolateralPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_orbitalAreaVentrolateralPartLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_orbitalAreaVentrolateralPartLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_orbitalAreaVentrolateralPartLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_orbitalAreaVentrolateralPartLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_agranularInsularArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_agranularInsularAreaDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_agranularInsularAreaDorsalPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_agranularInsularAreaDorsalPartLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_agranularInsularAreaDorsalPartLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_agranularInsularAreaDorsalPartLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_agranularInsularAreaDorsalPartLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_agranularInsularAreaPosteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_agranularInsularAreaPosteriorPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_agranularInsularAreaPosteriorPartLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_agranularInsularAreaPosteriorPartLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_agranularInsularAreaPosteriorPartLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_agranularInsularAreaPosteriorPartLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_agranularInsularAreaVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_agranularInsularAreaVentralPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_agranularInsularAreaVentralPartLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_agranularInsularAreaVentralPartLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_agranularInsularAreaVentralPartLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_agranularInsularAreaVentralPartLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_retrosplenialArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_retrosplenialAreaLateralAgranularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_retrosplenialAreaLateralAgranularPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_retrosplenialAreaLateralAgranularPartLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_retrosplenialAreaLateralAgranularPartLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_retrosplenialAreaLateralAgranularPartLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_retrosplenialAreaLateralAgranularPartLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mediomedialAnteriorVisualArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mediomedialAnteriorVisualAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mediomedialAnteriorVisualAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mediomedialAnteriorVisualAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mediomedialAnteriorVisualArealayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mediomedialAnteriorVisualAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mediomedialAnteriorVisualAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mediomedialPosteriorVisualArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mediomedialPosteriorVisualAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mediomedialPosteriorVisualAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mediomedialPosteriorVisualAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mediomedialPosteriorVisualArealayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mediomedialPosteriorVisualAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mediomedialPosteriorVisualAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialVisualArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialVisualAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialVisualAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialVisualAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialVisualArealayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialVisualAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialVisualAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_retrosplenialAreaDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_retrosplenialAreaDorsalPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_retrosplenialAreaDorsalPartLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_retrosplenialAreaDorsalPartLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_retrosplenialAreaDorsalPartLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_retrosplenialAreaDorsalPartLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_retrosplenialAreaDorsalPartLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_retrosplenialAreaVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_retrosplenialAreaVentralPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_retrosplenialAreaVentralPartLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_retrosplenialAreaVentralPartLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_retrosplenialAreaVentralPartLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_retrosplenialAreaVentralPartLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_retrosplenialAreaVentralPartLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posteriorParietalAssociationAreas"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posteriorParietalAssociationAreasLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posteriorParietalAssociationAreasLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posteriorParietalAssociationAreasLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posteriorParietalAssociationAreasLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posteriorParietalAssociationAreasLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posteriorParietalAssociationAreasLayer6b"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorArea"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_rostrolateralVisualArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_rostrolateralAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_rostrolateralAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_rostrolateralAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_rostrolateralAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_rostrolateralAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_rostrolateralAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_temporalAssociationAreas"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_temporalAssociationAreasLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_temporalAssociationAreasLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_temporalAssociationAreasLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_temporalAssociationAreasLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_temporalAssociationAreasLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_temporalAssociationAreasLayer6b"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_perirhinalArea"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_perirhinalAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_perirhinalAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_perirhinalAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_perirhinalAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_perirhinalAreaLayer2-3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ectorhinalArea"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ectorhinalAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ectorhinalAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ectorhinalAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ectorhinalAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ectorhinalAreaLayer6b"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_olfactoryAreas"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mainOlfactoryBulb"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mainOlfactoryBulbGlomerularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mainOlfactoryBulbGranuleLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mainOlfactoryBulbInnerPlexiformLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mainOlfactoryBulbMitralLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mainOlfactoryBulbOuterPlexiformLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_accessoryOlfactoryBulb"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_accessoryOlfactoryBulbGlomerularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_accessoryOlfactoryBulbGranularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_accessoryOlfactoryBulbMitralLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorOlfactoryNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorOlfactoryNucleusDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorOlfactoryNucleusExternalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorOlfactoryNucleusLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorOlfactoryNucleusMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorOlfactoryNucleusPosteroventralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorOlfactoryNucleusLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorOlfactoryNucleusLayer2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_taeniaTecta"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_taeniaTectaDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_taeniaTectaDorsalPartLayers14"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_taeniaTectaDorsalPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_taeniaTectaDorsalPartLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_taeniaTectaDorsalPartLayer3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_taeniaTectaDorsalPartLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_taeniaTectaVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_taeniaTectaVentralPartLayers13"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_taeniaTectaVentralPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_taeniaTectaVentralPartLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_taeniaTectaVentralPartLayer3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalPeduncularArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalPeduncularAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalPeduncularAreaLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalPeduncularAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalPeduncularAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalPeduncularAreaLayer6a"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_piriformArea"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_piriformAreaLayers13"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_piriformAreaMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_piriformAreaPyramidalLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_piriformAreaPolymorphLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusOfTheLateralOlfactoryTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusOfTheLateralOlfactoryTractLayers13"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusOfTheLateralOlfactoryTractMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusOfTheLateralOlfactoryTractPyramidalLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusOfTheLateralOlfactoryTractLayer3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corticalAmygdalarArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corticalAmygdalarAreaAnteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corticalAmygdalarAreaAnteriorPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corticalAmygdalarAreaAnteriorPartLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corticalAmygdalarAreaAnteriorPartLayer3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corticalAmygdalarAreaPosteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corticalAmygdalarAreaPosteriorPartLateralZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corticalAmygdalarAreaPosteriorPartLateralZoneLayers12"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corticalAmygdalarAreaPosteriorPartLateralZoneLayers13"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corticalAmygdalarAreaPosteriorPartLateralZoneLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corticalAmygdalarAreaPosteriorPartLateralZoneLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corticalAmygdalarAreaPosteriorPartLateralZoneLayer3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corticalAmygdalarAreaPosteriorPartMedialZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corticalAmygdalarAreaPosteriorPartMedialZoneLayers12"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corticalAmygdalarAreaPosteriorPartMedialZoneLayers13"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corticalAmygdalarAreaPosteriorPartMedialZoneLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corticalAmygdalarAreaPosteriorPartMedialZoneLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corticalAmygdalarAreaPosteriorPartMedialZoneLayer3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_piriformamygdalarArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_piriformamygdalarAreaLayers13"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_piriformamygdalarAreaMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_piriformamygdalarAreaPyramidalLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_piriformamygdalarAreaPolymorphLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_postpiriformTransitionArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_postpiriformTransitionAreaLayers13"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_postpiriformTransitionAreaLayers1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_postpiriformTransitionAreaLayers2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_postpiriformTransitionAreaLayers3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_hippocampalFormation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_hippocampalRegion"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ammonsHorn"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_fieldCA1"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_fieldCA1StratumLacunosummoleculare"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_fieldCA1StratumOriens"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_fieldCA1PyramidalLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_fieldCA1StratumRadiatum"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_fieldCA2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_fieldCA2StratumLacunosummoleculare"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_fieldCA2StratumOriens"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_fieldCA2PyramidalLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_fieldCA2StratumRadiatum"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_fieldCA3"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_fieldCA3StratumLacunosummoleculare"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_fieldCA3StratumLucidum"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_fieldCA3StratumOriens"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_fieldCA3PyramidalLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_fieldCA3StratumRadiatum"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dentateGyrus"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dentateGyrusMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dentateGyrusPolymorphLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dentateGyrusGranuleCellLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dentateGyrusSubgranularZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dentateGyrusCrest"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dentateGyrusCrestMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dentateGyrusCrestPolymorphLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dentateGyrusCrestGranuleCellLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dentateGyrusLateralBlade"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dentateGyrusLateralBladeMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dentateGyrusLateralBladePolymorphLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dentateGyrusLateralBladeGranuleCellLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dentateGyrusMedialBlade"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dentateGyrusMedialBladeMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dentateGyrusMedialBladePolymorphLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dentateGyrusMedialBladeGranuleCellLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_fasciolaCinerea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_induseumGriseum"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_retrohippocampalRegion"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalArea"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaLateralPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaLateralPartLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaLateralPartLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaLateralPartLayer2a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaLateralPartLayer2b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaLateralPartLayer3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaLateralPartLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaLateralPartLayer4-5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaLateralPartLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaLateralPartLayer5-6"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaLateralPartLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaLateralPartLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaMedialPartDorsalZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaMedialPartDorsalZoneLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaMedialPartDorsalZoneLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaMedialPartDorsalZoneLayer2a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaMedialPartDorsalZoneLayer2b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaMedialPartDorsalZoneLayer3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaMedialPartDorsalZoneLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaMedialPartDorsalZoneLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaMedialPartDorsalZoneLayer5-6"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaMedialPartDorsalZoneLayer6"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaMedialPartVentralZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaMedialPartVentralZoneLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaMedialPartVentralZoneLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaMedialPartVentralZoneLayer3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaMedialPartVentralZoneLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_entorhinalAreaMedialPartVentralZoneLayer5-6"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_parasubiculum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_parasubiculumLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_parasubiculumLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_parasubiculumLayer3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_postsubiculum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_postsubiculumLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_postsubiculumLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_postsubiculumLayer3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_presubiculum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_presubiculumLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_presubiculumLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_presubiculumLayer3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_subiculum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_subiculumDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_subiculumDorsalPartMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_subiculumDorsalPartPyramidalLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_subiculumDorsalPartStratumRadiatum"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_subiculumVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_subiculumVentralPartMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_subiculumVentralPartPyramidalLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_subiculumVentralPartStratumRadiatum"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_prosubiculum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_prosubiculumDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_prosubiculumDorsalPartMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_prosubiculumDorsalPartPyramidalLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_prosubiculumDorsalPartStratumRadiatum"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_prosubiculumVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_prosubiculumVentralPartMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_prosubiculumVentralPartPyramidalLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_prosubiculumVentralPartStratumRadiatum"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_areaProstriata"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corticalSubplate"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_layer6bIsocortex"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_claustrum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_endopiriformNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_endopiriformNucleusDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_endopiriformNucleusVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralAmygdalarNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_basolateralAmygdalarNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_basolateralAmygdalarNucleusAnteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_basolateralAmygdalarNucleusPosteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_basolateralAmygdalarNucleusVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_basomedialAmygdalarNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_basomedialAmygdalarNucleusAnteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_basomedialAmygdalarNucleusPosteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posteriorAmygdalarNucleus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_cerebralNuclei"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_striatum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_striatumDorsalRegion"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_caudoputamen"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_striatumVentralRegion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusAccumbens"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_fundusOfStriatum"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_olfactoryTubercle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_islandsOfCalleja"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_majorIslandOfCalleja"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_olfactoryTubercleLayers13"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_olfactoryTubercleMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_olfactoryTuberclePyramidalLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_olfactoryTuberclePolymorphLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralSeptalComplex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralSeptalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralSeptalNucleusCaudalCaudodorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralSeptalNucleusRostralRostroventralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralSeptalNucleusVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_septofimbrialNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_septohippocampalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_striatumlikeAmygdalarNuclei"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorAmygdalarArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_bedNucleusOfTheAccessoryOlfactoryTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_centralAmygdalarNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_centralAmygdalarNucleusCapsularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_centralAmygdalarNucleusLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_centralAmygdalarNucleusMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_intercalatedAmygdalarNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialAmygdalarNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialAmygdalarNucleusAnterodorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialAmygdalarNucleusAnteroventralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialAmygdalarNucleusPosterodorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialAmygdalarNucleusPosterodorsalPartSublayerA"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialAmygdalarNucleusPosterodorsalPartSublayerB"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialAmygdalarNucleusPosterodorsalPartSublayerC"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialAmygdalarNucleusPosteroventralPart"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_pallidum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_pallidumDorsalRegion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_globusPallidusExternalSegment"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_globusPallidusInternalSegment"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_pallidumVentralRegion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_substantiaInnominata"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_magnocellularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_pallidumMedialRegion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialSeptalComplex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialSeptalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_diagonalBandNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_triangularNucleusOfSeptum"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_pallidumCaudalRegion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_bedNucleiOfTheStriaTerminalis"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_bedNucleiOfTheStriaTerminalisAnteriorDivision"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_bedNucleiOfTheStriaTerminalisAnteriorDivisionAnterolateralArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_bedNucleiOfTheStriaTerminalisAnteriorDivisionAnteromedialArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_bedNucleiOfTheStriaTerminalisAnteriorDivisionDorsomedialNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_bedNucleiOfTheStriaTerminalisAnteriorDivisionFusiformNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_bedNucleiOfTheStriaTerminalisAnteriorDivisionJuxtacapsularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_bedNucleiOfTheStriaTerminalisAnteriorDivisionMagnocellularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_bedNucleiOfTheStriaTerminalisAnteriorDivisionOvalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_bedNucleiOfTheStriaTerminalisAnteriorDivisionRhomboidNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_bedNucleiOfTheStriaTerminalisAnteriorDivisionVentralNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_bedNucleiOfTheStriaTerminalisPosteriorDivision"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_bedNucleiOfTheStriaTerminalisPosteriorDivisionDorsalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_bedNucleiOfTheStriaTerminalisPosteriorDivisionPrincipalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_bedNucleiOfTheStriaTerminalisPosteriorDivisionInterfascicularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_bedNucleiOfTheStriaTerminalisPosteriorDivisionTransverseNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_bedNucleiOfTheStriaTerminalisPosteriorDivisionStrialExtension"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_bedNucleusOfTheAnteriorCommissure"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_brainStem"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_interbrain"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_thalamus"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_thalamusSensorymotorCortexRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventralGroupOfTheDorsalThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventralAnteriorlateralComplexOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventralMedialNucleusOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventralPosteriorComplexOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventralPosterolateralNucleusOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventralPosterolateralNucleusOfTheThalamusParvicellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventralPosteromedialNucleusOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventralPosteromedialNucleusOfTheThalamusParvicellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_subparafascicularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_subparafascicularNucleusMagnocellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_subparafascicularNucleusParvicellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_subparafascicularArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_peripeduncularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_geniculateGroupDorsalThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialGeniculateComplex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialGeniculateComplexDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialGeniculateComplexVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialGeniculateComplexMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalPartOfTheLateralGeniculateComplex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalPartOfTheLateralGeniculateComplexShell"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalPartOfTheLateralGeniculateComplexCore"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalPartOfTheLateralGeniculateComplexIpsilateralZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_thalamusPolymodalAssociationCortexRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralGroupOfTheDorsalThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralPosteriorNucleusOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posteriorComplexOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posteriorLimitingNucleusOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_suprageniculateNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorGroupOfTheDorsalThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteroventralNucleusOfThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteromedialNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteromedialNucleusDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteromedialNucleusVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anterodorsalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_interanteromedialNucleusOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_interanterodorsalNucleusOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralDorsalNucleusOfThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialGroupOfTheDorsalThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_intermediodorsalNucleusOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mediodorsalNucleusOfThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mediodorsalNucleusOfTheThalamusCentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mediodorsalNucleusOfTheThalamusLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mediodorsalNucleusOfTheThalamusMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_submedialNucleusOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_perireunensisNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_midlineGroupOfTheDorsalThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paraventricularNucleusOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_parataenialNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusOfReunions"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_intralaminarNucleiOfTheDorsalThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_rhomboidNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_centralMedialNucleusOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paracentralNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_centralLateralNucleusOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_parafascicularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_reticularNucleusOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_geniculateGroupVentralThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_intergeniculateLeafletOfTheLateralGeniculateComplex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventralPartOfTheLateralGeniculateComplex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventralPartOfTheLateralGeniculateComplexLateralZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventralPartOfTheLateralGeniculateComplexMedialZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_subgeniculateNucleus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_epithalamus"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialHabenula"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralHabenula"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_pinealBody"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_hypothalamus"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_periventricularZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_supraopticNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_accessorySupraopticGroup"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusCircularis"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paraventricularHypothalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paraventricularHypothalamicNucleusMagnocellularDivision"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paraventricularHypothalamicNucleusMagnocellularDivisionAnteriorMagnocellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paraventricularHypothalamicNucleusMagnocellularDivisionMedialMagnocellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paraventricularHypothalamicNucleusMagnocellularDivisionPosteriorMagnocellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paraventricularHypothalamicNucleusMagnocellularDivisionPosteriorMagnocellularPartLateralZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paraventricularHypothalamicNucleusMagnocellularDivisionPosteriorMagnocellularPartMedialZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paraventricularHypothalamicNucleusParvicellularDivision"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paraventricularHypothalamicNucleusParvicellularDivisionAnteriorParvicellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paraventricularHypothalamicNucleusParvicellularDivisionMedialParvicellularPartDorsalZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paraventricularHypothalamicNucleusParvicellularDivisionPeriventricularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_periventricularHypothalamicNucleusAnteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_periventricularHypothalamicNucleusIntermediatePart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_arcuateHypothalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_periventricularRegion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anterodorsalPreopticNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorHypothalamicArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteroventralPreopticNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteroventralPeriventricularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsomedialNucleusOfTheHypothalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsomedialNucleusOfTheHypothalamusAnteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsomedialNucleusOfTheHypothalamusPosteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsomedialNucleusOfTheHypothalamusVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medianPreopticNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialPreopticArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_vascularOrganOfTheLaminaTerminalis"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posterodorsalPreopticNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_parastrialNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_suprachiasmaticPreopticNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_periventricularHypothalamicNucleusPosteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_periventricularHypothalamicNucleusPreopticPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_subparaventricularZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_suprachiasmaticNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_subfornicalOrgan"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventrolateralPreopticNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_hypothalamicMedialZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorHypothalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorHypothalamicNucleusAnteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorHypothalamicNucleusCentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorHypothalamicNucleusDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorHypothalamicNucleusPosteriorPart"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mammillaryBody"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralMammillaryNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialMammillaryNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialMammillaryNucleusMedianPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_supramammillaryNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_supramammillaryNucleusLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_supramammillaryNucleusMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_tuberomammillaryNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_tuberomammillaryNucleusDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_tuberomammillaryNucleusVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialPreopticNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialPreopticNucleusCentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialPreopticNucleusLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialPreopticNucleusMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalPremammillaryNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventralPremammillaryNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paraventricularHypothalamicNucleusDescendingDivision"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paraventricularHypothalamicNucleusDescendingDivisionDorsalParvicellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paraventricularHypothalamicNucleusDescendingDivisionFornicealPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paraventricularHypothalamicNucleusDescendingDivisionLateralParvicellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paraventricularHypothalamicNucleusDescendingDivisionMedialParvicellularPartVentralZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventromedialHypothalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventromedialHypothalamicNucleusAnteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventromedialHypothalamicNucleusCentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventromedialHypothalamicNucleusDorsomedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventromedialHypothalamicNucleusVentrolateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posteriorHypothalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_hypothalamicLateralZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralHypothalamicArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralPreopticArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_preparasubthalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_parasubthalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_retrochiasmaticArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_subthalamicNucleus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_tuberalNucleus"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_zonaIncerta"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dopaminergicA13Group"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_fieldsOfForel"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medianEminence"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_midbrain"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_midbrainSensoryRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_superiorColliculusSensoryRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_superiorColliculusOpticLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_superiorColliculusSuperficialGrayLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_superiorColliculusZonalLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_inferiorColliculus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_inferiorColliculusCentralNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_inferiorColliculusDorsalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_inferiorColliculusExternalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusOfTheBrachiumOfTheInferiorColliculus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusSagulum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_parabigeminalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_midbrainTrigeminalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_midbrainMotorRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_substantiaNigraReticularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventralTegmentalArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_midbrainReticularNucleusRetrorubralArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_midbrainReticularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_midbrainReticularNucleusMagnocellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_midbrainReticularNucleusMagnocellularPartGeneral"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_midbrainReticularNucleusParvicellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_superiorColliculusMotorRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_superiorColliculusMotorRelatedDeepGrayLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_superiorColliculusMotorRelatedDeepWhiteLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_superiorColliculusMotorRelatedIntermediateWhiteLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_superiorColliculusMotorRelatedIntermediateGrayLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_superiorColliculusMotorRelatedIntermediateGrayLayerSublayerA"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_superiorColliculusMotorRelatedIntermediateGrayLayerSublayerB"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_superiorColliculusMotorRelatedIntermediateGrayLayerSublayerC"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_periaqueductalGray"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_precommissuralNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_interstitialNucleusOfCajal"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusOfDarkschewitsch"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_pretectalRegion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorPretectalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialPretectalArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusOfTheOpticTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusOfThePosteriorCommissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_olivaryPretectalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posteriorPretectalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_cuneiformNucleus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_redNucleus"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_oculomotorNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_edingerWestphalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_trochlearNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventralTegmentalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorTegmentalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralTerminalNucleusOfTheAccessoryOpticTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalTerminalNucleusOfTheAccessoryOpticTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialTerminalNucleusOfTheAccessoryOpticTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_substantiaNigraLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_midbrainBehavioralStateRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_substantiaNigraCompactPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_pedunculopontineNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_midbrainRapheNuclei"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_interfascicularNucleusRaphe"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_interpeduncularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_rostralLinearNucleusRaphe"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_centralLinearNucleusRaphe"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalNucleusRaphe"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_hindbrain"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_pons"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ponsSensoryRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusOfTheLateralLemniscus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusOfTheLateralLemniscusDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusOfTheLateralLemniscusHorizontalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusOfTheLateralLemniscusVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_principalSensoryNucleusOfTheTrigeminal"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_parabrachialNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_koellikerFuseSubnucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_parabrachialNucleusLateralDivision"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_parabrachialNucleusLateralDivisionCentralLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_parabrachialNucleusLateralDivisionDorsalLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_parabrachialNucleusLateralDivisionExternalLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_parabrachialNucleusLateralDivisionSuperiorLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_parabrachialNucleusLateralDivisionVentralLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_parabrachialNucleusMedialDivision"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_parabrachialNucleusMedialDivisionExternalMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_parabrachialNucleusMedialDivisionMedialMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_parabrachialNucleusMedialDivisionVentralMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_superiorOlivaryComplex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_superiorOlivaryComplexPeriolivaryRegion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_superiorOlivaryComplexMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_superiorOlivaryComplexLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ponsMotorRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_barringtonsNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalTegmentalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralTegmentalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_pontineCentralGray"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_pontineGray"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_pontineReticularNucleusCaudalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_pontineReticularNucleusVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_supragenualNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_superiorSalivatoryNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_supratrigeminalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_tegmentalReticularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_motorNucleusOfTrigeminal"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ponsBehavioralStateRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_superiorCentralNucleusRaphe"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_superiorCentralNucleusRapheLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_superiorCentralNucleusRapheMedialPart"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_locusCeruleus"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_laterodorsalTegmentalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusIncertus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_pontineReticularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusRaphePontis"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_subceruleusNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_sublaterodorsalNucleus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medulla"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medullaSensoryRelated"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_areaPostrema"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_cochlearNuclei"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_granularLaminaOfTheCochlearNuclei"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_cochlearNucleusSubpedunclularGranularRegion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalCochlearNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventralCochlearNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalColumnNuclei"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_cuneateNucleus"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_gracileNucleus"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_externalCuneateNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusOfTheTrapezoidBody"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusOfTheSolitaryTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusOfTheSolitaryTractCentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusOfTheSolitaryTractCommissuralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusOfTheSolitaryTractGelatinousPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusOfTheSolitaryTractLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusOfTheSolitaryTractMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_spinalNucleusOfTheTrigeminalCaudalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_spinalNucleusOfTheTrigeminalInterpolarPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_spinalNucleusOfTheTrigeminalOralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_spinalNucleusOfTheTrigeminalOralPartCaudalDorsomedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_spinalNucleusOfTheTrigeminalOralPartMiddleDorsomedialPartDorsalZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_spinalNucleusOfTheTrigeminalOralPartMiddleDorsomedialPartVentralZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_spinalNucleusOfTheTrigeminalOralPartRostralDorsomedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_spinalNucleusOfTheTrigeminalOralPartVentrolateralPart"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusZ"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medullaMotorRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_abducensNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_accessoryAbducensNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_facialMotorNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_accessoryFacialMotorNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_efferentVestibularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusAmbiguus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusAmbiguusDorsalDivision"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusAmbiguusVentralDivision"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalMotorNucleusOfTheVagusNerve"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_efferentCochlearGroup"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_gigantocellularReticularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_infracerebellarNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_inferiorOlivaryComplex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_intermediateReticularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_inferiorSalivatoryNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_linearNucleusOfTheMedulla"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralReticularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralReticularNucleusMagnocellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralReticularNucleusParvicellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_magnocellularReticularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medullaryReticularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medullaryReticularNucleusDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medullaryReticularNucleusVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_parvicellularReticularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_parasolitaryNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paragigantocellularReticularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paragigantocellularReticularNucleusDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paragigantocellularReticularNucleusLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_perihypoglossalNuclei"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusIntercalatus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusOfRoller"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusPrepositus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paramedianReticularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_parapyramidalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_parapyramidalNucleusDeepPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_parapyramidalNucleusSuperficialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_vestibularNuclei"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralVestibularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialVestibularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_spinalVestibularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_superiorVestibularNucleus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusX"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_hypoglossalNucleus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusY"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_interstitialNucleusOfTheVestibularNerve"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medullaBehavioralStateRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusRapheMagnus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusRaphePallidus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nucleusRapheObscurus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_cerebellum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_cerebellarCortex"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_vermalRegions"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lingulaI"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lingulaIMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lingulaIPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lingulaIGranularLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_centralLobule"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lobuleII"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lobuleIIMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lobuleIIPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lobuleIIGranularLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lobuleIII"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lobuleIIIMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lobuleIIIPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lobuleIIIGranularLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_culmen"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lobuleIV"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lobuleIVMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lobuleIVPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lobuleIVGranularLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lobuleV"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lobuleVMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lobuleVPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lobuleVGranularLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lobulesIV-V"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lobulesIV-VMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lobulesIV-VPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lobulesIV-VGranularLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_decliveVI"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_decliveVIMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_decliveVIPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_decliveVIGranularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_foliumtuberVermisVII"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_foliumtuberVermisVIIMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_foliumtuberVermisVIIPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_foliumtuberVermisVIIGranularLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_pyramusVIII"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_pyramusVIIIMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_pyramusVIIIPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_pyramusVIIIGranularLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_uvulaIX"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_uvulaIXMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_uvulaIXPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_uvulaIXGranularLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nodulusX"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nodulusXMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nodulusXPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nodulusXGranularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_hemisphericRegions"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_simpleLobule"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_simpleLobuleMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_simpleLobulePurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_simpleLobuleGranularLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ansiformLobule"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_crus1"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_crus1MolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_crus1PurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_crus1GranularLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_crus2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_crus2MolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_crus2PurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_crus2GranularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paramedianLobule"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paramedianLobuleMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paramedianLobulePurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paramedianLobuleGranularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_copulaPyramidis"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_copulaPyramidisMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_copulaPyramidisPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_copulaPyramidisGranularLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paraflocculus"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paraflocculusMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paraflocculusPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paraflocculusGranularLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_flocculus"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_flocculusMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_flocculusPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_flocculusGranularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_cerebellarCortexMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_cerebellarCortexPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_cerebellarCortexGranularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_cerebellarNuclei"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_fastigialNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_interposedNucleus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dentateNucleus"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_fiberTracts"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_cranialNerves"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_terminalNerve"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_vomeronasalNerve"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_olfactoryNerve"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_olfactoryNerveLayerOfMainOlfactoryBulb"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralOlfactoryTractGeneral"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralOlfactoryTractBody"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalLimb"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_accessoryOlfactoryTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorCommissureOlfactoryLimb"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_opticNerve"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_accessoryOpticTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_brachiumOfTheSuperiorColliculus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_superiorColliculusCommissure"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_opticChiasm"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_opticTract"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_tectothalamicPathway"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_oculomotorNerve"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialLongitudinalFascicle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posteriorCommissure"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_trochlearNerve"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_trochlearNerveDecussation"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_abducensNerve"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_trigeminalNerve"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_motorRootOfTheTrigeminalNerve"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_sensoryRootOfTheTrigeminalNerve"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_midbrainTractOfTheTrigeminalNerve"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_spinalTractOfTheTrigeminalNerve"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_facialNerve"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_intermediateNerve"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_genuOfTheFacialNerve"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_vestibulocochlearNerve"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_efferentCochleovestibularBundle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_vestibularNerve"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_cochlearNerve"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_trapezoidBody"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_intermediateAcousticStria"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalAcousticStria"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralLemniscus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_inferiorColliculusCommissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_brachiumOfTheInferiorColliculus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_glossopharyngealNerve"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_vagusNerve"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_solitaryTract"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_accessorySpinalNerve"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_hypoglossalNerve"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventralRoots"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalRoots"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_cervicothalamicTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsolateralFascicle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalCommissureOfTheSpinalCord"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventralCommissureOfTheSpinalCord"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_fasciculusProprius"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalColumn"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_cuneateFascicle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_gracileFascicle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_internalArcuateFibers"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialLemniscus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_spinothalamicTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralSpinothalamicTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventralSpinothalamicTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_spinocervicalTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_spinoolivaryPathway"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_spinoreticularPathway"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_spinovestibularPathway"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_spinotectalPathway"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_spinohypothalamicPathway"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_spinotelenchephalicPathway"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_hypothalamohypophysialTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_cerebellumRelatedFiberTracts"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_cerebellarCommissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_cerebellarPeduncles"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_superiorCerebelarPeduncles"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_superiorCerebellarPeduncleDecussation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_spinocerebellarTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_uncinateFascicle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventralSpinocerebellarTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_middleCerebellarPeduncle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_inferiorCerebellarPeduncle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalSpinocerebellarTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_cuneocerebellarTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_juxtarestiformBody"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_bulbocerebellarTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_olivocerebellarTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_reticulocerebellarTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_trigeminocerebellarTract"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_arborVitae"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_supracallosalCerebralWhiteMatter"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralForebrainBundleSystem"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corpusCallosum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corpusCallosumAnteriorForceps"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_externalCapsule"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corpusCallosumExtremeCapsule"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_genuOfCorpusCallosum"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corpusCallosumPosteriorForceps"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corpusCallosumRostrum"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corpusCallosumBody"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corpusCallosumSplenium"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corticospinalTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_internalCapsule"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_cerebalPeduncle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corticotectalTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corticorubralTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corticopontineTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corticobulbarTract"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_pyramid"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_pyramidalDecussation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corticospinalTractCrossed"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_corticospinalTractUncrossed"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_thalamusRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_externalMedullaryLaminaOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_internalMedullaryLaminaOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_middleThalamicCommissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_thalamicPeduncles"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_opticRadiation"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_auditoryRadiation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_extrapyramidalFiberSystems"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_cerebralNucleiRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_pallidothalmicPathway"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nigrostriatalTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nigrothalamicFibers"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_pallidotegmentalFascicle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_striatonigralPathway"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_subthalamicFascicle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_tectospinalPathway"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_directTectospinalPathway"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_doralTegmentalDecussation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_crossedTectospinalPathway"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_rubrospinalTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventralTegmentalDecussation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_rubroreticularTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_centralTegmentalBundle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_retriculospinalTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_retriculospinalTractLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_retriculospinalTractMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_vestibulospinalPathway"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialForebrainBundleSystem"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_cerebrumRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_amygdalarCapsule"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ansaPeduncularis"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_anteriorCommissureTemporalLimb"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_cingulumBundle"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_fornixSystem"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_alveus"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalFornix"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_fimbria"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_precommissuralFornixGeneral"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_precommissuralFornixDiagonalBand"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_postcommissuralFornix"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialCorticohypothalmicTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_columnsOfTheFornix"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_hippocampalCommissures"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalHippocampalCommissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventralHippocampalCommissure"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_perforantPath"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_angularPath"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_longitudinalAssociationBundle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_striaTerminalis"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_commissuralBranchOfStriaTerminalis"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_hypothalamusRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_medialForebrainBundle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventrolateralHypothalamicTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_preopticCommissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_supraopticCommissures"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_supraopticCommissuresAnterior"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_supraopticCommissuresDorsal"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_supraopticCommissuresVentral"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_premammillaryCommissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_supramammillaryDecussation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_propriohypothalamicPathways"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_propriohypothalamicPathwaysDorsal"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_propriohypothalamicPathwaysLateral"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_propriohypothalamicPathwaysMedial"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_propriohypothalamicPathwaysVentral"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_periventricularBundleOfTheHypothalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mammillaryRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_principalMammillaryTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mammilothalmicTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mammillotegmentalTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_mammillaryPeduncle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalThalamusRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_periventricularBundleOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_epithalamusRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_striaMedullaris"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_fasciculusRetroflexus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_habenularCommissure"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_pinealStalk"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_midbrainRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalLongitudinalFascicle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_dorsalTegmentalTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ventricularSystems"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralVentricle"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_rhinocele"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_subependymalZone"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_choroidPlexus"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_choroidFissure"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_interventricularForamen"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_thirdVentricle"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_cerebralAqueduct"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_fourthVentricle"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_lateralRecess"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_centralCanalSpinalCordmedulla"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_grooves"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_groovesOfTheCerebralCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_endorhinalGroove"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_hippocampalFissure"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_rhinalFissure"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_rhinalIncisure"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_groovesOfTheCerebellarCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_precentralFissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_preculminateFissure"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_primaryFissure"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posteriorSuperiorFissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_prepyramidalFissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_secondaryFissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_posterolateralFissure"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_nodularFissure"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_simpleFissure"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_intercruralFissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_ansoparamedianFissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_intraparafloccularFissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_paramedianSulcus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_parafloccularSulcus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_interpeduncularFossa"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2015_retina"},
        ],
        "ontologyIdentifier": None,
    },
    short_name="Allen Mouse Brain Atlas",
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/deterministicAtlas"},
    version_identifier="CCFv3, 2015",
)
BrainAtlasVersion.amba_cc_fv3_2017 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/AMBA_CCFv3-2017",
    abbreviation="AMBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpace/AMB-CCF_v3"},
    full_name="Allen Mouse Brain Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminology",
        "dataLocation": None,
        "hasEntity": [
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_root"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_basicCellGroupsAndRegions"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_cerebrum"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_cerebralCortex"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corticalPlate"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_isocortex"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_frontalPoleCerebralCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_frontalPoleLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_frontalPoleLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_frontalPoleLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_frontalPoleLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_frontalPoleLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_somatomotorAreas"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_somatomotorAreasLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_somatomotorAreasLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_somatomotorAreasLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_somatomotorAreasLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_somatomotorAreasLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primaryMotorArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primaryMotorAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primaryMotorAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primaryMotorAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primaryMotorAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primaryMotorAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_secondaryMotorArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_secondaryMotorAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_secondaryMotorAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_secondaryMotorAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_secondaryMotorAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_secondaryMotorAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_somatosensoryAreas"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_somatosensoryAreasLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_somatosensoryAreasLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_somatosensoryAreasLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_somatosensoryAreasLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_somatosensoryAreasLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_somatosensoryAreasLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaNose"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaNoseLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaNoseLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaNoseLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaNoseLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaNoseLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaNoseLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaBarrelField"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaBarrelFieldLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaBarrelFieldLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaBarrelFieldLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaBarrelFieldLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaBarrelFieldLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaBarrelFieldLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_rostrolateralLateralVisualArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_rostrolateralLateralVisualAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_rostrolateralLateralVisualAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_rostrolateralLateralVisualAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_rostrolateralLateralVisualArealayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_rostrolateralLateralVisualAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_rostrolateralLateralVisualAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaLowerLimb"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaLowerLimbLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaLowerLimbLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaLowerLimbLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaLowerLimbLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaLowerLimbLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaLowerLimbLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaMouth"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaMouthLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaMouthLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaMouthLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaMouthLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaMouthLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaMouthLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaUpperLimb"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaUpperLimbLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaUpperLimbLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaUpperLimbLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaUpperLimbLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaUpperLimbLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaUpperLimbLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaTrunk"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaTrunkLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaTrunkLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaTrunkLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaTrunkLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaTrunkLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaTrunkLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaUnassigned"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaUnassignedLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaUnassignedLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaUnassignedLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaUnassignedLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaUnassignedLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primarySomatosensoryAreaUnassignedLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_supplementalSomatosensoryArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_supplementalSomatosensoryAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_supplementalSomatosensoryAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_supplementalSomatosensoryAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_supplementalSomatosensoryAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_supplementalSomatosensoryAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_supplementalSomatosensoryAreaLayer6b"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_gustatoryAreas"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_gustatoryAreasLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_gustatoryAreasLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_gustatoryAreasLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_gustatoryAreasLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_gustatoryAreasLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_gustatoryAreasLayer6b"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_visceralArea"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_visceralAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_visceralAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_visceralAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_visceralAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_visceralAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_visceralAreaLayer6b"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_auditoryAreas"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalAuditoryArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalAuditoryAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalAuditoryAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalAuditoryAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalAuditoryAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalAuditoryAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalAuditoryAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_laterolateralAnteriorVisualArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_laterolateralAnteriorVisualAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_laterolateralAnteriorVisualAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_laterolateralAnteriorVisualAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_laterolateralAnteriorVisualArealayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_laterolateralAnteriorVisualAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_laterolateralAnteriorVisualAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primaryAuditoryArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primaryAuditoryAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primaryAuditoryAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primaryAuditoryAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primaryAuditoryAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primaryAuditoryAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primaryAuditoryAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteriorAuditoryArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteriorAuditoryAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteriorAuditoryAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteriorAuditoryAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteriorAuditoryAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteriorAuditoryAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteriorAuditoryAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventralAuditoryArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventralAuditoryAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventralAuditoryAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventralAuditoryAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventralAuditoryAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventralAuditoryAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventralAuditoryAreaLayer6b"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_visualAreas"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_visualAreasLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_visualAreasLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_visualAreasLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_visualAreasLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_visualAreasLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_visualAreasLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anterolateralVisualArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anterolateralVisualAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anterolateralVisualAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anterolateralVisualAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anterolateralVisualAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anterolateralVisualAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anterolateralVisualAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteromedialVisualArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteromedialVisualAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteromedialVisualAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteromedialVisualAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteromedialVisualAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteromedialVisualAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteromedialVisualAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralVisualArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralVisualAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralVisualAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralVisualAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralVisualAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralVisualAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralVisualAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primaryVisualArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primaryVisualAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primaryVisualAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primaryVisualAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primaryVisualAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primaryVisualAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primaryVisualAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posterolateralVisualArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posterolateralVisualAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posterolateralVisualAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posterolateralVisualAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posterolateralVisualAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posterolateralVisualAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posterolateralVisualAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteromedialVisualArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteromedialVisualAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteromedialVisualAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteromedialVisualAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteromedialVisualAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteromedialVisualAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteromedialVisualAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_laterointermediateArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_laterointermediateAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_laterointermediateAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_laterointermediateAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_laterointermediateAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_laterointermediateAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_laterointermediateAreaLayer6b"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_postrhinalArea"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_postrhinalAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_postrhinalAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_postrhinalAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_postrhinalAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_postrhinalAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_postrhinalAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorCingulateArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorCingulateAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorCingulateAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorCingulateAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorCingulateAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorCingulateAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorCingulateAreaDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorCingulateAreaDorsalPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorCingulateAreaDorsalPartLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorCingulateAreaDorsalPartLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorCingulateAreaDorsalPartLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorCingulateAreaDorsalPartLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorCingulateAreaVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorCingulateAreaVentralPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorCingulateAreaVentralPartLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorCingulateAreaVentralPartLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorCingulateAreaVentralPart6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorCingulateAreaVentralPart6b"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_prelimbicArea"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_prelimbicAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_prelimbicAreaLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_prelimbicAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_prelimbicAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_prelimbicAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_prelimbicAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_infralimbicArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_infralimbicAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_infralimbicAreaLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_infralimbicAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_infralimbicAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_infralimbicAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_infralimbicAreaLayer6b"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_orbitalArea"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_orbitalAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_orbitalAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_orbitalAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_orbitalAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_orbitalAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_orbitalAreaLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_orbitalAreaLateralPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_orbitalAreaLateralPartLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_orbitalAreaLateralPartLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_orbitalAreaLateralPartLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_orbitalAreaLateralPartLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_orbitalAreaMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_orbitalAreaMedialPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_orbitalAreaMedialPartLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_orbitalAreaMedialPartLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_orbitalAreaMedialPartLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_orbitalAreaMedialPartLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_orbitalAreaMedialPartLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_orbitalAreaVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_orbitalAreaVentrolateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_orbitalAreaVentrolateralPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_orbitalAreaVentrolateralPartLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_orbitalAreaVentrolateralPartLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_orbitalAreaVentrolateralPartLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_orbitalAreaVentrolateralPartLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_agranularInsularArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_agranularInsularAreaDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_agranularInsularAreaDorsalPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_agranularInsularAreaDorsalPartLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_agranularInsularAreaDorsalPartLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_agranularInsularAreaDorsalPartLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_agranularInsularAreaDorsalPartLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_agranularInsularAreaPosteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_agranularInsularAreaPosteriorPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_agranularInsularAreaPosteriorPartLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_agranularInsularAreaPosteriorPartLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_agranularInsularAreaPosteriorPartLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_agranularInsularAreaPosteriorPartLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_agranularInsularAreaVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_agranularInsularAreaVentralPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_agranularInsularAreaVentralPartLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_agranularInsularAreaVentralPartLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_agranularInsularAreaVentralPartLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_agranularInsularAreaVentralPartLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retrosplenialArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retrosplenialAreaLateralAgranularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retrosplenialAreaLateralAgranularPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retrosplenialAreaLateralAgranularPartLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retrosplenialAreaLateralAgranularPartLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retrosplenialAreaLateralAgranularPartLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retrosplenialAreaLateralAgranularPartLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mediomedialAnteriorVisualArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mediomedialAnteriorVisualAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mediomedialAnteriorVisualAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mediomedialAnteriorVisualAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mediomedialAnteriorVisualArealayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mediomedialAnteriorVisualAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mediomedialAnteriorVisualAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mediomedialPosteriorVisualArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mediomedialPosteriorVisualAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mediomedialPosteriorVisualAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mediomedialPosteriorVisualAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mediomedialPosteriorVisualArealayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mediomedialPosteriorVisualAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mediomedialPosteriorVisualAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialVisualArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialVisualAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialVisualAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialVisualAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialVisualArealayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialVisualAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialVisualAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retrosplenialAreaDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retrosplenialAreaDorsalPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retrosplenialAreaDorsalPartLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retrosplenialAreaDorsalPartLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retrosplenialAreaDorsalPartLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retrosplenialAreaDorsalPartLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retrosplenialAreaDorsalPartLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retrosplenialAreaVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retrosplenialAreaVentralPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retrosplenialAreaVentralPartLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retrosplenialAreaVentralPartLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retrosplenialAreaVentralPartLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retrosplenialAreaVentralPartLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retrosplenialAreaVentralPartLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteriorParietalAssociationAreas"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteriorParietalAssociationAreasLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteriorParietalAssociationAreasLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteriorParietalAssociationAreasLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteriorParietalAssociationAreasLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteriorParietalAssociationAreasLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteriorParietalAssociationAreasLayer6b"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorArea"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_rostrolateralVisualArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_rostrolateralAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_rostrolateralAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_rostrolateralAreaLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_rostrolateralAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_rostrolateralAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_rostrolateralAreaLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_temporalAssociationAreas"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_temporalAssociationAreasLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_temporalAssociationAreasLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_temporalAssociationAreasLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_temporalAssociationAreasLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_temporalAssociationAreasLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_temporalAssociationAreasLayer6b"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_perirhinalArea"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_perirhinalAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_perirhinalAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_perirhinalAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_perirhinalAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_perirhinalAreaLayer6b"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ectorhinalArea"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ectorhinalAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ectorhinalAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ectorhinalAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ectorhinalAreaLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ectorhinalAreaLayer6b"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_olfactoryAreas"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mainOlfactoryBulb"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mainOlfactoryBulbGlomerularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mainOlfactoryBulbGranuleLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mainOlfactoryBulbInnerPlexiformLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mainOlfactoryBulbMitralLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mainOlfactoryBulbOuterPlexiformLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_accessoryOlfactoryBulb"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_accessoryOlfactoryBulbGlomerularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_accessoryOlfactoryBulbGranularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_accessoryOlfactoryBulbMitralLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorOlfactoryNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorOlfactoryNucleusDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorOlfactoryNucleusExternalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorOlfactoryNucleusLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorOlfactoryNucleusMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorOlfactoryNucleusPosteroventralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorOlfactoryNucleusLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorOlfactoryNucleusLayer2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_taeniaTecta"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_taeniaTectaDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_taeniaTectaDorsalPartLayers14"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_taeniaTectaDorsalPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_taeniaTectaDorsalPartLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_taeniaTectaDorsalPartLayer3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_taeniaTectaDorsalPartLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_taeniaTectaVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_taeniaTectaVentralPartLayers13"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_taeniaTectaVentralPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_taeniaTectaVentralPartLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_taeniaTectaVentralPartLayer3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalPeduncularArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalPeduncularAreaLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalPeduncularAreaLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalPeduncularAreaLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalPeduncularAreaLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalPeduncularAreaLayer6a"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_piriformArea"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_piriformAreaLayers13"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_piriformAreaMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_piriformAreaPyramidalLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_piriformAreaPolymorphLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusOfTheLateralOlfactoryTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusOfTheLateralOlfactoryTractLayers13"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusOfTheLateralOlfactoryTractMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusOfTheLateralOlfactoryTractPyramidalLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusOfTheLateralOlfactoryTractLayer3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corticalAmygdalarArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corticalAmygdalarAreaAnteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corticalAmygdalarAreaAnteriorPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corticalAmygdalarAreaAnteriorPartLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corticalAmygdalarAreaAnteriorPartLayer3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corticalAmygdalarAreaPosteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corticalAmygdalarAreaPosteriorPartLateralZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corticalAmygdalarAreaPosteriorPartLateralZoneLayers12"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corticalAmygdalarAreaPosteriorPartLateralZoneLayers13"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corticalAmygdalarAreaPosteriorPartLateralZoneLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corticalAmygdalarAreaPosteriorPartLateralZoneLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corticalAmygdalarAreaPosteriorPartLateralZoneLayer3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corticalAmygdalarAreaPosteriorPartMedialZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corticalAmygdalarAreaPosteriorPartMedialZoneLayers12"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corticalAmygdalarAreaPosteriorPartMedialZoneLayers13"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corticalAmygdalarAreaPosteriorPartMedialZoneLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corticalAmygdalarAreaPosteriorPartMedialZoneLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corticalAmygdalarAreaPosteriorPartMedialZoneLayer3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_piriformamygdalarArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_piriformamygdalarAreaLayers13"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_piriformamygdalarAreaMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_piriformamygdalarAreaPyramidalLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_piriformamygdalarAreaPolymorphLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_postpiriformTransitionArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_postpiriformTransitionAreaLayers13"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_postpiriformTransitionAreaLayers1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_postpiriformTransitionAreaLayers2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_postpiriformTransitionAreaLayers3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_hippocampalFormation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_hippocampalRegion"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ammonsHorn"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_fieldCA1"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_fieldCA1StratumLacunosummoleculare"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_fieldCA1StratumOriens"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_fieldCA1PyramidalLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_fieldCA1StratumRadiatum"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_fieldCA2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_fieldCA2StratumLacunosummoleculare"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_fieldCA2StratumOriens"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_fieldCA2PyramidalLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_fieldCA2StratumRadiatum"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_fieldCA3"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_fieldCA3StratumLacunosummoleculare"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_fieldCA3StratumLucidum"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_fieldCA3StratumOriens"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_fieldCA3PyramidalLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_fieldCA3StratumRadiatum"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dentateGyrus"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dentateGyrusMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dentateGyrusPolymorphLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dentateGyrusGranuleCellLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dentateGyrusSubgranularZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dentateGyrusCrest"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dentateGyrusCrestMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dentateGyrusCrestPolymorphLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dentateGyrusCrestGranuleCellLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dentateGyrusLateralBlade"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dentateGyrusLateralBladeMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dentateGyrusLateralBladePolymorphLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dentateGyrusLateralBladeGranuleCellLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dentateGyrusMedialBlade"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dentateGyrusMedialBladeMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dentateGyrusMedialBladePolymorphLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dentateGyrusMedialBladeGranuleCellLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_fasciolaCinerea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_induseumGriseum"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retrohippocampalRegion"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalArea"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaLateralPartLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaLateralPartLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaLateralPartLayer2-3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaLateralPartLayer2a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaLateralPartLayer2b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaLateralPartLayer3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaLateralPartLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaLateralPartLayer4-5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaLateralPartLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaLateralPartLayer5-6"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaLateralPartLayer6a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaLateralPartLayer6b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaMedialPartDorsalZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaMedialPartDorsalZoneLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaMedialPartDorsalZoneLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaMedialPartDorsalZoneLayer2a"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaMedialPartDorsalZoneLayer2b"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaMedialPartDorsalZoneLayer3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaMedialPartDorsalZoneLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaMedialPartDorsalZoneLayer5"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaMedialPartDorsalZoneLayer5-6"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaMedialPartDorsalZoneLayer6"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaMedialPartVentralZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaMedialPartVentralZoneLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaMedialPartVentralZoneLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaMedialPartVentralZoneLayer3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaMedialPartVentralZoneLayer4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_entorhinalAreaMedialPartVentralZoneLayer5-6"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_parasubiculum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_parasubiculumLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_parasubiculumLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_parasubiculumLayer3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_postsubiculum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_postsubiculumLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_postsubiculumLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_postsubiculumLayer3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_presubiculum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_presubiculumLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_presubiculumLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_presubiculumLayer3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_subiculum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_subiculumDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_subiculumDorsalPartMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_subiculumDorsalPartPyramidalLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_subiculumDorsalPartStratumRadiatum"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_subiculumVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_subiculumVentralPartMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_subiculumVentralPartPyramidalLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_subiculumVentralPartStratumRadiatum"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_prosubiculum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_prosubiculumDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_prosubiculumDorsalPartMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_prosubiculumDorsalPartPyramidalLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_prosubiculumDorsalPartStratumRadiatum"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_prosubiculumVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_prosubiculumVentralPartMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_prosubiculumVentralPartPyramidalLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_prosubiculumVentralPartStratumRadiatum"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_hippocampoamygdalarTransitionArea"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_areaProstriata"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corticalSubplate"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_layer6bIsocortex"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_claustrum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_endopiriformNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_endopiriformNucleusDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_endopiriformNucleusVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralAmygdalarNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_basolateralAmygdalarNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_basolateralAmygdalarNucleusAnteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_basolateralAmygdalarNucleusPosteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_basolateralAmygdalarNucleusVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_basomedialAmygdalarNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_basomedialAmygdalarNucleusAnteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_basomedialAmygdalarNucleusPosteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteriorAmygdalarNucleus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_cerebralNuclei"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_striatum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_striatumDorsalRegion"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_caudoputamen"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_striatumVentralRegion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusAccumbens"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_fundusOfStriatum"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_olfactoryTubercle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_islandsOfCalleja"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_majorIslandOfCalleja"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_olfactoryTubercleLayers13"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_olfactoryTubercleMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_olfactoryTuberclePyramidalLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_olfactoryTuberclePolymorphLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralStripOfStriatum"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralSeptalComplex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralSeptalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralSeptalNucleusCaudalCaudodorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralSeptalNucleusRostralRostroventralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralSeptalNucleusVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_septofimbrialNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_septohippocampalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_striatumlikeAmygdalarNuclei"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorAmygdalarArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_bedNucleusOfTheAccessoryOlfactoryTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_centralAmygdalarNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_centralAmygdalarNucleusCapsularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_centralAmygdalarNucleusLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_centralAmygdalarNucleusMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_intercalatedAmygdalarNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialAmygdalarNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialAmygdalarNucleusAnterodorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialAmygdalarNucleusAnteroventralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialAmygdalarNucleusPosterodorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialAmygdalarNucleusPosterodorsalPartSublayerA"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialAmygdalarNucleusPosterodorsalPartSublayerB"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialAmygdalarNucleusPosterodorsalPartSublayerC"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialAmygdalarNucleusPosteroventralPart"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_pallidum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_pallidumDorsalRegion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_globusPallidusExternalSegment"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_globusPallidusInternalSegment"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_pallidumVentralRegion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_substantiaInnominata"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_magnocellularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_pallidumMedialRegion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialSeptalComplex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialSeptalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_diagonalBandNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_triangularNucleusOfSeptum"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_pallidumCaudalRegion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_bedNucleiOfTheStriaTerminalis"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_bedNucleiOfTheStriaTerminalisAnteriorDivision"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_bedNucleiOfTheStriaTerminalisAnteriorDivisionAnterolateralArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_bedNucleiOfTheStriaTerminalisAnteriorDivisionAnteromedialArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_bedNucleiOfTheStriaTerminalisAnteriorDivisionDorsomedialNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_bedNucleiOfTheStriaTerminalisAnteriorDivisionFusiformNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_bedNucleiOfTheStriaTerminalisAnteriorDivisionJuxtacapsularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_bedNucleiOfTheStriaTerminalisAnteriorDivisionMagnocellularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_bedNucleiOfTheStriaTerminalisAnteriorDivisionOvalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_bedNucleiOfTheStriaTerminalisAnteriorDivisionRhomboidNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_bedNucleiOfTheStriaTerminalisAnteriorDivisionVentralNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_bedNucleiOfTheStriaTerminalisPosteriorDivision"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_bedNucleiOfTheStriaTerminalisPosteriorDivisionDorsalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_bedNucleiOfTheStriaTerminalisPosteriorDivisionPrincipalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_bedNucleiOfTheStriaTerminalisPosteriorDivisionInterfascicularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_bedNucleiOfTheStriaTerminalisPosteriorDivisionTransverseNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_bedNucleiOfTheStriaTerminalisPosteriorDivisionStrialExtension"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_bedNucleusOfTheAnteriorCommissure"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_brainStem"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_interbrain"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_thalamus"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_thalamusSensorymotorCortexRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventralGroupOfTheDorsalThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventralAnteriorlateralComplexOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventralMedialNucleusOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventralPosteriorComplexOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventralPosterolateralNucleusOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventralPosterolateralNucleusOfTheThalamusParvicellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventralPosteromedialNucleusOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventralPosteromedialNucleusOfTheThalamusParvicellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteriorTriangularThalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_subparafascicularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_subparafascicularNucleusMagnocellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_subparafascicularNucleusParvicellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_subparafascicularArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_peripeduncularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_geniculateGroupDorsalThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialGeniculateComplex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialGeniculateComplexDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialGeniculateComplexVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialGeniculateComplexMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalPartOfTheLateralGeniculateComplex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalPartOfTheLateralGeniculateComplexShell"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalPartOfTheLateralGeniculateComplexCore"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalPartOfTheLateralGeniculateComplexIpsilateralZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_thalamusPolymodalAssociationCortexRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralGroupOfTheDorsalThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralPosteriorNucleusOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteriorComplexOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteriorLimitingNucleusOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_suprageniculateNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ethmoidNucleusOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retroethmoidNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorGroupOfTheDorsalThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteroventralNucleusOfThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteromedialNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteromedialNucleusDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteromedialNucleusVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anterodorsalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_interanteromedialNucleusOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_interanterodorsalNucleusOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralDorsalNucleusOfThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialGroupOfTheDorsalThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_intermediodorsalNucleusOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mediodorsalNucleusOfThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mediodorsalNucleusOfTheThalamusCentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mediodorsalNucleusOfTheThalamusLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mediodorsalNucleusOfTheThalamusMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_submedialNucleusOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_perireunensisNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_midlineGroupOfTheDorsalThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paraventricularNucleusOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_parataenialNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusOfReuniens"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_xiphoidThalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_intralaminarNucleiOfTheDorsalThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_rhomboidNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_centralMedialNucleusOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paracentralNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_centralLateralNucleusOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_parafascicularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteriorIntralaminarThalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_reticularNucleusOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_geniculateGroupVentralThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_intergeniculateLeafletOfTheLateralGeniculateComplex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_intermediateGeniculateNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventralPartOfTheLateralGeniculateComplex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventralPartOfTheLateralGeniculateComplexLateralZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventralPartOfTheLateralGeniculateComplexMedialZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_subgeniculateNucleus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_epithalamus"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialHabenula"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralHabenula"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_pinealBody"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_hypothalamus"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_periventricularZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_supraopticNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_accessorySupraopticGroup"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusCircularis"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paraventricularHypothalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paraventricularHypothalamicNucleusMagnocellularDivision"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paraventricularHypothalamicNucleusMagnocellularDivisionAnteriorMagnocellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paraventricularHypothalamicNucleusMagnocellularDivisionMedialMagnocellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paraventricularHypothalamicNucleusMagnocellularDivisionPosteriorMagnocellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paraventricularHypothalamicNucleusMagnocellularDivisionPosteriorMagnocellularPartLateralZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paraventricularHypothalamicNucleusMagnocellularDivisionPosteriorMagnocellularPartMedialZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paraventricularHypothalamicNucleusParvicellularDivision"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paraventricularHypothalamicNucleusParvicellularDivisionAnteriorParvicellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paraventricularHypothalamicNucleusParvicellularDivisionMedialParvicellularPartDorsalZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paraventricularHypothalamicNucleusParvicellularDivisionPeriventricularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_periventricularHypothalamicNucleusAnteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_periventricularHypothalamicNucleusIntermediatePart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_arcuateHypothalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_periventricularRegion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anterodorsalPreopticNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorHypothalamicArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteroventralPreopticNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteroventralPeriventricularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsomedialNucleusOfTheHypothalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsomedialNucleusOfTheHypothalamusAnteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsomedialNucleusOfTheHypothalamusPosteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsomedialNucleusOfTheHypothalamusVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medianPreopticNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialPreopticArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_vascularOrganOfTheLaminaTerminalis"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posterodorsalPreopticNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_parastrialNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_suprachiasmaticPreopticNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_periventricularHypothalamicNucleusPosteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_periventricularHypothalamicNucleusPreopticPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_subparaventricularZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_suprachiasmaticNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_subfornicalOrgan"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventromedialPreopticNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventrolateralPreopticNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_hypothalamicMedialZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorHypothalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorHypothalamicNucleusAnteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorHypothalamicNucleusCentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorHypothalamicNucleusDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorHypothalamicNucleusPosteriorPart"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mammillaryBody"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralMammillaryNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialMammillaryNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialMammillaryNucleusMedianPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialMammillaryNucleusLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialMammillaryNucleusMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialMammillaryNucleusPosteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialMammillaryNucleusDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_supramammillaryNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_supramammillaryNucleusLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_supramammillaryNucleusMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_tuberomammillaryNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_tuberomammillaryNucleusDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_tuberomammillaryNucleusVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialPreopticNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialPreopticNucleusCentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialPreopticNucleusLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialPreopticNucleusMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalPremammillaryNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventralPremammillaryNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paraventricularHypothalamicNucleusDescendingDivision"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paraventricularHypothalamicNucleusDescendingDivisionDorsalParvicellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paraventricularHypothalamicNucleusDescendingDivisionFornicealPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paraventricularHypothalamicNucleusDescendingDivisionLateralParvicellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paraventricularHypothalamicNucleusDescendingDivisionMedialParvicellularPartVentralZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventromedialHypothalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventromedialHypothalamicNucleusAnteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventromedialHypothalamicNucleusCentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventromedialHypothalamicNucleusDorsomedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventromedialHypothalamicNucleusVentrolateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteriorHypothalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_hypothalamicLateralZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralHypothalamicArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralPreopticArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_preparasubthalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_parasubthalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_perifornicalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retrochiasmaticArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_subthalamicNucleus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_tuberalNucleus"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_zonaIncerta"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dopaminergicA13Group"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_fieldsOfForel"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medianEminence"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_midbrain"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_midbrainSensoryRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_superiorColliculusSensoryRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_superiorColliculusOpticLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_superiorColliculusSuperficialGrayLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_superiorColliculusZonalLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_inferiorColliculus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_inferiorColliculusCentralNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_inferiorColliculusDorsalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_inferiorColliculusExternalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusOfTheBrachiumOfTheInferiorColliculus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusSagulum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_parabigeminalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_midbrainTrigeminalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_subcommissuralOrgan"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_midbrainMotorRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_substantiaNigraReticularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventralTegmentalArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paranigralNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_midbrainReticularNucleusRetrorubralArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_midbrainReticularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_midbrainReticularNucleusMagnocellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_midbrainReticularNucleusMagnocellularPartGeneral"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_midbrainReticularNucleusParvicellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_superiorColliculusMotorRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_superiorColliculusMotorRelatedDeepGrayLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_superiorColliculusMotorRelatedDeepWhiteLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_superiorColliculusMotorRelatedIntermediateWhiteLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_superiorColliculusMotorRelatedIntermediateGrayLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_superiorColliculusMotorRelatedIntermediateGrayLayerSublayerA"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_superiorColliculusMotorRelatedIntermediateGrayLayerSublayerB"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_superiorColliculusMotorRelatedIntermediateGrayLayerSublayerC"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_periaqueductalGray"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_precommissuralNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_interstitialNucleusOfCajal"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusOfDarkschewitsch"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_supraoculomotorPeriaqueductalGray"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_pretectalRegion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorPretectalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialPretectalArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusOfTheOpticTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusOfThePosteriorCommissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_olivaryPretectalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteriorPretectalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retroparafascicularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_intercollicularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_cuneiformNucleus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_redNucleus"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_oculomotorNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialAccesoryOculomotorNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_edingerWestphalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_trochlearNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paratrochlearNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventralTegmentalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorTegmentalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralTerminalNucleusOfTheAccessoryOpticTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalTerminalNucleusOfTheAccessoryOpticTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialTerminalNucleusOfTheAccessoryOpticTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_substantiaNigraLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_midbrainBehavioralStateRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_substantiaNigraCompactPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_pedunculopontineNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_midbrainRapheNuclei"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_interfascicularNucleusRaphe"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_interpeduncularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_interpeduncularNucleusRostral"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_interpeduncularNucleusCaudal"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_interpeduncularNucleusApical"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_interpeduncularNucleusLateral"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_interpeduncularNucleusIntermediate"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_interpeduncularNucleusDorsomedial"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_interpeduncularNucleusDorsolateral"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_interpeduncularNucleusRostrolateral"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_rostralLinearNucleusRaphe"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_centralLinearNucleusRaphe"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalNucleusRaphe"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_hindbrain"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_pons"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ponsSensoryRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusOfTheLateralLemniscus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusOfTheLateralLemniscusDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusOfTheLateralLemniscusHorizontalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusOfTheLateralLemniscusVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_principalSensoryNucleusOfTheTrigeminal"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_parabrachialNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_koellikerFuseSubnucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_parabrachialNucleusLateralDivision"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_parabrachialNucleusLateralDivisionCentralLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_parabrachialNucleusLateralDivisionDorsalLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_parabrachialNucleusLateralDivisionExternalLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_parabrachialNucleusLateralDivisionSuperiorLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_parabrachialNucleusLateralDivisionVentralLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_parabrachialNucleusMedialDivision"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_parabrachialNucleusMedialDivisionExternalMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_parabrachialNucleusMedialDivisionMedialMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_parabrachialNucleusMedialDivisionVentralMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_superiorOlivaryComplex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_superiorOlivaryComplexPeriolivaryRegion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_superiorOlivaryComplexMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_superiorOlivaryComplexLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ponsMotorRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_barringtonsNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalTegmentalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralTegmentalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posterodorsalTegmentalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_pontineCentralGray"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_pontineGray"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_pontineReticularNucleusCaudalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_pontineReticularNucleusVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_supragenualNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_superiorSalivatoryNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_supratrigeminalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_tegmentalReticularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_motorNucleusOfTrigeminal"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_peritrigeminalZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_accessoryTrigeminalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_parvicellularMotor5Nucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_intertrigeminalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ponsBehavioralStateRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_superiorCentralNucleusRaphe"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_superiorCentralNucleusRapheLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_superiorCentralNucleusRapheMedialPart"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_locusCeruleus"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_laterodorsalTegmentalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusIncertus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_pontineReticularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusRaphePontis"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_subceruleusNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_sublaterodorsalNucleus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medulla"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medullaSensoryRelated"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_areaPostrema"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_cochlearNuclei"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_granularLaminaOfTheCochlearNuclei"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_cochlearNucleusSubpedunclularGranularRegion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalCochlearNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventralCochlearNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalColumnNuclei"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_cuneateNucleus"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_gracileNucleus"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_externalCuneateNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusOfTheTrapezoidBody"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusOfTheSolitaryTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusOfTheSolitaryTractCentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusOfTheSolitaryTractCommissuralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusOfTheSolitaryTractGelatinousPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusOfTheSolitaryTractLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusOfTheSolitaryTractMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_spinalNucleusOfTheTrigeminalCaudalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_spinalNucleusOfTheTrigeminalInterpolarPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_spinalNucleusOfTheTrigeminalOralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_spinalNucleusOfTheTrigeminalOralPartCaudalDorsomedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_spinalNucleusOfTheTrigeminalOralPartMiddleDorsomedialPartDorsalZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_spinalNucleusOfTheTrigeminalOralPartMiddleDorsomedialPartVentralZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_spinalNucleusOfTheTrigeminalOralPartRostralDorsomedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_spinalNucleusOfTheTrigeminalOralPartVentrolateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paratrigeminalNucleus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusZ"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medullaMotorRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_abducensNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_accessoryAbducensNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_facialMotorNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_accessoryFacialMotorNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_efferentVestibularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusAmbiguus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusAmbiguusDorsalDivision"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusAmbiguusVentralDivision"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalMotorNucleusOfTheVagusNerve"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_efferentCochlearGroup"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_gigantocellularReticularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_infracerebellarNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_inferiorOlivaryComplex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_intermediateReticularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_inferiorSalivatoryNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_linearNucleusOfTheMedulla"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralReticularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralReticularNucleusMagnocellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralReticularNucleusParvicellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_magnocellularReticularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medullaryReticularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medullaryReticularNucleusDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medullaryReticularNucleusVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_parvicellularReticularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_parasolitaryNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paragigantocellularReticularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paragigantocellularReticularNucleusDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paragigantocellularReticularNucleusLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_perihypoglossalNuclei"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusIntercalatus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusOfRoller"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusPrepositus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paramedianReticularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_parapyramidalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_parapyramidalNucleusDeepPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_parapyramidalNucleusSuperficialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_vestibularNuclei"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralVestibularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialVestibularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_spinalVestibularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_superiorVestibularNucleus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusX"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_hypoglossalNucleus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusY"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_interstitialNucleusOfTheVestibularNerve"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medullaBehavioralStateRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusRapheMagnus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusRaphePallidus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nucleusRapheObscurus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_cerebellum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_cerebellarCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_cerebellarCortexMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_cerebellarCortexPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_cerebellarCortexGranularLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_vermalRegions"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lingulaI"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lingulaIMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lingulaIPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lingulaIGranularLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_centralLobule"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lobuleII"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lobuleIIMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lobuleIIPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lobuleIIGranularLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lobuleIII"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lobuleIIIMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lobuleIIIPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lobuleIIIGranularLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_culmen"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lobuleIV"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lobuleIVMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lobuleIVPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lobuleIVGranularLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lobuleV"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lobuleVMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lobuleVPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lobuleVGranularLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lobulesIV-V"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lobulesIV-VMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lobulesIV-VPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lobulesIV-VGranularLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_decliveVI"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_decliveVIMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_decliveVIPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_decliveVIGranularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_foliumtuberVermisVII"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_foliumtuberVermisVIIMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_foliumtuberVermisVIIPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_foliumtuberVermisVIIGranularLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_pyramusVIII"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_pyramusVIIIMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_pyramusVIIIPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_pyramusVIIIGranularLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_uvulaIX"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_uvulaIXMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_uvulaIXPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_uvulaIXGranularLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nodulusX"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nodulusXMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nodulusXPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nodulusXGranularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_hemisphericRegions"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_simpleLobule"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_simpleLobuleMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_simpleLobulePurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_simpleLobuleGranularLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ansiformLobule"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_crus1"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_crus1MolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_crus1PurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_crus1GranularLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_crus2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_crus2MolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_crus2PurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_crus2GranularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paramedianLobule"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paramedianLobuleMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paramedianLobulePurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paramedianLobuleGranularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_copulaPyramidis"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_copulaPyramidisMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_copulaPyramidisPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_copulaPyramidisGranularLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paraflocculus"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paraflocculusMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paraflocculusPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paraflocculusGranularLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_flocculus"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_flocculusMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_flocculusPurkinjeLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_flocculusGranularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_cerebellarNuclei"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_fastigialNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_interposedNucleus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dentateNucleus"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_vestibulocerebellarNucleus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_fiberTracts"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_cranialNerves"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_terminalNerve"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_vomeronasalNerve"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_olfactoryNerve"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_olfactoryNerveLayerOfMainOlfactoryBulb"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralOlfactoryTractGeneral"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralOlfactoryTractBody"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalLimb"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_accessoryOlfactoryTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorCommissureOlfactoryLimb"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_opticNerve"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_accessoryOpticTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_brachiumOfTheSuperiorColliculus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_superiorColliculusCommissure"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_opticChiasm"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_opticTract"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_tectothalamicPathway"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_oculomotorNerve"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialLongitudinalFascicle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteriorCommissure"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_trochlearNerve"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_trochlearNerveDecussation"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_abducensNerve"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_trigeminalNerve"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_motorRootOfTheTrigeminalNerve"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_sensoryRootOfTheTrigeminalNerve"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_midbrainTractOfTheTrigeminalNerve"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_spinalTractOfTheTrigeminalNerve"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_facialNerve"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_intermediateNerve"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_genuOfTheFacialNerve"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_vestibulocochlearNerve"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_efferentCochleovestibularBundle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_vestibularNerve"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_cochlearNerve"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_trapezoidBody"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_intermediateAcousticStria"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalAcousticStria"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralLemniscus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_inferiorColliculusCommissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_brachiumOfTheInferiorColliculus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_glossopharyngealNerve"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_vagusNerve"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_solitaryTract"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_accessorySpinalNerve"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_hypoglossalNerve"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventralRoots"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalRoots"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_cervicothalamicTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsolateralFascicle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalCommissureOfTheSpinalCord"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventralCommissureOfTheSpinalCord"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_fasciculusProprius"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalColumn"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_cuneateFascicle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_gracileFascicle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_internalArcuateFibers"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialLemniscus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_spinothalamicTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralSpinothalamicTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventralSpinothalamicTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_spinocervicalTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_spinoolivaryPathway"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_spinoreticularPathway"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_spinovestibularPathway"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_spinotectalPathway"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_spinohypothalamicPathway"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_spinotelenchephalicPathway"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_hypothalamohypophysialTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_cerebellumRelatedFiberTracts"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_cerebellarCommissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_cerebellarPeduncles"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_superiorCerebelarPeduncles"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_superiorCerebellarPeduncleDecussation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_spinocerebellarTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_uncinateFascicle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventralSpinocerebellarTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_middleCerebellarPeduncle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_inferiorCerebellarPeduncle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalSpinocerebellarTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_cuneocerebellarTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_juxtarestiformBody"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_bulbocerebellarTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_olivocerebellarTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_reticulocerebellarTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_trigeminocerebellarTract"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_arborVitae"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_supracallosalCerebralWhiteMatter"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralForebrainBundleSystem"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corpusCallosum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corpusCallosumAnteriorForceps"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_externalCapsule"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corpusCallosumExtremeCapsule"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_genuOfCorpusCallosum"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corpusCallosumPosteriorForceps"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corpusCallosumRostrum"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corpusCallosumBody"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corpusCallosumSplenium"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corticospinalTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_internalCapsule"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_cerebalPeduncle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corticotectalTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corticorubralTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corticopontineTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corticobulbarTract"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_pyramid"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_pyramidalDecussation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corticospinalTractCrossed"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_corticospinalTractUncrossed"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_thalamusRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_externalMedullaryLaminaOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_internalMedullaryLaminaOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_middleThalamicCommissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_thalamicPeduncles"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_opticRadiation"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_auditoryRadiation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_extrapyramidalFiberSystems"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_cerebralNucleiRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_pallidothalamicPathway"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nigrostriatalTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nigrothalamicFibers"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_pallidotegmentalFascicle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_striatonigralPathway"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_subthalamicFascicle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_tectospinalPathway"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_directTectospinalPathway"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_doralTegmentalDecussation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_crossedTectospinalPathway"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_rubrospinalTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventralTegmentalDecussation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_rubroreticularTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_centralTegmentalBundle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retriculospinalTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retriculospinalTractLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retriculospinalTractMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_vestibulospinalPathway"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialForebrainBundleSystem"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_cerebrumRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_amygdalarCapsule"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ansaPeduncularis"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_anteriorCommissureTemporalLimb"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_cingulumBundle"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_fornixSystem"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_alveus"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalFornix"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_fimbria"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_precommissuralFornixGeneral"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_precommissuralFornixDiagonalBand"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_postcommissuralFornix"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialCorticohypothalamicTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_columnsOfTheFornix"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_hippocampalCommissures"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalHippocampalCommissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventralHippocampalCommissure"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_perforantPath"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_angularPath"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_longitudinalAssociationBundle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_striaTerminalis"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_commissuralBranchOfStriaTerminalis"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_hypothalamusRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_medialForebrainBundle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventrolateralHypothalamicTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_preopticCommissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_supraopticCommissures"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_supraopticCommissuresAnterior"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_supraopticCommissuresDorsal"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_supraopticCommissuresVentral"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_premammillaryCommissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_supramammillaryDecussation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_propriohypothalamicPathways"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_propriohypothalamicPathwaysDorsal"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_propriohypothalamicPathwaysLateral"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_propriohypothalamicPathwaysMedial"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_propriohypothalamicPathwaysVentral"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_periventricularBundleOfTheHypothalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mammillaryRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_principalMammillaryTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mammillothalamicTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mammillotegmentalTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_mammillaryPeduncle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalThalamusRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_periventricularBundleOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_epithalamusRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_striaMedullaris"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_fasciculusRetroflexus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_habenularCommissure"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_pinealStalk"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_midbrainRelated"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalLongitudinalFascicle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_dorsalTegmentalTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ventricularSystems"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralVentricle"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_rhinocele"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_subependymalZone"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_choroidPlexus"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_choroidFissure"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_interventricularForamen"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_thirdVentricle"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_cerebralAqueduct"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_fourthVentricle"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_lateralRecess"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_centralCanalSpinalCordmedulla"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_grooves"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_groovesOfTheCerebralCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_endorhinalGroove"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_hippocampalFissure"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_rhinalFissure"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_rhinalIncisure"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_groovesOfTheCerebellarCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_precentralFissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_preculminateFissure"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_primaryFissure"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posteriorSuperiorFissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_prepyramidalFissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_secondaryFissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_posterolateralFissure"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_nodularFissure"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_simpleFissure"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_intercruralFissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_ansoparamedianFissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_intraparafloccularFissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_paramedianSulcus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_parafloccularSulcus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_interpeduncularFossa"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/AMBA_CCFv3-2017_retina"},
        ],
        "ontologyIdentifier": None,
    },
    short_name="Allen Mouse Brain Atlas",
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/deterministicAtlas"},
    version_identifier="CCFv3, 2017",
)
BrainAtlasVersion.ba_human_1909 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/BA-human_1909",
    abbreviation="BA-human",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    full_name="Brodmann Cortical Parcellation Scheme (human)",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA3"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA4"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA5"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA6"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA7"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA8"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA8a"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA9"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA10"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA11"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA12"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA13"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA14"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA15"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA16"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA17"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA18"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA19"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA20"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA21"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA22"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA23"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA24"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA25"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA26"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA27"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA28"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA29"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA30"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA31"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA32"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA33"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA34"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA35"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA36"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA37"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA38"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA39"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA40"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA41"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA42"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA43"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA44"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA45"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA46"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA47"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA48"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_BA52"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/BA-human_1909_cerebralCortex"},
        ],
        "ontologyIdentifier": None,
    },
    ontology_identifier=IRI("http://uri.interlex.org/base/ilx_0101468"),
    short_name="Brodmann Areas (human)",
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/parcellationScheme"},
    version_identifier="1909",
    version_innovation="This is the second released version of the human Brodmann cortical parcellation scheme.",
)
BrainAtlasVersion.dwma_2018 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/DWMA_2018",
    abbreviation="DWMA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={
        "@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/MNI-ICBM152_nonlinear-2009c-asym"
    },
    full_name="Atlas of Deep White Matter Fibre Bundles",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/DWMA_2018_anteriorSegementOfArcuateFasciculus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/DWMA_2018_corticospinalTract"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/DWMA_2018_directSegementOfArcuateFasciculus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/DWMA_2018_fornix"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/DWMA_2018_inferiorFronto-occipitalFasciculus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/DWMA_2018_inferiorLongitudinalFasciculus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/DWMA_2018_longCingulateFibres"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/DWMA_2018_posteriorSegementOfArcuateFasciculus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/DWMA_2018_shortCingulateFibres"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/DWMA_2018_temporalCingulateFibres"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/DWMA_2018_uncinateFasciculus"},
        ],
        "ontologyIdentifier": None,
    },
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    short_name="Deep White Matter Atlas",
    version_identifier="2018",
    version_innovation="This is the first released version of this brain atlas.",
)
BrainAtlasVersion.jba_v1_13__colin27 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v1.13-Colin27",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpace/MNI-Colin27_1998"},
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-1_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-25_PM-v16.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-33_PM-v16.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-3a_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-3b_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-44_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-45_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-4a_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-4p_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-5Ci_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-5L_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-5M_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-7A_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-7M_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-7P_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-7PC_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-FG1_PM-v1.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-FG2_PM-v1.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-FG3_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-FG4_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-Fo1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-Fo2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-Fo3_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-Fp1_PM-v2.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-Fp2_PM-v2.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-Id1_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-Ig1_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-Ig2_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-OP1_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-OP2_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-OP3_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-OP4_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-PF_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-PFcm_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-PFm_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-PFop_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-PFt_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-PGa_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-PGp_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-TE-1.0_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-TE-1.1_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-TE-1.2_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-TE-3_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-hIP1_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-hIP2_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-hIP3_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-hOc1_PM-v2.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-hOc2_PM-v2.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-hOc3d_PM-v2.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-hOc3v_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-hOc4d_PM-v2.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-hOc4la_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-hOc4lp_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-hOc4v_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-hOc5_PM-v2.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-s24_PM-v16.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Area-s32_PM-v16.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_CA1_PM-v11b.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_CA2_PM-v11b.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_CA3_PM-v11b.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_CM_PM-v6.1"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Ch-123_PM-v4.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Ch-4_PM-v4.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_DG_PM-v11b.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Dorsal-Dentate-Nucleus_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Entorhinal-Cortex_PM-v11b.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Fastigial-Nucleus_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_HATA_PM-v11b.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_IF_PM-v6.1"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Interposed-Nucleus_PM-v6.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_LB_PM-v6.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_MF_PM-v6.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_SF_PM-v6.1"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Subiculum_PM-v11b.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_VTM_PM-v6.1"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.13-Colin27_Ventral-Dentate-Nucleus_PM-v6.0"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2019)](https://doi.org/10.25493/Q3ZS-NV6).",
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v1.13",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/probabilisticAtlas"},
    version_identifier="v1.13, Colin27",
    version_innovation="This is the first release of the Julich-Brain Atlas using the common coordinate space Colin27 (1998).",
)
BrainAtlasVersion.jba_v1_18__colin27 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v1.18-Colin27",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/MNI-Colin27_1998"},
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-1_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-2_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-25_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-33_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-3a_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-3b_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-44_PM-v7.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-45_PM-v7.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-4a_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-4p_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-5Ci_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-5L_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-5M_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-6d1_PM-v4.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-6d2_PM-v4.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-6d3_PM-v4.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-6ma_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-6mp_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-7A_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-7M_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-7P_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-7PC_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-FG1_PM-v1.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-FG2_PM-v1.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-FG3_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-FG4_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-Fo1_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-Fo2_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-Fo3_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-Fo4_PM-v2.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-Fo5_PM-v2.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-Fo6_PM-v2.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-Fo7_PM-v2.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-Fp1_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-Fp2_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-Ia_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-Id1_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-Id2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-Id3_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-Id4_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-Id5_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-Id6_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-Id7_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-Ig1_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-Ig2_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-Ig3_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-OP1_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-OP2_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-OP3_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-OP4_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-OP8_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-OP9_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-PF_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-PFcm_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-PFm_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-PFop_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-PFt_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-PGa_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-PGp_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-STS1_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-STS2_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-TE-1.0_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-TE-1.1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-TE-1.2_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-TE-3_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-hIP1_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-hIP2_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-hIP3_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-hIP4_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-hIP5_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-hIP6_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-hIP7_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-hIP8_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-hOc1_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-hOc2_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-hOc3d_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-hOc3v_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-hOc4d_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-hOc4la_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-hOc4lp_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-hOc4v_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-hOc5_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-hOc6_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-hPO1_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-p24ab_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-p24c_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-p32_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-s24_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Area-s32_PM-v16.1"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_CA_PM-v11.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_CM_PM-v6.4"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Ch-123_PM-v4.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Ch-4_PM-v4.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_DG_PM-v11.1"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Dorsal-Dentate-Nucleus_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Entorhinal-Cortex_PM-v11.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Fastigial-Nucleus_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_HATA_PM-v11.1"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_IF_PM-v6.4"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Interposed-Nucleus_PM-v6.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_LB_PM-v6.4"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_MF_PM-v6.4"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_SF_PM-v6.4"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Subiculum_PM-v11.1"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_VTM_PM-v6.4"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-Colin27_Ventral-Dentate-Nucleus_PM-v6.2"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2019)](https://doi.org/10.25493/8EGG-ZAR).",
    is_alternative_version_of=[{"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v1.18-MNI152"}],
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v1.13-Colin27"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v1.18",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/probabilisticAtlas"},
    version_identifier="v1.18, Colin27",
)
BrainAtlasVersion.jba_v1_18_mni152 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v1.18-MNI152",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={
        "@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/MNI-ICBM152_nonlinear-2009c-asym"
    },
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-1_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-2_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-25_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-33_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-3a_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-3b_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-44_PM-v7.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-45_PM-v7.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-4a_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-4p_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-5Ci_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-5L_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-5M_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-6d1_PM-v4.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-6d2_PM-v4.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-6d3_PM-v4.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-6ma_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-6mp_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-7A_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-7M_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-7P_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-7PC_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-FG1_PM-v1.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-FG2_PM-v1.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-FG3_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-FG4_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-Fo1_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-Fo2_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-Fo3_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-Fo4_PM-v2.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-Fo5_PM-v2.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-Fo6_PM-v2.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-Fo7_PM-v2.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-Fp1_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-Fp2_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-Ia_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-Id1_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-Id2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-Id3_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-Id4_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-Id5_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-Id6_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-Id7_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-Ig1_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-Ig2_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-Ig3_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-OP1_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-OP2_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-OP3_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-OP4_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-OP8_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-OP9_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-PF_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-PFcm_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-PFm_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-PFop_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-PFt_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-PGa_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-PGp_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-STS1_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-STS2_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-TE-1.0_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-TE-1.1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-TE-1.2_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-TE-3_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-hIP1_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-hIP2_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-hIP3_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-hIP4_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-hIP5_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-hIP6_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-hIP7_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-hIP8_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-hOc1_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-hOc2_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-hOc3d_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-hOc3v_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-hOc4d_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-hOc4la_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-hOc4lp_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-hOc4v_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-hOc5_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-hOc6_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-hPO1_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-p24ab_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-p24c_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-p32_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-s24_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Area-s32_PM-v16.1"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_CA_PM-v11.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_CM_PM-v6.4"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Ch-123_PM-v4.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Ch-4_PM-v4.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_DG_PM-v11.1"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Dorsal-Dentate-Nucleus_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Entorhinal-Cortex_PM-v11.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Fastigial-Nucleus_PM-v6.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_HATA_PM-v11.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_IF_PM-v6.4"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Interposed-Nucleus_PM-v6.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_LB_PM-v6.4"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_MF_PM-v6.4"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_SF_PM-v6.4"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Subiculum_PM-v11.1"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_VTM_PM-v6.4"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v1.18-MNI152_Ventral-Dentate-Nucleus_PM-v6.2"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2019)](https://doi.org/10.25493/8EGG-ZAR).",
    is_alternative_version_of=[{"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v1.18-Colin27"}],
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v1.18",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/probabilisticAtlas"},
    version_identifier="v1.18, MNI152",
    version_innovation="This is the first release of the Julich-Brain Atlas using the common coordinate space MNI ICBM152 (2009c Nonlinear Asymmetric).",
)
BrainAtlasVersion.jba_v2_2__colin27 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.2-Colin27",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/MNI-Colin27_1998"},
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-1_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-2_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-25_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-33_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-3a_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-3b_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-44_PM-v7.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-45_PM-v7.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-4a_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-4p_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-5Ci_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-5L_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-5M_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-6d1_PM-v4.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-6d2_PM-v4.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-6d3_PM-v4.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-6ma_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-6mp_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-7A_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-7P_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-7PC_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-FG1_PM-v1.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-FG2_PM-v1.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-FG3_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-FG4_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-Fo1_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-Fo2_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-Fo3_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-Fo4_PM-v2.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-Fo5_PM-v2.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-Fo6_PM-v2.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-Fo7_PM-v2.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-Fp1_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-Fp2_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-Ia_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-Id1_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-Id2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-Id3_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-Id4_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-Id5_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-Id6_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-Id7_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-Ig1_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-Ig2_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-Ig3_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-OP1_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-OP2_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-OP3_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-OP4_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-OP5_PM-v2.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-OP6_PM-v2.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-OP7_PM-v2.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-OP8_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-OP9_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-PF_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-PFcm_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-PFm_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-PFop_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-PFt_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-PGa_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-PGp_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-STS1_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-STS2_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-TE-1.0_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-TE-1.1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-TE-1.2_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-TE-2.1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-TE-2.2_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-TE-3_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-TI_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-TeI_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-a29_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-a30_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-hIP1_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-hIP2_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-hIP3_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-hIP4_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-hIP5_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-hIP6_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-hIP7_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-hIP8_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-hOc1_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-hOc2_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-hOc3d_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-hOc3v_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-hOc4d_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-hOc4la_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-hOc4lp_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-hOc4v_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-hOc5_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-hOc6_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-hPO1_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-i29_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-i30_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-p24ab_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-p24c_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-p29_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-p30_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-p32_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-s24_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Area-s32_PM-v16.1"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_CA1_PM-v11.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_CA2_PM-v11.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_CA3_PM-v11.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_CM_PM-v6.4"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Ch-123_PM-v4.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Ch-4_PM-v4.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_DG_PM-v11.1"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Dorsal-Dentate-Nucleus_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Entorhinal-Cortex_PM-v11.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Fastigial-Nucleus_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Frontal-I_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Frontal-II_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Frontal-to-Occipital_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Frontal-to-Temporal_PM-v9.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_HATA_PM-v11.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_IF_PM-v6.4"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Interposed-Nucleus_PM-v6.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_LB_PM-v6.4"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_MF_PM-v6.4"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_SF_PM-v6.4"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Subiculum_PM-v11.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Temporal-to-Parietal_PM-v9.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_VTM_PM-v6.4"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-Colin27_Ventral-Dentate-Nucleus_PM-v6.2"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2020)](https://doi.org/10.25493/TAKY-64D).",
    is_alternative_version_of=[{"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.2-MNI152"}],
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v1.18-Colin27"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v2.2",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/probabilisticAtlas"},
    version_identifier="v2.2, Colin27",
)
BrainAtlasVersion.jba_v2_2_mni152 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.2-MNI152",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={
        "@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/MNI-ICBM152_nonlinear-2009c-asym"
    },
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-1_PM-v8.4"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-2_PM-v3.4"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-25_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-33_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-3a_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-3b_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-44_PM-v7.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-45_PM-v7.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-4a_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-4p_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-5Ci_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-5L_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-5M_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-6d1_PM-v4.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-6d2_PM-v4.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-6d3_PM-v4.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-6ma_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-6mp_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-7A_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-7P_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-7PC_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-FG1_PM-v1.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-FG2_PM-v1.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-FG3_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-FG4_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-Fo1_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-Fo2_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-Fo3_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-Fo4_PM-v2.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-Fo5_PM-v2.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-Fo6_PM-v2.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-Fo7_PM-v2.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-Fp1_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-Fp2_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-Ia_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-Id1_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-Id2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-Id3_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-Id4_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-Id5_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-Id6_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-Id7_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-Ig1_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-Ig2_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-Ig3_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-OP1_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-OP2_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-OP3_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-OP4_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-OP5_PM-v2.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-OP6_PM-v2.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-OP7_PM-v2.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-OP8_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-OP9_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-PF_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-PFcm_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-PFm_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-PFop_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-PFt_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-PGa_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-PGp_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-STS1_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-STS2_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-TE-1.0_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-TE-1.1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-TE-1.2_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-TE-2.1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-TE-2.2_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-TE-3_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-TI_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-TeI_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-a29_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-a30_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-hIP1_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-hIP2_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-hIP3_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-hIP4_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-hIP5_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-hIP6_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-hIP7_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-hIP8_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-hOc1_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-hOc2_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-hOc3d_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-hOc3v_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-hOc4d_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-hOc4la_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-hOc4lp_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-hOc4v_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-hOc5_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-hOc6_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-hPO1_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-i29_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-i30_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-p24ab_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-p24c_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-p29_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-p30_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-p32_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-s24_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Area-s32_PM-v16.1"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_CA1_PM-v11.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_CA2_PM-v11.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_CA3_PM-v11.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_CM_PM-v6.4"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Ch-123_PM-v4.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Ch-4_PM-v4.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_DG_PM-v11.1"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Dorsal-Dentate-Nucleus_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Entorhinal-Cortex_PM-v11.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Fastigial-Nucleus_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Frontal-I_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Frontal-II_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Frontal-to-Occipital_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Frontal-to-Temporal_PM-v9.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_HATA_PM-v11.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_IF_PM-v6.4"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Interposed-Nucleus_PM-v6.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_LB_PM-v6.4"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_MF_PM-v6.4"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_SF_PM-v6.4"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Subiculum_PM-v11.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Temporal-to-Parietal_PM-v9.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_VTM_PM-v6.4"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.2-MNI152_Ventral-Dentate-Nucleus_PM-v6.2"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2020)](https://doi.org/10.25493/TAKY-64D).",
    is_alternative_version_of=[{"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.2-Colin27"}],
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v1.18-MNI152"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v2.2",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/probabilisticAtlas"},
    version_identifier="v2.2, MNI152",
)
BrainAtlasVersion.jba_v2_4__colin27 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.4-Colin27",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/MNI-Colin27_1998"},
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-1_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-2_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-25_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-33_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-3a_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-3b_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-44_PM-v7.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-45_PM-v7.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-4a_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-4p_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-5Ci_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-5L_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-5M_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-6d1_PM-v4.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-6d2_PM-v4.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-6d3_PM-v4.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-6ma_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-6mp_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-7A_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-7P_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-7PC_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-FG1_PM-v1.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-FG2_PM-v1.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-FG3_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-FG4_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-Fo1_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-Fo2_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-Fo3_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-Fo4_PM-v2.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-Fo5_PM-v2.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-Fo6_PM-v2.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-Fo7_PM-v2.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-Fp1_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-Fp2_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-Ia_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-Id1_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-Id2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-Id3_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-Id4_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-Id5_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-Id6_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-Id7_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-Ig1_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-Ig2_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-Ig3_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-OP1_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-OP2_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-OP3_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-OP4_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-OP5_PM-v2.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-OP6_PM-v2.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-OP7_PM-v2.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-OP8_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-OP9_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-PF_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-PFcm_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-PFm_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-PFop_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-PFt_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-PGa_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-PGp_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-STS1_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-STS2_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-TE-1.0_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-TE-1.1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-TE-1.2_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-TE-2.1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-TE-2.2_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-TE-3_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-TI_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-TeI_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-a29_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-a30_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-hIP1_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-hIP2_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-hIP3_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-hIP4_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-hIP5_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-hIP6_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-hIP7_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-hIP8_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-hOc1_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-hOc2_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-hOc3d_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-hOc3v_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-hOc4d_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-hOc4la_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-hOc4lp_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-hOc4v_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-hOc5_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-hOc6_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-hPO1_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-i29_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-i30_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-p24ab_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-p24c_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-p29_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-p30_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-p32_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-s24_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Area-s32_PM-v16.1"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_CA1_PM-v11.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_CA2_PM-v11.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_CA3_PM-v11.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_CM_PM-v6.4"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Ch-123_PM-v4.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Ch-4_PM-v4.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_DG_PM-v11.1"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Dorsal-Dentate-Nucleus_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Entorhinal-Cortex_PM-v11.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Fastigial-Nucleus_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Frontal-I_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Frontal-II_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Frontal-to-Occipital_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Frontal-to-Temporal_PM-v9.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_HATA_PM-v11.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_IF_PM-v6.4"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Interposed-Nucleus_PM-v6.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_LB_PM-v6.4"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_MF_PM-v6.4"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_SF_PM-v6.4"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Subiculum_PM-v11.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Temporal-to-Parietal_PM-v9.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_VTM_PM-v6.4"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-Colin27_Ventral-Dentate-Nucleus_PM-v6.2"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2020)](https://doi.org/10.25493/A7Y0-NX9).",
    is_alternative_version_of=[{"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.4-MNI152"}],
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.2-Colin27"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v2.4",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/probabilisticAtlas"},
    version_identifier="v2.4, Colin27",
)
BrainAtlasVersion.jba_v2_4_mni152 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.4-MNI152",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={
        "@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/MNI-ICBM152_nonlinear-2009c-asym"
    },
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-1_PM-v8.4"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-2_PM-v3.4"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-25_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-33_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-3a_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-3b_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-44_PM-v7.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-45_PM-v7.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-4a_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-4p_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-5Ci_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-5L_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-5M_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-6d1_PM-v4.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-6d2_PM-v4.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-6d3_PM-v4.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-6ma_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-6mp_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-7A_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-7P_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-7PC_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-FG1_PM-v1.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-FG2_PM-v1.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-FG3_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-FG4_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-Fo1_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-Fo2_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-Fo3_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-Fo4_PM-v2.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-Fo5_PM-v2.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-Fo6_PM-v2.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-Fo7_PM-v2.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-Fp1_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-Fp2_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-Ia_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-Id1_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-Id2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-Id3_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-Id4_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-Id5_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-Id6_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-Id7_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-Ig1_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-Ig2_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-Ig3_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-OP1_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-OP2_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-OP3_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-OP4_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-OP5_PM-v2.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-OP6_PM-v2.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-OP7_PM-v2.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-OP8_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-OP9_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-PF_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-PFcm_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-PFm_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-PFop_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-PFt_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-PGa_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-PGp_PM-v9.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-STS1_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-STS2_PM-v3.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-TE-1.0_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-TE-1.1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-TE-1.2_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-TE-2.1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-TE-2.2_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-TE-3_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-TI_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-TeI_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-a29_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-a30_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-hIP1_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-hIP2_PM-v6.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-hIP3_PM-v8.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-hIP4_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-hIP5_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-hIP6_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-hIP7_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-hIP8_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-hOc1_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-hOc2_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-hOc3d_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-hOc3v_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-hOc4d_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-hOc4la_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-hOc4lp_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-hOc4v_PM-v3.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-hOc5_PM-v2.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-hOc6_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-hPO1_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-i29_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-i30_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-p24ab_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-p24c_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-p29_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-p30_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-p32_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-s24_PM-v16.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Area-s32_PM-v16.1"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_CA1_PM-v11.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_CA2_PM-v11.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_CA3_PM-v11.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_CM_PM-v6.4"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Ch-123_PM-v4.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Ch-4_PM-v4.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_DG_PM-v11.1"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Dorsal-Dentate-Nucleus_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Entorhinal-Cortex_PM-v11.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Fastigial-Nucleus_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Frontal-I_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Frontal-II_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Frontal-to-Occipital_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Frontal-to-Temporal_PM-v9.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_HATA_PM-v11.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_IF_PM-v6.4"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Interposed-Nucleus_PM-v6.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_LB_PM-v6.4"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_MF_PM-v6.4"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_SF_PM-v6.4"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Subiculum_PM-v11.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Temporal-to-Parietal_PM-v9.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_VTM_PM-v6.4"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.4-MNI152_Ventral-Dentate-Nucleus_PM-v6.2"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2020)](https://doi.org/10.25493/A7Y0-NX9).",
    is_alternative_version_of=[{"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.4-Colin27"}],
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.2-MNI152"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v2.4",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/probabilisticAtlas"},
    version_identifier="v2.4, MNI152",
)
BrainAtlasVersion.jba_v2_5__colin27 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.5-Colin27",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/MNI-Colin27_1998"},
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-1_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-2_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-25_PM-v18.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-33_PM-v18.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-3a_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-3b_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-44_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-45_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-4a_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-4p_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-5Ci_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-5L_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-5M_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-6d1_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-6d2_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-6d3_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-6ma_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-6mp_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-7A_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-7M_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-7P_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-7PC_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-FG1_PM-v3.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-FG2_PM-v3.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-FG3_PM-v7.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-FG4_PM-v7.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-Fo1_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-Fo2_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-Fo3_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-Fo4_PM-v3.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-Fo5_PM-v3.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-Fo6_PM-v3.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-Fo7_PM-v3.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-Fp1_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-Fp2_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-Ia_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-Id1_PM-v14.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-Id2_PM-v8.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-Id3_PM-v8.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-Id4_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-Id5_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-Id6_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-Id7_PM-v7.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-Ig1_PM-v14.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-Ig2_PM-v14.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-Ig3_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-OP1_PM-v12.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-OP2_PM-v12.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-OP3_PM-v12.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-OP4_PM-v12.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-OP5_PM-v3.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-OP6_PM-v3.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-OP7_PM-v3.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-OP8_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-OP9_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-PF_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-PFcm_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-PFm_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-PFop_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-PFt_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-PGa_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-PGp_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-STS1_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-STS2_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-TE-1.0_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-TE-1.1_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-TE-1.2_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-TE-2.1_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-TE-2.2_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-TE-3_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-TI_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-TeI_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-hIP1_PM-v7.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-hIP2_PM-v7.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-hIP3_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-hIP4_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-hIP5_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-hIP6_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-hIP7_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-hIP8_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-hOc1_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-hOc2_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-hOc3d_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-hOc3v_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-hOc4d_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-hOc4la_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-hOc4lp_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-hOc4v_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-hOc5_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-hOc6_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-hPO1_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-p24ab_PM-v18.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-p24c_PM-v18.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-p32_PM-v18.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-s24_PM-v18.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Area-s32_PM-v18.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_CA1_PM-v13.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_CA2_PM-v13.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_CA3_PM-v13.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_CM_PM-v8.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Ch-123_PM-v4.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Ch-4_PM-v4.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_DG_PM-v13.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Dorsal-Dentate-Nucleus_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Entorhinal-Cortex_PM-v13.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Fastigial-Nucleus_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Frontal-I_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Frontal-II_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Frontal-to-Occipital_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Frontal-to-Temporal_PM-v10.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_HATA_PM-v13.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_HC-Transsubiculum_PM-v13.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_IF_PM-v8.1"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Interposed-Nucleus_PM-v6.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_LB_PM-v8.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_MF_PM-v8.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_SF_PM-v8.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Subiculum.PaS_PM-v13.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Subiculum.PreS_PM-v13.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Subiculum.ProS_PM-v13.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Subiculum.Sub_PM-v13.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Temporal-to-Parietal_PM-v10.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_VTM_PM-v8.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-Colin27_Ventral-Dentate-Nucleus_PM-v6.2"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2020)](https://doi.org/10.25493/8JKE-M53).",
    is_alternative_version_of=[{"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.5-MNI152"}],
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.4-Colin27"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v2.5",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/probabilisticAtlas"},
    version_identifier="v2.5, Colin27",
)
BrainAtlasVersion.jba_v2_5_mni152 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.5-MNI152",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={
        "@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/MNI-ICBM152_nonlinear-2009c-asym"
    },
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-1_PM-v10.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-2_PM-v5.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-25_PM-v18.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-33_PM-v18.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-3a_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-3b_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-44_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-45_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-4a_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-4p_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-5Ci_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-5L_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-5M_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-6d1_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-6d2_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-6d3_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-6ma_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-6mp_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-7A_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-7M_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-7P_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-7PC_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-FG1_PM-v3.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-FG2_PM-v3.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-FG3_PM-v7.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-FG4_PM-v7.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-Fo1_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-Fo2_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-Fo3_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-Fo4_PM-v3.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-Fo5_PM-v3.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-Fo6_PM-v3.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-Fo7_PM-v3.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-Fp1_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-Fp2_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-Ia_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-Id1_PM-v14.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-Id2_PM-v8.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-Id3_PM-v8.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-Id4_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-Id5_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-Id6_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-Id7_PM-v7.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-Ig1_PM-v14.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-Ig2_PM-v14.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-Ig3_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-OP1_PM-v12.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-OP2_PM-v12.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-OP3_PM-v12.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-OP4_PM-v12.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-OP5_PM-v3.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-OP6_PM-v3.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-OP7_PM-v3.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-OP8_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-OP9_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-PF_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-PFcm_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-PFm_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-PFop_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-PFt_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-PGa_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-PGp_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-STS1_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-STS2_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-TE-1.0_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-TE-1.1_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-TE-1.2_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-TE-2.1_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-TE-2.2_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-TE-3_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-TI_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-TeI_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-hIP1_PM-v7.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-hIP2_PM-v7.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-hIP3_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-hIP4_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-hIP5_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-hIP6_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-hIP7_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-hIP8_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-hOc1_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-hOc2_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-hOc3d_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-hOc3v_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-hOc4d_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-hOc4la_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-hOc4lp_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-hOc4v_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-hOc5_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-hOc6_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-hPO1_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-p24ab_PM-v18.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-p24c_PM-v18.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-p32_PM-v18.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-s24_PM-v18.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Area-s32_PM-v18.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_CA1_PM-v13.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_CA2_PM-v13.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_CA3_PM-v13.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_CM_PM-v8.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Ch-123_PM-v4.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Ch-4_PM-v4.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_DG_PM-v13.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Dorsal-Dentate-Nucleus_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Entorhinal-Cortex_PM-v13.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Fastigial-Nucleus_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Frontal-I_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Frontal-II_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Frontal-to-Occipital_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Frontal-to-Temporal_PM-v10.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_HATA_PM-v13.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_HC-Transsubiculum_PM-v13.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_IF_PM-v8.1"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Interposed-Nucleus_PM-v6.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_LB_PM-v8.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_MF_PM-v8.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_SF_PM-v8.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Subiculum.PaS_PM-v13.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Subiculum.PreS_PM-v13.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Subiculum.ProS_PM-v13.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Subiculum.Sub_PM-v13.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Temporal-to-Parietal_PM-v10.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_VTM_PM-v8.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.5-MNI152_Ventral-Dentate-Nucleus_PM-v6.2"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2020)](https://doi.org/10.25493/8JKE-M53).",
    is_alternative_version_of=[{"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.5-Colin27"}],
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.4-MNI152"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v2.5",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/probabilisticAtlas"},
    version_identifier="v2.5, MNI152",
)
BrainAtlasVersion.jba_v2_6_mni152 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.6-MNI152",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={
        "@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/MNI-ICBM152_nonlinear-2009c-asym"
    },
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-1_PM-v10.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-2_PM-v5.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-25_PM-v18.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-33_PM-v18.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-3a_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-3b_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-44_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-45_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-4a_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-4p_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-5Ci_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-5L_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-5M_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-6d1_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-6d2_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-6d3_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-6ma_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-6mp_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-7A_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-7M_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-7P_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-7PC_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-FG1_PM-v3.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-FG2_PM-v3.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-FG3_PM-v7.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-FG4_PM-v7.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-Fo1_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-Fo2_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-Fo3_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-Fo4_PM-v3.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-Fo5_PM-v3.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-Fo6_PM-v3.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-Fo7_PM-v3.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-Fp1_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-Fp2_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-Ia_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-Id1_PM-v14.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-Id2_PM-v8.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-Id3_PM-v8.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-Id4_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-Id5_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-Id6_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-Id7_PM-v7.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-Ig1_PM-v14.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-Ig2_PM-v14.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-Ig3_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-OP1_PM-v12.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-OP2_PM-v12.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-OP3_PM-v12.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-OP4_PM-v12.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-OP5_PM-v3.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-OP6_PM-v3.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-OP7_PM-v3.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-OP8_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-OP9_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-PF_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-PFcm_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-PFm_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-PFop_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-PFt_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-PGa_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-PGp_PM-v11.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-STS1_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-STS2_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-TE-1.0_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-TE-1.1_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-TE-1.2_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-TE-2.1_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-TE-2.2_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-TE-3_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-TI_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-TeI_PM-v6.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-hIP1_PM-v7.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-hIP2_PM-v7.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-hIP3_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-hIP4_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-hIP5_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-hIP6_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-hIP7_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-hIP8_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-hOc1_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-hOc2_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-hOc3d_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-hOc3v_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-hOc4d_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-hOc4la_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-hOc4lp_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-hOc4v_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-hOc5_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-hOc6_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-hPO1_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-p24ab_PM-v18.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-p24c_PM-v18.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-p32_PM-v18.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-s24_PM-v18.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Area-s32_PM-v18.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_CA1_PM-v13.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_CA2_PM-v13.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_CA3_PM-v13.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_CM_PM-v8.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Ch-123_PM-v4.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Ch-4_PM-v4.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_DG_PM-v13.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Dorsal-Dentate-Nucleus_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Entorhinal-Cortex_PM-v13.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Fastigial-Nucleus_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Frontal-I_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Frontal-II_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Frontal-to-Occipital_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Frontal-to-Temporal_PM-v10.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_HATA_PM-v13.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_HC-Transsubiculum_PM-v13.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_IF_PM-v8.1"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Interposed-Nucleus_PM-v6.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_LB_PM-v8.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_MF_PM-v8.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_SF_PM-v8.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Subiculum.PaS_PM-v13.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Subiculum.PreS_PM-v13.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Subiculum.ProS_PM-v13.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Subiculum.Sub_PM-v13.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Temporal-to-Parietal_PM-v10.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_VTM_PM-v8.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.6-MNI152_Ventral-Dentate-Nucleus_PM-v6.2"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2021)](https://doi.org/10.25493/KJQN-AM0).",
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.5-MNI152"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v2.6",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/probabilisticAtlas"},
    version_identifier="v2.6, MNI152",
)
BrainAtlasVersion.jba_v2_9__big_brain = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.9-BigBrain",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/BigBrain_2015"},
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_Area-6d1_int"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_Area-6d2_int"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_Area-6d3_int"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_Area-6ma_int"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_Area-MFG1_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_Area-MFG2_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_Area-SFS1_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_Area-SFS2_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_Area-STS1_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_Area-STS2_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_Area-TE-1.0_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_Area-TE-1.1_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_Area-TE-1.2_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_Area-TE-3_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_Area-hIP4_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_Area-hIP5_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_Area-hIP6_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_Area-hIP7_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_Area-hIP8_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_Area-hOc1_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_Area-hOc2_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_Area-hOc3v_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_Area-hOc5_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_Area-hOc6_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_Area-hPO1_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_CGM.CGMd_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_CGM.CGMm_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_CGM.CGMv_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-BigBrain_Entorhinal-Cortex_int"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2021)](https://doi.org/10.25493/VSMK-H94).",
    is_alternative_version_of=[
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.9-Colin27"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.9-fsaverage"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.9-MNI152"},
    ],
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v2.9",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/deterministicAtlas"},
    version_identifier="v2.9, BigBrain",
    version_innovation="This is the first release of the Julich-Brain Atlas using the common coordinate space BigBrain (2015).",
)
BrainAtlasVersion.jba_v2_9__colin27 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.9-Colin27",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/MNI-Colin27_1998"},
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-1_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-25_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-33_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-3a_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-3b_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-44_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-45_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-4a_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-4p_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-5Ci_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-5L_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-5M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-6d1_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-6d2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-6d3_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-6ma_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-6mp_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-7A_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-7M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-7P_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-7PC_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-8d1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-8d2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-8v1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-8v2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-CoS1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-FG1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-FG2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-FG3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-FG4_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-Fo1_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-Fo2_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-Fo3_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-Fo4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-Fo5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-Fo6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-Fo7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-Fp1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-Fp2_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-IFJ1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-IFJ2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-IFS1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-IFS2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-IFS3_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-IFS4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-Ia1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-Ia2_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-Ia3_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-Id1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-Id10_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-Id2_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-Id3_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-Id4_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-Id5_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-Id6_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-Id7_PM-v8.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-Id8_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-Id9_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-Ig1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-Ig2_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-Ig3_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-OP1_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-OP2_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-OP3_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-OP4_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-OP5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-OP6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-OP7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-OP8_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-OP9_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-PF_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-PFcm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-PFm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-PFop_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-PFt_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-PGa_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-PGp_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-Ph1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-Ph2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-Ph3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-STS1_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-STS2_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-TE-1.0_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-TE-1.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-TE-1.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-TE-2.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-TE-2.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-TE-3_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-TI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-TPJ_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-TeI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-hIP1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-hIP2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-hIP3_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-hIP4_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-hIP5_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-hIP6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-hIP7_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-hIP8_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-hOc1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-hOc2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-hOc3d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-hOc3v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-hOc4d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-hOc4la_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-hOc4lp_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-hOc4v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-hOc5_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-hOc6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-hPO1_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-p24ab_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-p24c_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-p32_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-s24_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Area-s32_PM-v20.1"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_BST_PM-v6.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_CA1_PM-v13.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_CA2_PM-v13.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_CA3_PM-v13.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_CGL_PM-v5.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_CGM_PM-v5.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_CM_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Ch-123_PM-v4.3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Ch-4_PM-v4.3"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_DG_PM-v13.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Dorsal-Dentate-Nucleus_PM-v6.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Entorhinal-Cortex_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Fastigial-Nucleus_PM-v6.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Frontal-I_PM-v11.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Frontal-II_PM-v11.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Frontal-to-Occipital_PM-v11.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Frontal-to-Temporal-I_PM-v11.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Frontal-to-Temporal-II_PM-v11.3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_HATA_PM-v13.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_HC-Transsubiculum_PM-v13.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_IF_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Interposed-Nucleus_PM-v6.3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_LB_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_MF_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_SF_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Subiculum.PaS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Subiculum.PreS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Subiculum.ProS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Subiculum.Sub_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Temporal-to-Parietal_PM-v11.3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_VTM_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-Colin27_Ventral-Dentate-Nucleus_PM-v6.3"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2021)](https://doi.org/10.25493/VSMK-H94).",
    is_alternative_version_of=[
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.9-BigBrain"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.9-fsaverage"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.9-MNI152"},
    ],
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.5-Colin27"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v2.9",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/probabilisticAtlas"},
    version_identifier="v2.9, Colin27",
)
BrainAtlasVersion.jba_v2_9_fsaverage = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.9-fsaverage",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/fsaverage_7"},
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-1_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-25_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-33_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-3a_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-3b_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-44_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-45_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-4a_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-4p_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-5Ci_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-5L_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-5M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-6d1_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-6d2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-6d3_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-6ma_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-6mp_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-7A_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-7M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-7P_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-7PC_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-8d1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-8d2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-8v1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-8v2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-CoS1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-FG1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-FG2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-FG3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-FG4_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-Fo1_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-Fo2_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-Fo3_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-Fo4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-Fo5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-Fo6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-Fo7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-Fp1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-Fp2_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-IFJ1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-IFJ2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-IFS1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-IFS2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-IFS3_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-IFS4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-Ia1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-Ia2_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-Ia3_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-Id1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-Id10_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-Id2_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-Id3_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-Id4_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-Id5_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-Id6_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-Id7_PM-v8.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-Id8_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-Id9_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-Ig1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-Ig2_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-Ig3_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-OP1_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-OP2_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-OP3_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-OP4_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-OP5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-OP6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-OP7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-OP8_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-OP9_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-PF_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-PFcm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-PFm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-PFop_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-PFt_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-PGa_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-PGp_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-Ph1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-Ph2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-Ph3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-STS1_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-STS2_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-TE-1.0_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-TE-1.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-TE-1.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-TE-2.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-TE-2.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-TE-3_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-TI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-TPJ_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-TeI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-hIP1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-hIP2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-hIP3_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-hIP4_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-hIP5_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-hIP6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-hIP7_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-hIP8_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-hOc1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-hOc2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-hOc3d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-hOc3v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-hOc4d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-hOc4la_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-hOc4lp_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-hOc4v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-hOc5_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-hOc6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-hPO1_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-p24ab_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-p24c_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-p32_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-s24_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Area-s32_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_CA1_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_CA2_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_CA3_PM-v13.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_CGL_PM-v5.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_CGM_PM-v5.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_DG_PM-v13.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Entorhinal-Cortex_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Frontal-I_PM-v11.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Frontal-II_PM-v11.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Frontal-to-Occipital_PM-v11.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Frontal-to-Temporal-I_PM-v11.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Frontal-to-Temporal-II_PM-v11.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_HATA_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_HC-Transsubiculum_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Subiculum.PaS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Subiculum.PreS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Subiculum.ProS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Subiculum.Sub_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-fsaverage_Temporal-to-Parietal_PM-v11.3"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2021)](https://doi.org/10.25493/VSMK-H94).",
    is_alternative_version_of=[
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.9-BigBrain"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.9-Colin27"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.9-MNI152"},
    ],
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v2.9",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/probabilisticAtlas"},
    version_identifier="v2.9, fsaverage",
    version_innovation="This is the first release of the Julich-Brain Atlas using the common coordinate space FsAverage (7).",
)
BrainAtlasVersion.jba_v2_9_mni152 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.9-MNI152",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={
        "@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/MNI-ICBM152_nonlinear-2009c-asym"
    },
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-1_PM-v12.1"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-2_PM-v7.1"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-25_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-33_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-3a_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-3b_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-44_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-45_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-4a_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-4p_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-5Ci_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-5L_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-5M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-6d1_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-6d2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-6d3_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-6ma_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-6mp_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-7A_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-7M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-7P_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-7PC_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-8d1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-8d2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-8v1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-8v2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-CoS1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-FG1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-FG2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-FG3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-FG4_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-Fo1_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-Fo2_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-Fo3_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-Fo4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-Fo5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-Fo6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-Fo7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-Fp1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-Fp2_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-IFJ1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-IFJ2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-IFS1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-IFS2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-IFS3_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-IFS4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-Ia1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-Ia2_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-Ia3_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-Id1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-Id10_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-Id2_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-Id3_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-Id4_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-Id5_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-Id6_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-Id7_PM-v8.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-Id8_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-Id9_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-Ig1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-Ig2_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-Ig3_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-OP1_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-OP2_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-OP3_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-OP4_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-OP5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-OP6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-OP7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-OP8_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-OP9_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-PF_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-PFcm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-PFm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-PFop_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-PFt_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-PGa_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-PGp_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-Ph1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-Ph2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-Ph3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-STS1_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-STS2_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-TE-1.0_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-TE-1.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-TE-1.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-TE-2.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-TE-2.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-TE-3_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-TI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-TPJ_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-TeI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-hIP1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-hIP2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-hIP3_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-hIP4_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-hIP5_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-hIP6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-hIP7_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-hIP8_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-hOc1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-hOc2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-hOc3d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-hOc3v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-hOc4d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-hOc4la_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-hOc4lp_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-hOc4v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-hOc5_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-hOc6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-hPO1_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-p24ab_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-p24c_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-p32_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-s24_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Area-s32_PM-v20.1"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_BST_PM-v6.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_CA1_PM-v13.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_CA2_PM-v13.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_CA3_PM-v13.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_CGL_PM-v5.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_CGM_PM-v5.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_CM_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Ch-123_PM-v4.3"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Ch-4_PM-v4.3"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_DG_PM-v13.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Dorsal-Dentate-Nucleus_PM-v6.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Entorhinal-Cortex_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Fastigial-Nucleus_PM-v6.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Frontal-I_PM-v11.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Frontal-II_PM-v11.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Frontal-to-Occipital_PM-v11.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Frontal-to-Temporal-I_PM-v11.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Frontal-to-Temporal-II_PM-v11.3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_HATA_PM-v13.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_HC-Transsubiculum_PM-v13.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_IF_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Interposed-Nucleus_PM-v6.3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_LB_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_MF_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_SF_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Subiculum.PaS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Subiculum.PreS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Subiculum.ProS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Subiculum.Sub_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Temporal-to-Parietal_PM-v11.3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_VTM_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v2.9-MNI152_Ventral-Dentate-Nucleus_PM-v6.3"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2021)](https://doi.org/10.25493/VSMK-H94).",
    is_alternative_version_of=[
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.9-BigBrain"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.9-Colin27"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.9-fsaverage"},
    ],
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.6-MNI152"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v2.9",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/probabilisticAtlas"},
    version_identifier="v2.9, MNI152",
)
BrainAtlasVersion.jba_v3_0_1__big_brain = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.1-BigBrain",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/BigBrain_2015"},
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_Area-6d1_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_Area-6d2_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_Area-6d3_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_Area-6ma_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_Area-MFG1_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_Area-MFG2_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_Area-SFS1_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_Area-SFS2_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_Area-STS1_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_Area-STS2_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_Area-TE-1.0_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_Area-TE-1.1_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_Area-TE-1.2_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_Area-TE-3_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_Area-hIP4_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_Area-hIP5_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_Area-hIP6_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_Area-hIP7_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_Area-hIP8_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_Area-hOc1_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_Area-hOc2_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_Area-hOc3v_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_Area-hOc5_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_Area-hOc6_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_Area-hPO1_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_CGM.CGMd_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_CGM.CGMm_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_CGM.CGMv_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-BigBrain_Entorhinal-Cortex_int"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2022)](https://doi.org/10.25493/2BV2-001).",
    is_alternative_version_of=[
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.1-Colin27"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.1-fsaverage"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.1-MNI152"},
    ],
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0-BigBrain"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v3.0.1",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/deterministicAtlas"},
    version_identifier="v3.0.1, BigBrain",
)
BrainAtlasVersion.jba_v3_0_1__colin27 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.1-Colin27",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/MNI-Colin27_1998"},
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_AcbL_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_AcbM_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-1_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-25_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-25.25a_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-25.25p_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-33_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-3a_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-3b_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-44_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-45_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-4a_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-4p_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-5Ci_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-5L_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-5M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-6d1_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-6d2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-6d3_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-6ma_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-6mp_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-7A_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-7M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-7P_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-7PC_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-8d1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-8d2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-8v1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-8v2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-CoS1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-FG1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-FG2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-FG3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-FG4_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-Fo1_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-Fo2_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-Fo3_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-Fo4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-Fo5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-Fo6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-Fo7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-Fp1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-Fp2_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-IFJ1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-IFJ2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-IFS1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-IFS2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-IFS3_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-IFS4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-Ia1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-Ia2_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-Ia3_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-Id1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-Id10_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-Id2_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-Id3_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-Id4_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-Id5_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-Id6_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-Id7_PM-v8.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-Id8_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-Id9_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-Ig1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-Ig2_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-Ig3_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-MFG1_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-MFG2_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-OP1_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-OP2_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-OP3_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-OP4_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-OP5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-OP6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-OP7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-OP8_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-OP9_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-PF_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-PFcm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-PFm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-PFop_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-PFt_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-PGa_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-PGp_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-Ph1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-Ph2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-Ph3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-SFS1_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-SFS2_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-STS1_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-STS2_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-TE-1.0_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-TE-1.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-TE-1.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-TE-2.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-TE-2.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-TE-3_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-TI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-TPJ_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-TeI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-hIP1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-hIP2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-hIP3_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-hIP4_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-hIP5_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-hIP6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-hIP7_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-hIP8_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-hOc1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-hOc2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-hOc3d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-hOc3v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-hOc4d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-hOc4la_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-hOc4lp_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-hOc4v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-hOc5_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-hOc6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-hPO1_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-p24ab_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-p24ab.p24a_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-p24ab.p24b_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-p24c_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-p24c.pd24cd_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-p24c.pd24cv_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-p24c.pv24c_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-p32_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-s24_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-s24.s24a_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-s24.s24b_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Area-s32_PM-v20.1"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_BST_PM-v6.1"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_CA1_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_CA2_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_CA3_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_CGL_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_CGM_PM-v10.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_CM_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_CM.AAA_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_CM.Ce_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_CM.Me_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Ch-123_PM-v4.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Ch-4_PM-v4.3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_DG_PM-v13.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Dorsal-Dentate-Nucleus_PM-v6.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Entorhinal-Cortex_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Fastigial-Nucleus_PM-v6.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Frontal-I_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Frontal-II_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Frontal-to-Occipital_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Frontal-to-Temporal-I_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Frontal-to-Temporal-II_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_FuCd_PM-v5.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_FuP_PM-v5.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_HATA_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_HC-Transsubiculum_PM-v13.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_IF_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_IF.ice_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_IF.iol_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_IF.ld_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Interposed-Nucleus_PM-v6.3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_LB_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_LB.Bl_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_LB.Bm_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_LB.La_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_LB.Pl_PM-v8.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_MF_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_MF.icm_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_MF.lm_PM-v8.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_SF_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_SF.AHi_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_SF.APir_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_SF.VCo_PM-v8.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_STN_PM-v5.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Subiculum.PaS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Subiculum.PreS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Subiculum.ProS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Subiculum.Sub_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Temporal-to-Parietal_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Terminal-islands_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Tuberculum_PM-v4.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_VP_PM-v5.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_VTM_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-Colin27_Ventral-Dentate-Nucleus_PM-v6.3"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2022)](https://doi.org/10.25493/2BV2-001).",
    is_alternative_version_of=[
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.1-BigBrain"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.1-fsaverage"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.1-MNI152"},
    ],
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0-Colin27"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v3.0.1",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/probabilisticAtlas"},
    version_identifier="v3.0.1, Colin27",
)
BrainAtlasVersion.jba_v3_0_1_fsaverage = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.1-fsaverage",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/fsaverage_7"},
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-1_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-25_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-33_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-3a_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-3b_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-44_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-45_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-4a_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-4p_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-5Ci_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-5L_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-5M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-6d1_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-6d2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-6d3_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-6ma_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-6mp_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-7A_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-7M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-7P_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-7PC_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-8d1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-8d2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-8v1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-8v2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-CoS1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-FG1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-FG2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-FG3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-FG4_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-Fo1_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-Fo2_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-Fo3_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-Fo4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-Fo5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-Fo6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-Fo7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-Fp1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-Fp2_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-IFJ1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-IFJ2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-IFS1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-IFS2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-IFS3_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-IFS4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-Ia1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-Ia2_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-Ia3_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-Id1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-Id10_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-Id2_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-Id3_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-Id4_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-Id5_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-Id6_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-Id7_PM-v8.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-Id8_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-Id9_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-Ig1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-Ig2_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-Ig3_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-MFG1_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-MFG2_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-OP1_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-OP2_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-OP3_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-OP4_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-OP5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-OP6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-OP7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-OP8_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-OP9_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-PF_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-PFcm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-PFm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-PFop_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-PFt_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-PGa_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-PGp_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-Ph1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-Ph2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-Ph3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-SFS1_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-SFS2_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-STS1_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-STS2_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-TE-1.0_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-TE-1.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-TE-1.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-TE-2.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-TE-2.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-TE-3_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-TI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-TPJ_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-TeI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-hIP1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-hIP2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-hIP3_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-hIP4_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-hIP5_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-hIP6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-hIP7_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-hIP8_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-hOc1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-hOc2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-hOc3d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-hOc3v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-hOc4d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-hOc4la_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-hOc4lp_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-hOc4v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-hOc5_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-hOc6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-hPO1_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-p24ab_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-p24c_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-p32_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-s24_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Area-s32_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_CA1_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_CA2_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_CA3_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_CGL_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_CGM_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_DG_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Entorhinal-Cortex_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Frontal-I_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Frontal-II_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Frontal-to-Occipital_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Frontal-to-Temporal-I_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Frontal-to-Temporal-II_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_HATA_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_HC-Transsubiculum_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Subiculum.PaS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Subiculum.PreS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Subiculum.ProS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Subiculum.Sub_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Temporal-to-Parietal_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-fsaverage_Tuberculum_PM-v4.0"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2022)](https://doi.org/10.25493/2BV2-001).",
    is_alternative_version_of=[
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.1-BigBrain"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.1-Colin27"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.1-MNI152"},
    ],
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0-fsaverage"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v3.0.1",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/probabilisticAtlas"},
    version_identifier="v3.0.1, fsaverage",
)
BrainAtlasVersion.jba_v3_0_1_mni152 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.1-MNI152",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={
        "@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/MNI-ICBM152_nonlinear-2009c-asym"
    },
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_AcbL_PM-v5.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_AcbM_PM-v5.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-1_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-25_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-25.25a_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-25.25p_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-33_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-3a_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-3b_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-44_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-45_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-4a_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-4p_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-5Ci_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-5L_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-5M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-6d1_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-6d2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-6d3_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-6ma_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-6mp_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-7A_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-7M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-7P_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-7PC_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-8d1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-8d2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-8v1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-8v2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-CoS1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-FG1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-FG2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-FG3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-FG4_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-Fo1_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-Fo2_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-Fo3_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-Fo4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-Fo5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-Fo6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-Fo7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-Fp1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-Fp2_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-IFJ1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-IFJ2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-IFS1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-IFS2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-IFS3_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-IFS4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-Ia1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-Ia2_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-Ia3_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-Id1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-Id10_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-Id2_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-Id3_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-Id4_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-Id5_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-Id6_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-Id7_PM-v8.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-Id8_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-Id9_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-Ig1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-Ig2_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-Ig3_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-MFG1_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-MFG2_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-OP1_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-OP2_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-OP3_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-OP4_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-OP5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-OP6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-OP7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-OP8_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-OP9_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-PF_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-PFcm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-PFm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-PFop_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-PFt_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-PGa_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-PGp_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-Ph1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-Ph2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-Ph3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-SFS1_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-SFS2_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-STS1_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-STS2_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-TE-1.0_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-TE-1.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-TE-1.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-TE-2.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-TE-2.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-TE-3_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-TI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-TPJ_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-TeI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-hIP1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-hIP2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-hIP3_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-hIP4_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-hIP5_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-hIP6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-hIP7_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-hIP8_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-hOc1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-hOc2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-hOc3d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-hOc3v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-hOc4d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-hOc4la_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-hOc4lp_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-hOc4v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-hOc5_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-hOc6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-hPO1_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-p24ab_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-p24ab.p24a_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-p24ab.p24b_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-p24c_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-p24c.pd24cd_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-p24c.pd24cv_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-p24c.pv24c_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-p32_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-s24_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-s24.s24a_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-s24.s24b_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Area-s32_PM-v20.1"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_BST_PM-v6.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_CA1_PM-v13.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_CA2_PM-v13.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_CA3_PM-v13.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_CGL_PM-v10.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_CGM_PM-v10.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_CM_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_CM.AAA_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_CM.Ce_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_CM.Me_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Ch-123_PM-v4.3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Ch-4_PM-v4.3"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_DG_PM-v13.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Dorsal-Dentate-Nucleus_PM-v6.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Entorhinal-Cortex_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Fastigial-Nucleus_PM-v6.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Frontal-I_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Frontal-II_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Frontal-to-Occipital_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Frontal-to-Temporal-I_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Frontal-to-Temporal-II_PM-v11.4"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_FuCd_PM-v5.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_FuP_PM-v5.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_HATA_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_HC-Transsubiculum_PM-v13.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_IF_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_IF.ice_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_IF.iol_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_IF.ld_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Interposed-Nucleus_PM-v6.3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_LB_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_LB.Bl_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_LB.Bm_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_LB.La_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_LB.Pl_PM-v8.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_MF_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_MF.icm_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_MF.lm_PM-v8.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_SF_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_SF.AHi_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_SF.APir_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_SF.VCo_PM-v8.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_STN_PM-v5.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Subiculum.PaS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Subiculum.PreS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Subiculum.ProS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Subiculum.Sub_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Temporal-to-Parietal_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Terminal-islands_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Tuberculum_PM-v4.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_VP_PM-v5.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_VTM_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.1-MNI152_Ventral-Dentate-Nucleus_PM-v6.3"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2022)](https://doi.org/10.25493/2BV2-001).",
    is_alternative_version_of=[
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.1-BigBrain"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.1-Colin27"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.1-fsaverage"},
    ],
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0-MNI152"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v3.0.1",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/probabilisticAtlas"},
    version_identifier="v3.0.1, MNI152",
)
BrainAtlasVersion.jba_v3_0_2__big_brain = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.2-BigBrain",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/BigBrain_2015"},
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_Area-6d1_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_Area-6d2_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_Area-6d3_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_Area-6ma_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_Area-MFG1_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_Area-MFG2_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_Area-SFS1_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_Area-SFS2_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_Area-STS1_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_Area-STS2_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_Area-TE-1.0_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_Area-TE-1.1_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_Area-TE-1.2_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_Area-TE-3_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_Area-hIP4_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_Area-hIP5_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_Area-hIP6_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_Area-hIP7_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_Area-hIP8_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_Area-hOc1_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_Area-hOc2_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_Area-hOc3v_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_Area-hOc5_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_Area-hOc6_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_Area-hPO1_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_CGM.CGMd_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_CGM.CGMm_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_CGM.CGMv_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-BigBrain_Entorhinal-Cortex_int"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2022)](https://doi.org/10.25493/TMQ3-0EP).",
    is_alternative_version_of=[
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.2-Colin27"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.2-fsaverage"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.2-MNI152"},
    ],
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.1-BigBrain"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v3.0.2",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/deterministicAtlas"},
    version_identifier="v3.0.2, BigBrain",
)
BrainAtlasVersion.jba_v3_0_2__colin27 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.2-Colin27",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/MNI-Colin27_1998"},
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_AcbL_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_AcbM_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-1_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-25_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-25.25a_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-25.25p_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-33_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-3a_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-3b_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-44_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-45_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-4a_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-4p_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-5Ci_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-5L_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-5M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-6d1_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-6d2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-6d3_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-6ma_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-6mp_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-7A_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-7M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-7P_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-7PC_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-8d1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-8d2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-8v1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-8v2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-CoS1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-FG1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-FG2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-FG3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-FG4_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-Fo1_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-Fo2_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-Fo3_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-Fo4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-Fo5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-Fo6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-Fo7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-Fp1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-Fp2_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-IFJ1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-IFJ2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-IFS1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-IFS2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-IFS3_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-IFS4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-Ia1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-Ia2_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-Ia3_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-Id1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-Id10_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-Id2_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-Id3_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-Id4_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-Id5_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-Id6_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-Id7_PM-v8.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-Id8_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-Id9_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-Ig1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-Ig2_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-Ig3_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-MFG1_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-MFG2_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-OP1_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-OP2_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-OP3_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-OP4_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-OP5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-OP6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-OP7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-OP8_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-OP9_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-PF_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-PFcm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-PFm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-PFop_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-PFt_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-PGa_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-PGp_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-Ph1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-Ph2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-Ph3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-SFS1_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-SFS2_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-STS1_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-STS2_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-TE-1.0_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-TE-1.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-TE-1.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-TE-2.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-TE-2.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-TE-3_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-TI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-TPJ_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-TeI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-hIP1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-hIP2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-hIP3_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-hIP4_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-hIP5_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-hIP6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-hIP7_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-hIP8_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-hOc1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-hOc2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-hOc3d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-hOc3v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-hOc4d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-hOc4la_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-hOc4lp_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-hOc4v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-hOc5_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-hOc6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-hPO1_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-p24ab_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-p24ab.p24a_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-p24ab.p24b_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-p24c_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-p24c.pd24cd_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-p24c.pd24cv_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-p24c.pv24c_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-p32_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-s24_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-s24.s24a_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-s24.s24b_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Area-s32_PM-v20.1"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_BST_PM-v6.1"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_CA1_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_CA2_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_CA3_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_CGL_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_CGM_PM-v10.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_CM_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_CM.AAA_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_CM.Ce_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_CM.Me_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Ch-123_PM-v4.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Ch-4_PM-v4.3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_DG_PM-v13.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Dorsal-Dentate-Nucleus_PM-v6.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Entorhinal-Cortex_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Fastigial-Nucleus_PM-v6.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Frontal-I_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Frontal-II_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Frontal-to-Occipital_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Frontal-to-Temporal-I_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Frontal-to-Temporal-II_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_FuCd_PM-v5.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_FuP_PM-v5.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_HATA_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_HC-Transsubiculum_PM-v13.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_IF_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_IF.ice_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_IF.iol_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_IF.ld_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Interposed-Nucleus_PM-v6.3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_LB_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_LB.Bl_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_LB.Bm_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_LB.La_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_LB.Pl_PM-v8.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_MF_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_MF.icm_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_MF.lm_PM-v8.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_SF_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_SF.AHi_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_SF.APir_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_SF.VCo_PM-v8.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_STN_PM-v5.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Subiculum.PaS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Subiculum.PreS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Subiculum.ProS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Subiculum.Sub_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Temporal-to-Parietal_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Terminal-islands_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Tuberculum_PM-v4.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_VP_PM-v5.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_VTM_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-Colin27_Ventral-Dentate-Nucleus_PM-v6.3"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2022)](https://doi.org/10.25493/TMQ3-0EP).",
    is_alternative_version_of=[
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.2-BigBrain"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.2-fsaverage"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.2-MNI152"},
    ],
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.1-Colin27"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v3.0.2",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/probabilisticAtlas"},
    version_identifier="v3.0.2, Colin27",
)
BrainAtlasVersion.jba_v3_0_2_fsaverage = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.2-fsaverage",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/fsaverage_7"},
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-1_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-25_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-33_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-3a_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-3b_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-44_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-45_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-4a_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-4p_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-5Ci_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-5L_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-5M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-6d1_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-6d2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-6d3_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-6ma_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-6mp_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-7A_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-7M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-7P_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-7PC_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-8d1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-8d2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-8v1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-8v2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-CoS1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-FG1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-FG2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-FG3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-FG4_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-Fo1_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-Fo2_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-Fo3_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-Fo4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-Fo5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-Fo6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-Fo7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-Fp1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-Fp2_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-IFJ1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-IFJ2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-IFS1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-IFS2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-IFS3_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-IFS4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-Ia1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-Ia2_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-Ia3_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-Id1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-Id10_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-Id2_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-Id3_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-Id4_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-Id5_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-Id6_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-Id7_PM-v8.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-Id8_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-Id9_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-Ig1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-Ig2_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-Ig3_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-MFG1_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-MFG2_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-OP1_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-OP2_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-OP3_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-OP4_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-OP5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-OP6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-OP7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-OP8_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-OP9_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-PF_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-PFcm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-PFm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-PFop_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-PFt_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-PGa_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-PGp_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-Ph1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-Ph2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-Ph3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-SFS1_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-SFS2_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-STS1_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-STS2_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-TE-1.0_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-TE-1.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-TE-1.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-TE-2.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-TE-2.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-TE-3_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-TI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-TPJ_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-TeI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-hIP1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-hIP2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-hIP3_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-hIP4_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-hIP5_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-hIP6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-hIP7_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-hIP8_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-hOc1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-hOc2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-hOc3d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-hOc3v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-hOc4d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-hOc4la_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-hOc4lp_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-hOc4v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-hOc5_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-hOc6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-hPO1_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-p24ab_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-p24c_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-p32_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-s24_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Area-s32_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_CA1_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_CA2_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_CA3_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_CGL_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_CGM_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_DG_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Entorhinal-Cortex_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Frontal-I_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Frontal-II_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Frontal-to-Occipital_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Frontal-to-Temporal-I_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Frontal-to-Temporal-II_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_HATA_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_HC-Transsubiculum_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Subiculum.PaS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Subiculum.PreS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Subiculum.ProS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Subiculum.Sub_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Temporal-to-Parietal_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-fsaverage_Tuberculum_PM-v4.0"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2022)](https://doi.org/10.25493/TMQ3-0EP).",
    is_alternative_version_of=[
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.2-BigBrain"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.2-Colin27"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.2-MNI152"},
    ],
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.1-fsaverage"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v3.0.2",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/probabilisticAtlas"},
    version_identifier="v3.0.2, fsaverage",
)
BrainAtlasVersion.jba_v3_0_2_mni152 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.2-MNI152",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={
        "@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/MNI-ICBM152_nonlinear-2009c-asym"
    },
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_AcbL_PM-v5.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_AcbM_PM-v5.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-1_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-25_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-25.25a_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-25.25p_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-33_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-3a_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-3b_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-44_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-45_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-4a_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-4p_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-5Ci_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-5L_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-5M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-6d1_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-6d2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-6d3_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-6ma_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-6mp_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-7A_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-7M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-7P_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-7PC_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-8d1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-8d2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-8v1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-8v2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-CoS1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-FG1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-FG2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-FG3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-FG4_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-Fo1_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-Fo2_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-Fo3_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-Fo4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-Fo5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-Fo6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-Fo7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-Fp1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-Fp2_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-IFJ1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-IFJ2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-IFS1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-IFS2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-IFS3_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-IFS4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-Ia1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-Ia2_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-Ia3_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-Id1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-Id10_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-Id2_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-Id3_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-Id4_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-Id5_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-Id6_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-Id7_PM-v8.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-Id8_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-Id9_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-Ig1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-Ig2_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-Ig3_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-MFG1_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-MFG2_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-OP1_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-OP2_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-OP3_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-OP4_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-OP5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-OP6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-OP7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-OP8_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-OP9_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-PF_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-PFcm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-PFm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-PFop_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-PFt_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-PGa_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-PGp_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-Ph1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-Ph2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-Ph3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-SFS1_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-SFS2_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-STS1_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-STS2_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-TE-1.0_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-TE-1.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-TE-1.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-TE-2.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-TE-2.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-TE-3_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-TI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-TPJ_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-TeI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-hIP1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-hIP2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-hIP3_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-hIP4_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-hIP5_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-hIP6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-hIP7_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-hIP8_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-hOc1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-hOc2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-hOc3d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-hOc3v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-hOc4d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-hOc4la_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-hOc4lp_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-hOc4v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-hOc5_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-hOc6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-hPO1_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-p24ab_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-p24ab.p24a_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-p24ab.p24b_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-p24c_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-p24c.pd24cd_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-p24c.pd24cv_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-p24c.pv24c_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-p32_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-s24_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-s24.s24a_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-s24.s24b_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Area-s32_PM-v20.1"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_BST_PM-v6.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_CA1_PM-v13.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_CA2_PM-v13.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_CA3_PM-v13.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_CGL_PM-v10.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_CGM_PM-v10.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_CM_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_CM.AAA_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_CM.Ce_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_CM.Me_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Ch-123_PM-v4.3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Ch-4_PM-v4.3"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_DG_PM-v13.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Dorsal-Dentate-Nucleus_PM-v6.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Entorhinal-Cortex_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Fastigial-Nucleus_PM-v6.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Frontal-I_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Frontal-II_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Frontal-to-Occipital_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Frontal-to-Temporal-I_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Frontal-to-Temporal-II_PM-v11.4"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_FuCd_PM-v5.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_FuP_PM-v5.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_HATA_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_HC-Transsubiculum_PM-v13.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_IF_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_IF.ice_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_IF.iol_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_IF.ld_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Interposed-Nucleus_PM-v6.3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_LB_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_LB.Bl_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_LB.Bm_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_LB.La_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_LB.Pl_PM-v8.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_MF_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_MF.icm_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_MF.lm_PM-v8.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_SF_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_SF.AHi_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_SF.APir_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_SF.VCo_PM-v8.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_STN_PM-v5.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Subiculum.PaS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Subiculum.PreS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Subiculum.ProS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Subiculum.Sub_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Temporal-to-Parietal_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Terminal-islands_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Tuberculum_PM-v4.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_VP_PM-v5.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_VTM_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.2-MNI152_Ventral-Dentate-Nucleus_PM-v6.3"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2022)](https://doi.org/10.25493/TMQ3-0EP).",
    is_alternative_version_of=[
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.2-BigBrain"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.2-Colin27"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.2-fsaverage"},
    ],
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.1-MNI152"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v3.0.2",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/probabilisticAtlas"},
    version_identifier="v3.0.2, MNI152",
)
BrainAtlasVersion.jba_v3_0_3__big_brain = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.3-BigBrain",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/BigBrain_2015"},
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_Area-6d1_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_Area-6d2_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_Area-6d3_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_Area-6ma_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_Area-MFG1_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_Area-MFG2_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_Area-SFS1_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_Area-SFS2_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_Area-STS1_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_Area-STS2_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_Area-TE-1.0_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_Area-TE-1.1_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_Area-TE-1.2_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_Area-TE-3_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_Area-hIP4_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_Area-hIP5_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_Area-hIP6_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_Area-hIP7_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_Area-hIP8_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_Area-hOc1_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_Area-hOc2_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_Area-hOc3v_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_Area-hOc5_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_Area-hOc6_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_Area-hPO1_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_CGM.CGMd_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_CGM.CGMm_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_CGM.CGMv_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-BigBrain_Entorhinal-Cortex_int"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2023)](https://doi.org/10.25493/56EM-75H).",
    is_alternative_version_of=[
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.3-Colin27"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.3-fsaverage"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.3-MNI152"},
    ],
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.2-BigBrain"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v3.0.3",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/deterministicAtlas"},
    version_identifier="v3.0.3, BigBrain",
)
BrainAtlasVersion.jba_v3_0_3__colin27 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.3-Colin27",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/MNI-Colin27_1998"},
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_AcbL_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_AcbM_PM-v5.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-1_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-25_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-25.25a_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-25.25p_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-33_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-3a_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-3b_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-44_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-45_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-4a_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-4p_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-5Ci_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-5L_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-5M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-6d1_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-6d2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-6d3_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-6ma_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-6mp_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-7A_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-7M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-7P_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-7PC_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-8d1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-8d2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-8v1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-8v2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-CoS1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-FG1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-FG2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-FG3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-FG4_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-Fo1_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-Fo2_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-Fo3_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-Fo4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-Fo5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-Fo6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-Fo7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-Fp1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-Fp2_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-IFJ1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-IFJ2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-IFS1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-IFS2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-IFS3_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-IFS4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-Ia1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-Ia2_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-Ia3_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-Id1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-Id10_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-Id2_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-Id3_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-Id4_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-Id5_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-Id6_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-Id7_PM-v8.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-Id8_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-Id9_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-Ig1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-Ig2_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-Ig3_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-MFG1_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-MFG2_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-OP1_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-OP2_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-OP3_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-OP4_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-OP5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-OP6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-OP7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-OP8_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-OP9_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-PF_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-PFcm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-PFm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-PFop_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-PFt_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-PGa_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-PGp_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-Ph1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-Ph2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-Ph3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-SFS1_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-SFS2_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-STS1_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-STS2_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-TE-1.0_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-TE-1.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-TE-1.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-TE-2.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-TE-2.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-TE-3_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-TI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-TPJ_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-TeI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-hIP1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-hIP2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-hIP3_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-hIP4_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-hIP5_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-hIP6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-hIP7_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-hIP8_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-hOc1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-hOc2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-hOc3d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-hOc3v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-hOc4d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-hOc4la_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-hOc4lp_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-hOc4v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-hOc5_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-hOc6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-hPO1_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-p24ab_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-p24ab.p24a_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-p24ab.p24b_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-p24c_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-p24c.pd24cd_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-p24c.pd24cv_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-p24c.pv24c_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-p32_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-s24_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-s24.s24a_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-s24.s24b_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Area-s32_PM-v20.1"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_BST_PM-v6.1"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_CA1_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_CA2_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_CA3_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_CGL_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_CGM_PM-v10.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_CM_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_CM.AAA_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_CM.Ce_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_CM.Me_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Ch-123_PM-v4.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Ch-4_PM-v4.3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_DG_PM-v13.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Dorsal-Dentate-Nucleus_PM-v6.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Entorhinal-Cortex_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Fastigial-Nucleus_PM-v6.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Frontal-I_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Frontal-II_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Frontal-to-Occipital_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Frontal-to-Temporal-I_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Frontal-to-Temporal-II_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_FuCd_PM-v5.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_FuP_PM-v5.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_HATA_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_HC-Transsubiculum_PM-v13.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_IF_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_IF.ice_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_IF.iol_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_IF.ld_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Interposed-Nucleus_PM-v6.3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_LB_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_LB.Bl_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_LB.Bm_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_LB.La_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_LB.Pl_PM-v8.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_MF_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_MF.icm_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_MF.lm_PM-v8.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_SF_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_SF.AHi_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_SF.APir_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_SF.VCo_PM-v8.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_STN_PM-v5.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Subiculum.PaS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Subiculum.PreS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Subiculum.ProS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Subiculum.Sub_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Temporal-to-Parietal_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Terminal-islands_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Tuberculum_PM-v4.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_VP_PM-v5.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_VTM_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-Colin27_Ventral-Dentate-Nucleus_PM-v6.3"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2023)](https://doi.org/10.25493/56EM-75H).",
    is_alternative_version_of=[
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.3-BigBrain"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.3-fsaverage"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.3-MNI152"},
    ],
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.2-Colin27"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v3.0.3",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/probabilisticAtlas"},
    version_identifier="v3.0.3, Colin27",
)
BrainAtlasVersion.jba_v3_0_3_fsaverage = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.3-fsaverage",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/fsaverage_7"},
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-1_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-25_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-33_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-3a_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-3b_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-44_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-45_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-4a_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-4p_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-5Ci_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-5L_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-5M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-6d1_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-6d2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-6d3_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-6ma_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-6mp_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-7A_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-7M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-7P_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-7PC_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-8d1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-8d2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-8v1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-8v2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-CoS1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-FG1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-FG2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-FG3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-FG4_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-Fo1_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-Fo2_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-Fo3_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-Fo4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-Fo5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-Fo6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-Fo7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-Fp1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-Fp2_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-IFJ1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-IFJ2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-IFS1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-IFS2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-IFS3_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-IFS4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-Ia1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-Ia2_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-Ia3_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-Id1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-Id10_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-Id2_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-Id3_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-Id4_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-Id5_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-Id6_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-Id7_PM-v8.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-Id8_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-Id9_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-Ig1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-Ig2_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-Ig3_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-MFG1_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-MFG2_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-OP1_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-OP2_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-OP3_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-OP4_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-OP5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-OP6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-OP7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-OP8_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-OP9_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-PF_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-PFcm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-PFm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-PFop_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-PFt_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-PGa_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-PGp_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-Ph1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-Ph2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-Ph3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-SFS1_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-SFS2_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-STS1_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-STS2_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-TE-1.0_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-TE-1.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-TE-1.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-TE-2.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-TE-2.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-TE-3_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-TI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-TPJ_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-TeI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-hIP1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-hIP2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-hIP3_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-hIP4_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-hIP5_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-hIP6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-hIP7_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-hIP8_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-hOc1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-hOc2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-hOc3d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-hOc3v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-hOc4d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-hOc4la_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-hOc4lp_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-hOc4v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-hOc5_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-hOc6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-hPO1_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-p24ab_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-p24c_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-p32_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-s24_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Area-s32_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_CA1_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_CA2_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_CA3_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_CGL_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_CGM_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_DG_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Entorhinal-Cortex_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Frontal-I_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Frontal-II_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Frontal-to-Occipital_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Frontal-to-Temporal-I_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Frontal-to-Temporal-II_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_HATA_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_HC-Transsubiculum_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Subiculum.PaS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Subiculum.PreS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Subiculum.ProS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Subiculum.Sub_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Temporal-to-Parietal_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-fsaverage_Tuberculum_PM-v4.0"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2023)](https://doi.org/10.25493/56EM-75H).",
    is_alternative_version_of=[
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.3-BigBrain"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.3-Colin27"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.3-MNI152"},
    ],
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.2-fsaverage"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v3.0.3",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/probabilisticAtlas"},
    version_identifier="v3.0.3, fsaverage",
)
BrainAtlasVersion.jba_v3_0_3_mni152 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.3-MNI152",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={
        "@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/MNI-ICBM152_nonlinear-2009c-asym"
    },
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_AcbL_PM-v5.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_AcbM_PM-v5.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-1_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-25_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-25.25a_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-25.25p_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-33_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-3a_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-3b_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-44_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-45_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-4a_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-4p_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-5Ci_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-5L_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-5M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-6d1_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-6d2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-6d3_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-6ma_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-6mp_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-7A_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-7M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-7P_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-7PC_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-8d1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-8d2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-8v1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-8v2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-CoS1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-FG1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-FG2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-FG3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-FG4_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-Fo1_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-Fo2_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-Fo3_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-Fo4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-Fo5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-Fo6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-Fo7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-Fp1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-Fp2_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-IFJ1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-IFJ2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-IFS1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-IFS2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-IFS3_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-IFS4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-Ia1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-Ia2_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-Ia3_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-Id1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-Id10_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-Id2_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-Id3_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-Id4_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-Id5_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-Id6_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-Id7_PM-v8.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-Id8_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-Id9_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-Ig1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-Ig2_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-Ig3_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-MFG1_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-MFG2_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-OP1_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-OP2_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-OP3_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-OP4_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-OP5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-OP6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-OP7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-OP8_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-OP9_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-PF_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-PFcm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-PFm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-PFop_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-PFt_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-PGa_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-PGp_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-Ph1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-Ph2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-Ph3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-SFS1_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-SFS2_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-STS1_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-STS2_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-TE-1.0_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-TE-1.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-TE-1.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-TE-2.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-TE-2.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-TE-3_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-TI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-TPJ_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-TeI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-hIP1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-hIP2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-hIP3_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-hIP4_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-hIP5_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-hIP6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-hIP7_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-hIP8_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-hOc1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-hOc2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-hOc3d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-hOc3v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-hOc4d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-hOc4la_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-hOc4lp_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-hOc4v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-hOc5_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-hOc6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-hPO1_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-p24ab_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-p24ab.p24a_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-p24ab.p24b_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-p24c_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-p24c.pd24cd_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-p24c.pd24cv_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-p24c.pv24c_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-p32_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-s24_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-s24.s24a_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-s24.s24b_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Area-s32_PM-v20.1"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_BST_PM-v6.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_CA1_PM-v13.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_CA2_PM-v13.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_CA3_PM-v13.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_CGL_PM-v10.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_CGM_PM-v10.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_CM_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_CM.AAA_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_CM.Ce_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_CM.Me_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Ch-123_PM-v4.3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Ch-4_PM-v4.3"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_DG_PM-v13.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Dorsal-Dentate-Nucleus_PM-v6.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Entorhinal-Cortex_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Fastigial-Nucleus_PM-v6.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Frontal-I_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Frontal-II_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Frontal-to-Occipital_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Frontal-to-Temporal-I_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Frontal-to-Temporal-II_PM-v11.4"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_FuCd_PM-v5.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_FuP_PM-v5.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_HATA_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_HC-Transsubiculum_PM-v13.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_IF_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_IF.ice_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_IF.iol_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_IF.ld_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Interposed-Nucleus_PM-v6.3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_LB_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_LB.Bl_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_LB.Bm_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_LB.La_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_LB.Pl_PM-v8.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_MF_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_MF.icm_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_MF.lm_PM-v8.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_SF_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_SF.AHi_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_SF.APir_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_SF.VCo_PM-v8.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_STN_PM-v5.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Subiculum.PaS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Subiculum.PreS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Subiculum.ProS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Subiculum.Sub_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Temporal-to-Parietal_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Terminal-islands_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Tuberculum_PM-v4.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_VP_PM-v5.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_VTM_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0.3-MNI152_Ventral-Dentate-Nucleus_PM-v6.3"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2023)](https://doi.org/10.25493/56EM-75H).",
    is_alternative_version_of=[
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.3-BigBrain"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.3-Colin27"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.3-fsaverage"},
    ],
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0.2-MNI152"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v3.0.3",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/probabilisticAtlas"},
    version_identifier="v3.0.3, MNI152",
)
BrainAtlasVersion.jba_v3_0__big_brain = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0-BigBrain",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/BigBrain_2015"},
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_Area-6d1_int"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_Area-6d2_int"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_Area-6d3_int"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_Area-6ma_int"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_Area-MFG1_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_Area-MFG2_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_Area-SFS1_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_Area-SFS2_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_Area-STS1_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_Area-STS2_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_Area-TE-1.0_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_Area-TE-1.1_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_Area-TE-1.2_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_Area-TE-3_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_Area-hIP4_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_Area-hIP5_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_Area-hIP6_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_Area-hIP7_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_Area-hIP8_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_Area-hOc1_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_Area-hOc2_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_Area-hOc3v_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_Area-hOc5_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_Area-hOc6_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_Area-hPO1_int"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_CGM.CGMd_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_CGM.CGMm_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_CGM.CGMv_deep"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-BigBrain_Entorhinal-Cortex_int"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2022)](https://doi.org/10.25493/MGKP-Z5T).",
    is_alternative_version_of=[
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0-Colin27"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0-fsaverage"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0-MNI152"},
    ],
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.9-BigBrain"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v3.0",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/deterministicAtlas"},
    version_identifier="v3.0, BigBrain",
)
BrainAtlasVersion.jba_v3_0__colin27 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0-Colin27",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/MNI-Colin27_1998"},
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_AcbL_PM-v5.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_AcbM_PM-v5.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-1_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-25_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-25.25a_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-25.25p_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-33_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-3a_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-3b_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-44_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-45_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-4a_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-4p_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-5Ci_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-5L_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-5M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-6d1_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-6d2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-6d3_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-6ma_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-6mp_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-7A_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-7M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-7P_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-7PC_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-8d1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-8d2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-8v1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-8v2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-CoS1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-FG1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-FG2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-FG3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-FG4_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-Fo1_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-Fo2_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-Fo3_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-Fo4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-Fo5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-Fo6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-Fo7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-Fp1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-Fp2_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-IFJ1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-IFJ2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-IFS1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-IFS2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-IFS3_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-IFS4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-Ia1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-Ia2_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-Ia3_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-Id1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-Id10_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-Id2_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-Id3_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-Id4_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-Id5_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-Id6_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-Id7_PM-v8.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-Id8_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-Id9_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-Ig1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-Ig2_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-Ig3_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-MFG1_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-MFG2_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-OP1_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-OP2_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-OP3_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-OP4_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-OP5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-OP6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-OP7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-OP8_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-OP9_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-PF_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-PFcm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-PFm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-PFop_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-PFt_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-PGa_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-PGp_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-Ph1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-Ph2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-Ph3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-SFS1_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-SFS2_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-STS1_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-STS2_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-TE-1.0_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-TE-1.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-TE-1.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-TE-2.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-TE-2.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-TE-3_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-TI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-TPJ_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-TeI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-hIP1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-hIP2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-hIP3_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-hIP4_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-hIP5_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-hIP6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-hIP7_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-hIP8_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-hOc1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-hOc2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-hOc3d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-hOc3v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-hOc4d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-hOc4la_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-hOc4lp_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-hOc4v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-hOc5_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-hOc6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-hPO1_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-p24ab_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-p24ab.p24a_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-p24ab.p24b_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-p24c_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-p24c.pd24cd_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-p24c.pd24cv_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-p24c.pv24c_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-p32_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-s24_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-s24.s24a_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-s24.s24b_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Area-s32_PM-v20.1"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_BST_PM-v6.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_CA1_PM-v13.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_CA2_PM-v13.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_CA3_PM-v13.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_CGL_PM-v10.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_CGM_PM-v10.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_CM_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_CM.AAA_PM-v8.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_CM.Ce_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_CM.Me_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Ch-123_PM-v4.3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Ch-4_PM-v4.3"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_DG_PM-v13.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Dorsal-Dentate-Nucleus_PM-v6.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Entorhinal-Cortex_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Fastigial-Nucleus_PM-v6.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Frontal-I_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Frontal-II_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Frontal-to-Occipital_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Frontal-to-Temporal-I_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Frontal-to-Temporal-II_PM-v11.4"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_FuCd_PM-v5.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_FuP_PM-v5.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_HATA_PM-v13.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_HC-Transsubiculum_PM-v13.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_IF_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_IF.ice_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_IF.iol_PM-v8.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_IF.ld_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Interposed-Nucleus_PM-v6.3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_LB_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_LB.Bl_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_LB.Bm_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_LB.La_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_LB.Pl_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_MF_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_MF.icm_PM-v8.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_MF.lm_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_SF_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_SF.AHi_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_SF.APir_PM-v8.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_SF.VCo_PM-v8.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_STN_PM-v5.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Subiculum.PaS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Subiculum.PreS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Subiculum.ProS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Subiculum.Sub_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Temporal-to-Parietal_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Terminal-islands_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Tuberculum_PM-v4.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_VP_PM-v5.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_VTM_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-Colin27_Ventral-Dentate-Nucleus_PM-v6.3"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2022)](https://doi.org/10.25493/MGKP-Z5T).",
    is_alternative_version_of=[
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0-BigBrain"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0-fsaverage"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0-MNI152"},
    ],
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.9-Colin27"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v3.0",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/probabilisticAtlas"},
    version_identifier="v3.0, Colin27",
)
BrainAtlasVersion.jba_v3_0_fsaverage = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0-fsaverage",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/fsaverage_7"},
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-1_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-25_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-33_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-3a_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-3b_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-44_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-45_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-4a_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-4p_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-5Ci_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-5L_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-5M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-6d1_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-6d2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-6d3_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-6ma_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-6mp_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-7A_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-7M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-7P_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-7PC_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-8d1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-8d2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-8v1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-8v2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-CoS1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-FG1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-FG2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-FG3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-FG4_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-Fo1_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-Fo2_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-Fo3_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-Fo4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-Fo5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-Fo6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-Fo7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-Fp1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-Fp2_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-IFJ1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-IFJ2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-IFS1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-IFS2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-IFS3_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-IFS4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-Ia1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-Ia2_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-Ia3_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-Id1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-Id10_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-Id2_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-Id3_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-Id4_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-Id5_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-Id6_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-Id7_PM-v8.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-Id8_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-Id9_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-Ig1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-Ig2_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-Ig3_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-MFG1_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-MFG2_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-OP1_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-OP2_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-OP3_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-OP4_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-OP5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-OP6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-OP7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-OP8_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-OP9_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-PF_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-PFcm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-PFm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-PFop_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-PFt_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-PGa_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-PGp_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-Ph1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-Ph2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-Ph3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-SFS1_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-SFS2_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-STS1_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-STS2_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-TE-1.0_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-TE-1.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-TE-1.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-TE-2.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-TE-2.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-TE-3_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-TI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-TPJ_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-TeI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-hIP1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-hIP2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-hIP3_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-hIP4_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-hIP5_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-hIP6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-hIP7_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-hIP8_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-hOc1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-hOc2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-hOc3d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-hOc3v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-hOc4d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-hOc4la_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-hOc4lp_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-hOc4v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-hOc5_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-hOc6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-hPO1_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-p24ab_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-p24c_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-p32_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-s24_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Area-s32_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_CA1_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_CA2_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_CA3_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_CGL_PM-v10.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_CGM_PM-v10.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_DG_PM-v13.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Entorhinal-Cortex_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Frontal-I_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Frontal-II_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Frontal-to-Occipital_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Frontal-to-Temporal-I_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Frontal-to-Temporal-II_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_HATA_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_HC-Transsubiculum_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Subiculum.PaS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Subiculum.PreS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Subiculum.ProS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Subiculum.Sub_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Temporal-to-Parietal_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-fsaverage_Tuberculum_PM-v4.0"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2022)](https://doi.org/10.25493/MGKP-Z5T).",
    is_alternative_version_of=[
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0-BigBrain"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0-Colin27"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0-MNI152"},
    ],
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.9-fsaverage"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v3.0",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/probabilisticAtlas"},
    version_identifier="v3.0, fsaverage",
)
BrainAtlasVersion.jba_v3_0_mni152 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0-MNI152",
    abbreviation="JBA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={
        "@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/MNI-ICBM152_nonlinear-2009c-asym"
    },
    full_name="Julich-Brain Cytoarchitectonic Atlas",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_AcbL_PM-v5.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_AcbM_PM-v5.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-1_PM-v12.1"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-2_PM-v7.1"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-25_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-25.25a_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-25.25p_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-33_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-3a_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-3b_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-44_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-45_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-4a_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-4p_PM-v13.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-5Ci_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-5L_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-5M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-6d1_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-6d2_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-6d3_PM-v7.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-6ma_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-6mp_PM-v12.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-7A_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-7M_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-7P_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-7PC_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-8d1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-8d2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-8v1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-8v2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-CoS1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-FG1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-FG2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-FG3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-FG4_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-Fo1_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-Fo2_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-Fo3_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-Fo4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-Fo5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-Fo6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-Fo7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-Fp1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-Fp2_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-IFJ1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-IFJ2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-IFS1_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-IFS2_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-IFS3_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-IFS4_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-Ia1_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-Ia2_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-Ia3_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-Id1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-Id10_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-Id2_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-Id3_PM-v9.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-Id4_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-Id5_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-Id6_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-Id7_PM-v8.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-Id8_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-Id9_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-Ig1_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-Ig2_PM-v14.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-Ig3_PM-v5.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-MFG1_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-MFG2_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-OP1_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-OP2_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-OP3_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-OP4_PM-v12.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-OP5_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-OP6_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-OP7_PM-v3.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-OP8_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-OP9_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-PF_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-PFcm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-PFm_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-PFop_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-PFt_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-PGa_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-PGp_PM-v11.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-Ph1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-Ph2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-Ph3_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-SFS1_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-SFS2_PM-v9.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-STS1_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-STS2_PM-v5.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-TE-1.0_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-TE-1.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-TE-1.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-TE-2.1_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-TE-2.2_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-TE-3_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-TI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-TPJ_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-TeI_PM-v6.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-hIP1_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-hIP2_PM-v7.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-hIP3_PM-v9.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-hIP4_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-hIP5_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-hIP6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-hIP7_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-hIP8_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-hOc1_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-hOc2_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-hOc3d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-hOc3v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-hOc4d_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-hOc4la_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-hOc4lp_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-hOc4v_PM-v5.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-hOc5_PM-v4.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-hOc6_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-hPO1_PM-v7.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-p24ab_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-p24ab.p24a_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-p24ab.p24b_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-p24c_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-p24c.pd24cd_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-p24c.pd24cv_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-p24c.pv24c_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-p32_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-s24_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-s24.s24a_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-s24.s24b_PM-v20.1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Area-s32_PM-v20.1"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_BST_PM-v6.1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_CA1_PM-v13.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_CA2_PM-v13.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_CA3_PM-v13.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_CGL_PM-v10.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_CGM_PM-v10.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_CM_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_CM.AAA_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_CM.Ce_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_CM.Me_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Ch-123_PM-v4.3"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Ch-4_PM-v4.3"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_DG_PM-v13.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Dorsal-Dentate-Nucleus_PM-v6.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Entorhinal-Cortex_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Fastigial-Nucleus_PM-v6.3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Frontal-I_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Frontal-II_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Frontal-to-Occipital_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Frontal-to-Temporal-I_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Frontal-to-Temporal-II_PM-v11.4"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_FuCd_PM-v5.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_FuP_PM-v5.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_HATA_PM-v13.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_HC-Transsubiculum_PM-v13.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_IF_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_IF.ice_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_IF.iol_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_IF.ld_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Interposed-Nucleus_PM-v6.3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_LB_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_LB.Bl_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_LB.Bm_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_LB.La_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_LB.Pl_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_MF_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_MF.icm_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_MF.lm_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_SF_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_SF.AHi_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_SF.APir_PM-v8.2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_SF.VCo_PM-v8.2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_STN_PM-v5.0"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Subiculum.PaS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Subiculum.PreS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Subiculum.ProS_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Subiculum.Sub_PM-v13.2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Temporal-to-Parietal_PM-v11.4"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Terminal-islands_PM-v4.0"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Tuberculum_PM-v4.0"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_VP_PM-v5.0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_VTM_PM-v8.2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/JBA_v3.0-MNI152_Ventral-Dentate-Nucleus_PM-v6.3"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://julich-brain-atlas.de/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_023277](https://scicrunch.org/resolver/SCR_023277), and cite the following publications: [Amunts and Zilles (2015)](https://doi.org/10.1016/j.neuron.2015.12.001); [Amunts et al. (2020)](https://doi.org/10.1126/science.abb4588), [Amunts et al. (2022)](https://doi.org/10.25493/MGKP-Z5T).",
    is_alternative_version_of=[
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0-BigBrain"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0-Colin27"},
        {"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v3.0-fsaverage"},
    ],
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/JBA_v2.9-MNI152"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    major_version_identifier="v3.0",
    short_name="Julich-Brain Atlas",
    support_channels=["julich-brain@fz-juelich.de"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/probabilisticAtlas"},
    version_identifier="v3.0, MNI152",
)
BrainAtlasVersion.schaefer_400p_2018_fs_lr32k_kong17n = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/Schaefer-400p_2018-fsLR32k-kong17n",
    abbreviation="Schaefer-400p",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/fsLR_32k"},
    full_name="Schaefer Atlas with 400 Parcellation",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": None,
        "ontologyIdentifier": None,
    },
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/mit"},
    major_version_identifier="2018",
    short_name="Schaefer Atlas (400p)",
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/deterministicAtlas"},
    version_identifier="2018, fsLR32k, kong17n",
)
BrainAtlasVersion.schaefer_400p_2018_fs_lr32k_yeo17n = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/Schaefer-400p_2018-fsLR32k-yeo17n",
    abbreviation="Schaefer-400p",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/fsLR_32k"},
    full_name="Schaefer Atlas with 400 Parcellation",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": None,
        "ontologyIdentifier": None,
    },
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/mit"},
    major_version_identifier="2018",
    short_name="Schaefer Atlas (400p)",
    version_identifier="2018, fsLR32k, yeo17n",
)
BrainAtlasVersion.schaefer_400p_2018_fs_lr32k_yeo7n = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/Schaefer-400p_2018-fsLR32k-yeo7n",
    abbreviation="Schaefer-400p",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/fsLR_32k"},
    full_name="Schaefer Atlas with 400 Parcellation",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": None,
        "ontologyIdentifier": None,
    },
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/mit"},
    major_version_identifier="2018",
    short_name="Schaefer Atlas (400p)",
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/deterministicAtlas"},
    version_identifier="2018, fsLR32k, yeo7n",
)
BrainAtlasVersion.schaefer_400p_2018_fsl_mni152_kong17n = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/Schaefer-400p_2018-FSL-MNI152-kong17n",
    abbreviation="Schaefer-400p",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    full_name="Schaefer Atlas with 400 Parcellation",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": None,
        "ontologyIdentifier": None,
    },
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/mit"},
    major_version_identifier="2018",
    short_name="Schaefer Atlas (400p)",
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/deterministicAtlas"},
    version_identifier="2018, FSL-MNI152, kong17n",
)
BrainAtlasVersion.schaefer_400p_2018_fsl_mni152_yeo17n = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/Schaefer-400p_2018-FSL-MNI152-yeo17n",
    abbreviation="Schaefer-400p",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    full_name="Schaefer Atlas with 400 Parcellation",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": None,
        "ontologyIdentifier": None,
    },
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/mit"},
    major_version_identifier="2018",
    short_name="Schaefer Atlas (400p)",
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/deterministicAtlas"},
    version_identifier="2018, FSL-MNI152, yeo17n",
)
BrainAtlasVersion.schaefer_400p_2018_fsl_mni152_yeo7n = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/Schaefer-400p_2018-FSL-MNI152-yeo7n",
    abbreviation="Schaefer-400p",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    full_name="Schaefer Atlas with 400 Parcellation",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": None,
        "ontologyIdentifier": None,
    },
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/mit"},
    major_version_identifier="2018",
    short_name="Schaefer Atlas (400p)",
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/deterministicAtlas"},
    version_identifier="2018, FSL-MNI152, yeo7n",
)
BrainAtlasVersion.swma_2018 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/SWMA_2018",
    abbreviation="SWMA",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={
        "@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpaceVersion/MNI-ICBM152_nonlinear-2009c-asym"
    },
    full_name="Atlas of Superficial White Matter Fibre Bundles",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_CAC-PoCi_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_CAC-PrCu_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_CMF-Op_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_CMF-PoC_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_CMF-PrC_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_CMF-PrC_1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_CMF-RMF_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_CMF-SF_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_CMF-SF_1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_Cu-Li_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_Fu-LO_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_Fu-LO_1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_IC-PrCu_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_IP-IT_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_IP-LO_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_IP-LO_1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_IP-MT_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_IP-SM_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_IP-SP_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_IP-SP_1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_IT-MT_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_IT-MT_1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_IT-MT_2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_LO-SP_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_LOF-MOF_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_LOF-Or_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_LOF-RMF_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_LOF-RMF_1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_LOF-ST_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_MOF-ST_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_MT-SM_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_MT-ST_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_Op-Ins_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_Op-PrC_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_Op-SF_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_Op-Tr_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_Or-Ins_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_PoC-Ins_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_PoC-PrC_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_PoC-PrC_1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_PoC-PrC_2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_PoC-PrC_3"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_PoC-SM_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_PoC-SM_1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_PoC-SP_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_PoC-SP_1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_PoCi-PrCu_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_PoCi-PrCu_1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_PoCi-PrCu_2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_PoCi-RAC_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_PoCi-SF_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_PrC-Ins_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_PrC-SF_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_PrC-SM_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_PrC-SP_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_RAC-SF_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_RAC-SF_1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_RMF-SF_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_RMF-SF_1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_SM-Ins_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_SP-SM_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_ST-Ins_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_ST-TT_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_Tr-Ins_0"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/SWMA_2018_Tr-SF_0"},
        ],
        "ontologyIdentifier": None,
    },
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccByNcSa4.0"},
    short_name="Superficial White Matter Atlas",
    version_identifier="2018",
    version_innovation="This is the first released version of this brain atlas.",
)
BrainAtlasVersion.whss_datlas_v1_01 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/WHSSDatlas_v1.01",
    abbreviation="WHSSDatlas",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpace/WHSSD_v1.01"},
    full_documentation={"@id": "https://doi.org/10.1016/j.neuroimage.2014.10.017"},
    full_name="Waxholm Space Atlas of the Sprague Dawley Rat Brain",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_descendingCorticofugalPathways"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_substantiaNigra"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_subthalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_molecularCellLayerOfTheCerebellum"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_deeperCerebellum"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_alveusOfTheHippocampus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_inferiorCerebellarPeduncle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_cingulateCortexArea2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_dorsallateralEntorhinalArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_dorsalintermediateEntorhinalArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_perirhinalCortex"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_striatum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_globusPallidus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_entopeduncularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_ventricularSystem"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_medialLemniscus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_facialNerve"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_anteriorCommissureAnteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_anteriorCommissurePosteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_ventralHippocampalCommissure"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_thalamus"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_septalRegion"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_opticNerve"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_opticTractAndOpticChiasm"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_pinealGland"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_innerEar"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_spinalCord"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_commissureOfTheSuperiorColliculus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_brainstem"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_hypothalamicRegion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_inferiorColliculus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_superficialGrayLayerOfTheSuperiorColliculus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_periaqueductalGray"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_fornix"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_mammillothalamicTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_commissuralStriaTerminalis"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_deeperLayersOfTheSuperiorColliculus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_periventricularGray"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_genuOfTheFacialNerve"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_pontineNuclei"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_fimbriaOfTheHippocampus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_fasciculusRetroflexus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_striaMedullarisOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_striaTerminalis"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_posteriorCommissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_glomerularLayerOfTheAccessoryOlfactoryBulb"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_glomerularLayerOfTheOlfactoryBulb"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_olfactoryBulb"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_corpusCallosumAndAssociatedSubcorticalWhiteMatter"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_brachiumOfTheSuperiorColliculus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_commissureOfTheInferiorColliculus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_centralCanal"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_interpeduncularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_ascendingFibersOfTheFacialNerve"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_anteriorCommissureIntrabulbarPart"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_inferiorOlive"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_spinalTrigeminalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_spinalTrigeminalTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_frontalAssociationCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_middleCerebellarPeduncle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_transverseFibersOfThePons"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_habenularCommissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_nucleusOfTheStriaMedullaris"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_basalForebrainRegion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_supraopticDecussation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_medialLemniscusDecussation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_pyramidalDecussation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_hippocampalFormation"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_subiculum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_postrhinalCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_ventralintermediateEntorhinalArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_medialEntorhinalField"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_caudalEntorhinalField"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_neocortex"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_bedNucleusOfTheStriaTerminalis"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v1.01_pretectalRegion"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://www.nitrc.org/projects/whs-sd-atlas/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_001592](https://scicrunch.org/resolver/SCR_001592), and cite the following publications: [Papp et al. (2014)](https://doi.org/10.1016/j.neuroimage.2014.04.001); [Papp et al. (2015)](https://doi.org/10.1016/j.neuroimage.2014.10.017).",
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccBy4.0"},
    related_publications=[{"@id": "https://doi.org/10.1016/j.neuroimage.2014.04.001"}],
    release_date="2014-07-17",
    short_name="Waxholm Space Rat Brain Atlas",
    support_channels=["support@ebrains.eu", "https://www.nitrc.org/forum/forum.php?forum_id=9174"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/deterministicAtlas"},
    version_identifier="v1.01",
    version_innovation="Anatomical delineations of 76 major brain regions and white matter tracts in the Sprague Dawley rat brain, based on observations in a high resolution magnetic resonance imaging (MRI) volume (DOI: 10.25493/DTSG-ZBS). This dataset is hosted on NITRC.org and includes: WHS_SD_rat_atlas_v1.01.nii.gz: delineation file with anatomical structures; WHS_SD_rat_atlas_v1.label: text file naming the anatomical structures; MBAT_WHS_SD_rat_atlas_v1.01.zip: files describing a suggested hierarchical organization of the anatomical structures. Note: The licence was changed to from CC BY-SA-NC to CC BY-SA on October 1, 2021.",
)
BrainAtlasVersion.whss_datlas_v2 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/WHSSDatlas_v2",
    abbreviation="WHSSDatlas",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpace/WHSSD_v1.01"},
    full_documentation={"@id": "https://doi.org/10.1016/j.neuroimage.2014.12.080"},
    full_name="Waxholm Space Atlas of the Sprague Dawley Rat Brain",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_descendingCorticofugalPathways"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_substantiaNigra"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_subthalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_molecularLayerOfTheCerebellum"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_granuleCellLevelOfTheCerebellum"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_alveusOfTheHippocampus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_inferiorCerebellarPeduncle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_cingulateCortexArea2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_striatum"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_globusPallidus"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_entopeduncularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_ventricularSystem"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_medialLemniscus"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_facialNerve"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_anteriorCommissureAnteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_anteriorCommissurePosteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_ventralHippocampalCommissure"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_thalamus"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_septalRegion"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_opticNerve"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_opticTractAndOpticChiasm"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_pinealGland"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_innerEar"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_spinalCord"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_commissureOfTheSuperiorColliculus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_brainstem"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_hypothalamicRegion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_inferiorColliculus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_superficialGrayLayerOfTheSuperiorColliculus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_periaqueductalGray"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_fornix"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_mammillothalamicTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_commissuralStriaTerminalis"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_deeperLayersOfTheSuperiorColliculus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_periventricularGray"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_genuOfTheFacialNerve"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_pontineNuclei"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_fimbriaOfTheHippocampus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_fasciculusRetroflexus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_striaMedullarisOfTheThalamus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_striaTerminalis"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_posteriorCommissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_glomerularLayerOfTheAccessoryOlfactoryBulb"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_glomerularLayerOfTheOlfactoryBulb"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_olfactoryBulb"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_corpusCallosumAndAssociatedSubcorticalWhiteMatter"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_brachiumOfTheSuperiorColliculus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_commissureOfTheInferiorColliculus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_centralCanal"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_interpeduncularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_ascendingFibersOfTheFacialNerve"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_anteriorCommissure"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_inferiorOlive"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_spinalTrigeminalNuclus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_spinalTrigeminalTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_frontalAssociiationCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_middleCerebellarPeduncle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_transverseFibersOfThePons"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_habenularCommissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_nucleusOfTheStriaMedullaris"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_basalForebrainRegion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_supraopticDecussation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_medialLemniscusDecussation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_pyramidalDecussation"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_neocortex"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_bedNucleusOfTheStriaTerminalis"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_pretectalRegion"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_cornuAmmonis3"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_dentateGyrus"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_cornuAmmonis2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_cornuAmmonis1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_fasciolaCinereum"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_subiculum"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_postrhinalCortex"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_presubiculum"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_parasubiculum"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_perirhinalArea35"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_perirhinalArea36"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_entorhinalCortex"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v2_lateralEntorhinalCortex"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://www.nitrc.org/projects/whs-sd-atlas/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_001592](https://scicrunch.org/resolver/SCR_001592), and cite the following publications: [Papp et al. (2014)](https://doi.org/10.1016/j.neuroimage.2014.04.001); [Kjonigsen et al. (2015)](https://doi.org/10.1016/j.neuroimage.2014.12.080).",
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/WHSSDatlas_v1.01"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccBy4.0"},
    related_publications=[
        {"@id": "https://doi.org/10.1016/j.neuroimage.2014.04.001"},
        {"@id": "https://doi.org/10.1016/j.neuroimage.2014.10.017"},
    ],
    release_date="2015-02-02",
    short_name="Waxholm Space Rat Brain Atlas",
    support_channels=["support@ebrains.eu", "https://www.nitrc.org/forum/forum.php?forum_id=9174"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/deterministicAtlas"},
    version_identifier="v2",
    version_innovation="Anatomical delineations of 79 brain regions and white matter tracts in the Sprague Dawley rat brain, based on observations in a high resolution magnetic resonance imaging (MRI) volume (DOI: 10.25493/DTSG-ZBS). Version 2 of the Waxholm Space atlas of the Sprague Dawley rat brain contains 13 new and updated delineations of the hippocampal formation and parahippocampal region, and 66 structure delineations unchanged relative to v1.01. This dataset is hosted on NITRC.org and includes: WHS_SD_rat_atlas_v2.nii.gz: delineation file with anatomical structures; WHS_SD_rat_atlas_v2.label: text file naming anatomical structures; MBAT_WHS_SD_rat_atlas_v2.zip: file describing a suggested hierarchy of the anatomical structures. Note: The licence was changed to from CC BY-SA-NC to CC BY-SA on October 1, 2021.",
)
BrainAtlasVersion.whss_datlas_v3 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/WHSSDatlas_v3",
    abbreviation="WHSSDatlas",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpace/WHSSD_v1.01"},
    full_documentation={"@id": "https://doi.org/10.1016/j.neuroimage.2019.05.016"},
    full_name="Waxholm Space Atlas of the Sprague Dawley Rat Brain",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_descendingCorticofugalPathways"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_substantiaNigra"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_subthalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_molecularLayerOfTheCerebellum"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_granuleCellLevelOfTheCerebellum"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_alveusOfTheHippocampus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_inferiorCerebellarPeduncle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_cingulateCortexArea2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_striatum"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_globusPallidus"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_entopeduncularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_ventricularSystem"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_medialLemniscus"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_facialNerve"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_anteriorCommissureAnteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_anteriorCommissurePosteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_ventralHippocampalCommissure"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_thalamus"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_septalRegion"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_opticNerve"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_opticTractAndOpticChiasm"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_pinealGland"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_spinalCord"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_commissureOfTheSuperiorColliculus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_brainstem"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_hypothalamicRegion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_superficialGrayLayerOfTheSuperiorColliculus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_periaqueductalGray"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_fornix"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_mammillothalamicTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_commissuralStriaTerminalis"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_deeperLayersOfTheSuperiorColliculus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_periventricularGray"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_genuOfTheFacialNerve"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_pontineNuclei"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_fimbriaOfTheHippocampus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_fasciculusRetroflexus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_striaMedullarisOfTheThalamus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_striaTerminalis"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_posteriorCommissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_glomerularLayerOfTheAccessoryOlfactoryBulb"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_glomerularLayerOfTheOlfactoryBulb"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_olfactoryBulb"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_corpusCallosumAndAssociatedSubcorticalWhiteMatter"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_brachiumOfTheSuperiorColliculus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_inferiorColliculusCommissure"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_centralCanal"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_interpeduncularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_ascendingFibersOfTheFacialNerve"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_anteriorCommissure"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_inferiorOlive"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_spinalTrigeminalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_spinalTrigeminalTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_frontalAssociationCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_middleCerebellarPeduncle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_transverseFibersOfThePons"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_habenularCommissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_nucleusOfTheStriaMedullaris"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_basalForebrainRegion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_supraopticDecussation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_medialLemniscusDecussation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_pyramidalDecussation"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_neocortex"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_bedNucleusOfTheStriaTerminalis"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_pretectalRegion"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_cornuAmmonis3"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_dentateGyrus"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_cornuAmmonis2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_cornuAmmonis1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_fasciolaCinereum"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_subiculum"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_postrhinalCortex"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_presubiculum"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_parasubiculum"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_perirhinalArea35"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_perirhinalArea36"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_entorhinalCortex"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_lateralEntorhinalCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_vestibularApparatus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_cochlea"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_cochlearNerve"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_vestibularNerve"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_ventralCochlearNucleusGranuleCellLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_4thVentricle"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_dorsalCochlearNucleusMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_dorsalCochlearNucleusFusiformAndGranuleLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_dorsalCochlearNucleusDeepCore"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_acousticStriae"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_trapezoidBody"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_nucleusOfTheTrapezoidBody"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_superiorParaolivaryNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_medialSuperiorOlive"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_lateralSuperiorOlive"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_superiorPeriolivaryRegion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_ventralPeriolivaryNuclei"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_lateralLemniscusVentralNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_lateralLemniscusIntermediateNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_lateralLemniscusDorsalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_lateralLemniscusCommissure"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_lateralLemniscus"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_inferiorColliculusDorsalCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_inferiorColliculusCentralNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_inferiorColliculusExternalCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_inferiorColliculusBrachium"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_medialGeniculateBodyMedialDivision"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_medialGeniculateBodyDorsalDivision"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_medialGeniculateBodyVentralDivision"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_medialGeniculateBodyMarginalZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_primaryAuditoryCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_secondaryAuditoryCortexDorsalArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_secondaryAuditoryCortexVentralArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_auditoryRadiation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_ventralCochlearNucleusAnteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_ventralCochlearNucleusPosteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_ventralCochlearNucleusCapArea"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_spiralGanglion"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_nucleusSagulum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3_reticularThalamicNucleusAuditorySegment"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://www.nitrc.org/projects/whs-sd-atlas/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_001592](https://scicrunch.org/resolver/SCR_001592), and cite the following publications: [Papp et al. (2014)](https://doi.org/10.1016/j.neuroimage.2014.04.001); [Osen et al. (2019)](https://doi.org/10.1016/j.neuroimage.2019.05.016).",
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/WHSSDatlas_v2"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccBy4.0"},
    related_publications=[
        {"@id": "https://doi.org/10.1016/j.neuroimage.2014.04.001"},
        {"@id": "https://doi.org/10.1016/j.neuroimage.2014.10.017"},
        {"@id": "https://doi.org/10.1016/j.neuroimage.2014.12.080"},
    ],
    release_date="2019-05-15",
    short_name="Waxholm Space Rat Brain Atlas",
    support_channels=["support@ebrains.eu", "https://www.nitrc.org/forum/forum.php?forum_id=9174"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/deterministicAtlas"},
    version_identifier="v3",
    version_innovation="Anatomical delineations of 118 brain regions and white matter tracts in the Sprague Dawley rat brain, based on observations in a high resolution magnetic resonance imaging (MRI) volume (DOI: 10.25493/DTSG-ZBS). Version 3 of the Waxholm Space atlas of the Sprague Dawley rat brain contains 41 new and 10 updated delineations related or adjacent to the ascending the auditory system. 65 delineations have remained unchanged relative to v2. This dataset is hosted on NITRC.org and includes: WHS_SD_rat_atlas_v3.nii.gz: delineation file with anatomical structures; WHS_SD_rat_atlas_v3.label: text file naming anatomical structures; MBAT_WHS_SD_rat_atlas_v3.zip: file describing a suggested hierarchy of the anatomical structures. Note: The licence was changed to from CC BY-SA-NC to CC BY-SA on October 1, 2021.",
)
BrainAtlasVersion.whss_datlas_v3_01 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/WHSSDatlas_v3.01",
    abbreviation="WHSSDatlas",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpace/WHSSD_v1.01"},
    full_documentation={"@id": "https://doi.org/10.1016/j.neuroimage.2019.05.016"},
    full_name="Waxholm Space Atlas of the Sprague Dawley Rat Brain",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_descendingCorticofugalPathways"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_substantiaNigra"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_subthalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_molecularCellLayerOfTheCerebellum"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_deeperCerebellum"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_alveusOfTheHippocampus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_inferiorCerebellarPeduncle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_cingulateCortexArea2"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_striatum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_globusPallidus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_entopeduncularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_ventricularSystemUnspecified"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_medialLemniscus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_facialNerve"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_anteriorCommissureAnteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_anteriorCommissurePosteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_ventralHippocampalCommissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_thalamusUnspecified"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_septalRegion"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_opticNerve"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_opticTractAndOpticChiasm"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_pinealGland"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_spinalCord"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_commissureOfTheSuperiorColliculus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_brainstemUnspecified"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_hypothalamicRegion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_superficialGrayLayerOfTheSuperiorColliculus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_periaqueductalGray"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_fornix"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_mammillotegmentalTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_commissuralStriaTerminalis"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_deeperLayersOfTheSuperiorColliculus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_periventricularGray"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_genuOfTheFacialNerve"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_pontineNuclei"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_fimbriaOfTheHippocampus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_fasciculusRetroflexus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_striaMedullarisOfTheThalamus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_striaTerminalis"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_posteriorCommissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_glomerularLayerOfTheAccessoryOlfactoryBulb"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_glomerularLayerOfTheOlfactoryBulb"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_olfactoryBulb"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_corpusCallosumAndAssociatedSubcorticalWhiteMatter"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_brachiumOfTheSuperiorColliculus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_inferiorColliculusCommissure"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_centralCanal"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_interpeduncularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_ascendingFibersOfTheFacialNerve"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_anteriorCommissureIntrabulbarPart"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_inferiorOlive"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_spinalTrigeminalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_spinalTrigeminalTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_frontalAssociationCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_middleCerebellarPeduncle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_transverseFibersOfThePons"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_habenularCommissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_nucleusOfTheStriaMedullaris"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_basalForebrainRegionUnspecified"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_supraopticDecussation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_medialLemniscusDecussation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_pyramidalDecussation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_neocortexUnspecified"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_bedNucleusOfTheStriaTerminalis"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_pretectalRegion"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_cornuAmmonis3"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_dentateGyrus"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_cornuAmmonis2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_cornuAmmonis1"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_fasciolaCinereum"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_subiculum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_postrhinalCortex"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_presubiculum"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_parasubiculum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_perirhinalArea35"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_perirhinalArea36"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_medialEntorhinalCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_lateralEntorhinalCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_vestibularApparatus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_cochlea"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_cochlearNerve"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_vestibularNerve"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_ventralCochlearNucleusGranuleCellLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_4thVentricle"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_dorsalCochlearNucleusMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_dorsalCochlearNucleusFusiformAndGranuleLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_dorsalCochlearNucleusDeepCore"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_acousticStriae"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_trapezoidBody"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_nucleusOfTheTrapezoidBody"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_superiorParaolivaryNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_medialSuperiorOlive"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_lateralSuperiorOlive"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_superiorPeriolivaryRegion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_ventralPeriolivaryNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_lateralLemniscusVentralNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_lateralLemniscusIntermediateNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_lateralLemniscusDorsalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_lateralLemniscusCommissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_lateralLemniscus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_inferiorColliculusDorsalCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_inferiorColliculusCentralNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_inferiorColliculusExternalCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_inferiorColliculusBrachium"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_medialGeniculateBodyMedialDivision"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_medialGeniculateBodyDorsalDivision"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_medialGeniculateBodyVentralDivision"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_medialGeniculateBodyMarginalZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_primaryAuditoryCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_secondaryAuditoryCortexDorsalArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_secondaryAuditoryCortexVentralArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_auditoryRadiation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_ventralCochlearNucleusAnteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_ventralCochlearNucleusPosteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_ventralCochlearNucleusCapArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_spiralGanglion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_nucleusSagulum"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v3.01_reticularThalamicNucleusAuditorySegment"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://www.nitrc.org/projects/whs-sd-atlas/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_001592](https://scicrunch.org/resolver/SCR_001592), and cite the following publications: [Papp et al. (2014)](https://doi.org/10.1016/j.neuroimage.2014.04.001); [Osen et al. (2019)](https://doi.org/10.1016/j.neuroimage.2019.05.016).",
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/WHSSDatlas_v3"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccBy4.0"},
    related_publications=[
        {"@id": "https://doi.org/10.1016/j.neuroimage.2014.04.001"},
        {"@id": "https://doi.org/10.1016/j.neuroimage.2014.10.017"},
        {"@id": "https://doi.org/10.1016/j.neuroimage.2014.12.080"},
    ],
    release_date="2021-10-01",
    short_name="Waxholm Space Rat Brain Atlas",
    support_channels=["support@ebrains.eu", "https://www.nitrc.org/forum/forum.php?forum_id=9174"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/deterministicAtlas"},
    version_identifier="v3.01",
)
BrainAtlasVersion.whss_datlas_v4 = BrainAtlasVersion(
    id="https://openminds.ebrains.eu/instances/brainAtlasVersion/WHSSDatlas_v4",
    abbreviation="WHSSDatlas",
    accessibility={"@id": "https://openminds.ebrains.eu/instances/productAccessibility/freeAccess"},
    coordinate_space={"@id": "https://openminds.ebrains.eu/instances/commonCoordinateSpace/WHSSD_v1.01"},
    full_documentation={"@id": "https://doi.org/10.21203/rs.3.rs-2466303/v1"},
    full_name="Waxholm Space Atlas of the Sprague Dawley Rat Brain",
    has_terminology={
        "@type": "https://openminds.ebrains.eu/sands/ParcellationTerminologyVersion",
        "dataLocation": None,
        "hasEntity": [
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_corticofugalTractAndCoronaRadiata"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_subthalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_molecularCellLayerOfTheCerebellum"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_cerebellumUnspecified"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_alveusOfTheHippocampus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_inferiorCerebellarPeduncle"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_cingulateArea2"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_entopeduncularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_ventricularSystemUnspecified"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_medialLemniscusUnspecified"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_facialNerveUnspecified"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_anteriorCommissureAnteriorLimb"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_anteriorCommissurePosteriorLimb"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_ventralHippocampalCommissure"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_septalRegion"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_opticNerve"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_opticTractAndOpticChiasm"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_pinealGland"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_spinalCord"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_commissureOfTheSuperiorColliculus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_brainstemUnspecified"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_hypothalamicRegionUnspecified"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_superficialGrayLayerOfTheSuperiorColliculus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_periaqueductalGray"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_fornix"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_mammillotegmentalTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_commissuralStriaTerminalis"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_deeperLayersOfTheSuperiorColliculus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_periventricularGray"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_genuOfTheFacialNerve"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_pontineNuclei"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_fimbriaOfTheHippocampus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_fasciculusRetroflexus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_striaMedullarisThalami"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_striaTerminalis"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_posteriorCommissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_glomerularLayerOfTheAccessoryOlfactoryBulb"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_glomerularLayerOfTheOlfactoryBulb"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_olfactoryBulbUnspecified"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_corpusCallosumAndAssociatedSubcorticalWhiteMatter"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_brachiumOfTheSuperiorColliculus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_inferiorColliculusCommissure"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_centralCanal"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_interpeduncularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_ascendingFibersOfTheFacialNerve"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_anteriorCommissureIntrabulbarPart"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_inferiorOlive"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_spinalTrigeminalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_spinalTrigeminalTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_frontalAssociationCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_middleCerebellarPeduncle"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_transverseFibersOfThePons"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_habenularCommissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_nucleusOfTheStriaMedullaris"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_basalForebrainRegionUnspecified"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_supraopticDecussation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_medialLemniscusDecussation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_pyramidalDecussation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_bedNucleusOfTheStriaTerminalis"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_pretectalRegion"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_cornuAmmonis3"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_dentateGyrus"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_cornuAmmonis2"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_cornuAmmonis1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_fasciolaCinereum"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_subiculum"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_postrhinalCortex"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_presubiculum"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_parasubiculum"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_perirhinalArea35"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_perirhinalArea36"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_medialEntorhinalCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_lateralEntorhinalCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_vestibularApparatus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_cochlea"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_cochlearNerve"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_vestibularNerve"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_ventralCochlearNucleusGranuleCellLayer"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_4thVentricle"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_dorsalCochlearNucleusMolecularLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_dorsalCochlearNucleusFusiformAndGranuleLayer"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_dorsalCochlearNucleusDeepCore"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_acousticStriae"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_trapezoidBody"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_nucleusOfTheTrapezoidBody"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_superiorParaolivaryNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_medialSuperiorOlive"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_lateralSuperiorOlive"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_superiorPeriolivaryRegion"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_ventralPeriolivaryNuclei"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_lateralLemniscusVentralNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_lateralLemniscusIntermediateNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_lateralLemniscusDorsalNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_lateralLemniscusCommissure"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_lateralLemniscusUnspecified"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_inferiorColliculusDorsalCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_inferiorColliculusCentralNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_inferiorColliculusExternalCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_inferiorColliculusBrachium"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_medialGeniculateBodyMarginalZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_primaryAuditoryArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_secondaryAuditoryAreaDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_secondaryAuditoryAreaVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_externalMedullaryLaminaAuditoryRadiation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_ventralCochlearNucleusAnteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_ventralCochlearNucleusPosteriorPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_ventralCochlearNucleusCapArea"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_spiralGanglion"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_nucleusSagulum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_reticularPrethalamicNucleusAuditorySegment"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_lateralOlfactoryTract"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_piriformCortexLayer1"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_piriformCortexLayer2"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_piriformCortexLayer3"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_nucleusAccumbensCore"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_substantiaNigraReticularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_substantiaNigraCompactPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_substantiaNigraLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_nucleusAccumbensShell"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_ventralPallidum"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_globusPallidusExternalMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_ventralTegmentalArea"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_caudatePutamen"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_globusPallidusExternalLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_ventralStriatalRegionUnspecified"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_reticularPrethalamicNucleusUnspecified"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_peripeduncularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_pregeniculateNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_dorsalLateralGeniculateNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_lateralHabenularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_medialHabenularNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_posteriorIntralaminarNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_posteriorThalamicNuclearGroupTriangularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_parataenialThalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_anterodorsalThalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_anteroventralThalamicNucleusDorsomedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_anteroventralThalamicNucleusVentrolateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_rhomboidThalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_xiphoidThalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_reuniensThalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_ventromedialThalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_submediusThalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_angularThalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_ventralPosteromedialThalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_laterodorsalThalamicNucleusDorsomedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_laterodorsalThalamicNucleusVentrolateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_posteriorThalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_ventrolateralThalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_mediodorsalThalamicNucleusLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_mediodorsalThalamicNucleusCentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_zonaIncertaDorsalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_zonaIncertaVentralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_zonaIncertaA13DopamineCells"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_pretectothalamicLamina"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_mediodorsalThalamicNucleusMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_paraventricularThalamicNucleiAnteriorAndPosterior"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_paracentralThalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_centralMedialThalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_centralLateralThalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_externalMedullaryLaminaUnspecified"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_anteromedialThalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_interanteromedialThalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_zonaIncertaRostralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_intermediodorsalThalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_ventralPosteriorNucleusOfTheThalamusParvicellularPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_parafascicularThalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_retroreuniensThalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_superiorCerebellarPeduncleAndPrerubralField"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_intergeniculateLeaflet"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_subparafascicularNucleus"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_fieldsOfForel"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_subgeniculateNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_ethmoidLimitansNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_lateralPosteriorThalamicNucleusLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_zonaIncertaA11DopamineCells"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_lateralPosteriorThalamicNucleusMediorostralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_lateralPosteriorThalamicNucleusMediocaudalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_zonaIncertaCaudalPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_intramedullaryThalamicArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_internalMedullaryLamina"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_ventralAnteriorThalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_ventralPosterolateralThalamicNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_medialGeniculateBodyDorsalDivision"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_medialGeniculateBodyMedialDivision"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_medialGeniculateBodyVentralDivision"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_medialGeniculateBodySuprageniculateNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_ventrolateralOrbitalArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_lateralOrbitalArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_ventralOrbitalArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_medialOrbitalArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_dorsolateralOrbitalArea"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_prelimbicArea"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_secondaryMotorArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_frontalAssociationArea3"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_primaryMotorArea"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_agranularInsularCortexVentralArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_agranularInsularCortexDorsalArea"
            },
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_cingulateArea1"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_claustrum"},
            {"@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_infralimbicArea"},
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_dysgranularInsularCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_granularInsularCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_primarySomatosensoryAreaForelimbRepresentation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_primarySomatosensoryAreaDysgranularZone"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_primarySomatosensoryAreaFaceRepresentation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_secondarySomatosensoryArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_primarySomatosensoryAreaHindlimbRepresentation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_agranularInsularCortexPosteriorArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_primarySomatosensoryAreaBarrelField"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_retrosplenialDysgranularArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_primarySomatosensoryAreaTrunkRepresentation"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_retrosplenialGranularArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_parietalAssociationCortexLateralArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_parietalAssociationCortexMedialArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_parietalAssociationCortexPosteriorArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_primaryVisualArea"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_secondaryVisualAreaLateralPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_temporalAssociationCortex"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_secondaryVisualAreaMedialPart"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_endopiriformNucleus"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_amygdaloidAreaUnspecified"
            },
            {
                "@id": "https://openminds.ebrains.eu/instances/parcellationEntityVersion/WHSSDatlas_v4_nucleusOfTheLateralOlfactoryTract"
            },
        ],
        "ontologyIdentifier": None,
    },
    homepage=IRI("https://www.nitrc.org/projects/whs-sd-atlas/"),
    how_to_cite="Please refer to the atlas by its [RRID:SCR_001592](https://scicrunch.org/resolver/SCR_001592), and cite the following publications: [Papp et al. (2014)](https://doi.org/10.1016/j.neuroimage.2014.04.001); [Kleven et al. (2023)](https://doi.org/10.21203/rs.3.rs-2466303/v1).",
    is_new_version_of={"@id": "https://openminds.ebrains.eu/instances/brainAtlasVersion/WHSSDatlas_v3.01"},
    license={"@id": "https://openminds.ebrains.eu/instances/licenses/ccBy4.0"},
    related_publications=[
        {"@id": "https://doi.org/10.1016/j.neuroimage.2014.04.001"},
        {"@id": "https://doi.org/10.1016/j.neuroimage.2014.10.017"},
        {"@id": "https://doi.org/10.1016/j.neuroimage.2014.12.080"},
        {"@id": "https://doi.org/10.1016/j.neuroimage.2019.05.016"},
    ],
    release_date="2021-10-01",
    short_name="Waxholm Space Rat Brain Atlas",
    support_channels=["support@ebrains.eu", "https://www.nitrc.org/forum/forum.php?forum_id=9174"],
    type={"@id": "https://openminds.ebrains.eu/instances/atlasType/deterministicAtlas"},
    version_identifier="v4",
    version_innovation="Anatomical delineations of 222 brain regions and white matter tracts in the Sprague Dawley rat brain, based on a high resolution magnetic resonance imaging (MRI) volume (DOI: 10.25493/DTSG-ZBS). Version 4 of the Waxholm Space atlas of the Sprague Dawley rat brain contains 112 new and 56 updated delineations related or adjacent to the basal ganglia, thalamus and cortical structures. 54 delineations have remained unchanged and 9 have been completely replaced relative to v3. This dataset is hosted on NITRC.org and includes: WHS_SD_rat_atlas_v4.nii.gz: delineation file with anatomical structures; WHS_SD_rat_atlas_v4.label: text file naming anatomical structures; MBAT_WHS_SD_rat_atlas_v4.zip: file describing a suggested hierarchy of the anatomical structures",
)
